#[non_exhaustive]pub struct CreateAutonomousDatabaseOutput {
pub autonomous_database_id: String,
pub display_name: Option<String>,
pub status: Option<AutonomousDatabaseResourceStatus>,
pub status_reason: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.autonomous_database_id: StringThe unique identifier of the Autonomous Database that was created.
display_name: Option<String>The user-friendly name of the Autonomous Database that was created.
status: Option<AutonomousDatabaseResourceStatus>The current status of the Autonomous Database.
status_reason: Option<String>Additional information about the current status of the Autonomous Database, if applicable.
Implementations
Sourceimpl CreateAutonomousDatabaseOutput
impl CreateAutonomousDatabaseOutput
Sourcepub fn autonomous_database_id(&self) -> &str
pub fn autonomous_database_id(&self) -> &str
The unique identifier of the Autonomous Database that was created.
Sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
The user-friendly name of the Autonomous Database that was created.
Sourcepub fn status(&self) -> Option<&AutonomousDatabaseResourceStatus>
pub fn status(&self) -> Option<&AutonomousDatabaseResourceStatus>
The current status of the Autonomous Database.
Sourcepub fn status_reason(&self) -> Option<&str>
pub fn status_reason(&self) -> Option<&str>
Additional information about the current status of the Autonomous Database, if applicable.
Sourceimpl CreateAutonomousDatabaseOutput
impl CreateAutonomousDatabaseOutput
Sourcepub fn builder() -> CreateAutonomousDatabaseOutputBuilder
pub fn builder() -> CreateAutonomousDatabaseOutputBuilder
Creates a new builder-style object to manufacture CreateAutonomousDatabaseOutput.