#[non_exhaustive]pub struct CreateAutonomousDatabaseBackupInputBuilder { /* private fields */ }Expand description
A builder for CreateAutonomousDatabaseBackupInput.
Implementations
Sourceimpl CreateAutonomousDatabaseBackupInputBuilder
impl CreateAutonomousDatabaseBackupInputBuilder
Sourcepub fn autonomous_database_id(self, input: impl Into<String>) -> Self
pub fn autonomous_database_id(self, input: impl Into<String>) -> Self
The unique identifier of the Autonomous Database to back up.
This field is required.Sourcepub fn set_autonomous_database_id(self, input: Option<String>) -> Self
pub fn set_autonomous_database_id(self, input: Option<String>) -> Self
The unique identifier of the Autonomous Database to back up.
Sourcepub fn get_autonomous_database_id(&self) -> &Option<String>
pub fn get_autonomous_database_id(&self) -> &Option<String>
The unique identifier of the Autonomous Database to back up.
Sourcepub fn display_name(self, input: impl Into<String>) -> Self
pub fn display_name(self, input: impl Into<String>) -> Self
The user-friendly name for the Autonomous Database backup.
Sourcepub fn set_display_name(self, input: Option<String>) -> Self
pub fn set_display_name(self, input: Option<String>) -> Self
The user-friendly name for the Autonomous Database backup.
Sourcepub fn get_display_name(&self) -> &Option<String>
pub fn get_display_name(&self) -> &Option<String>
The user-friendly name for the Autonomous Database backup.
Sourcepub fn retention_period_in_days(self, input: i32) -> Self
pub fn retention_period_in_days(self, input: i32) -> Self
The retention period, in days, for the Autonomous Database backup.
Sourcepub fn set_retention_period_in_days(self, input: Option<i32>) -> Self
pub fn set_retention_period_in_days(self, input: Option<i32>) -> Self
The retention period, in days, for the Autonomous Database backup.
Sourcepub fn get_retention_period_in_days(&self) -> &Option<i32>
pub fn get_retention_period_in_days(&self) -> &Option<i32>
The retention period, in days, for the Autonomous Database backup.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A client-provided token to ensure the idempotency of the request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A client-provided token to ensure the idempotency of the request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A client-provided token to ensure the idempotency of the request.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
The list of resource tags to apply to the Autonomous Database backup. Each tag is a key-value pair with no predefined name, type, or namespace.
The list of resource tags to apply to the Autonomous Database backup. Each tag is a key-value pair with no predefined name, type, or namespace.
The list of resource tags to apply to the Autonomous Database backup. Each tag is a key-value pair with no predefined name, type, or namespace.
Sourcepub fn build(self) -> Result<CreateAutonomousDatabaseBackupInput, BuildError>
pub fn build(self) -> Result<CreateAutonomousDatabaseBackupInput, BuildError>
Consumes the builder and constructs a CreateAutonomousDatabaseBackupInput.
Sourceimpl CreateAutonomousDatabaseBackupInputBuilder
impl CreateAutonomousDatabaseBackupInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateAutonomousDatabaseBackupOutput, SdkError<CreateAutonomousDatabaseBackupError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateAutonomousDatabaseBackupOutput, SdkError<CreateAutonomousDatabaseBackupError, HttpResponse>>
Sends a request with this input using the given client.