#[non_exhaustive]pub struct CreateAutonomousDatabaseBackupInput {
pub autonomous_database_id: Option<String>,
pub display_name: Option<String>,
pub retention_period_in_days: Option<i32>,
pub client_token: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.autonomous_database_id: Option<String>The unique identifier of the Autonomous Database to back up.
display_name: Option<String>The user-friendly name for the Autonomous Database backup.
retention_period_in_days: Option<i32>The retention period, in days, for the Autonomous Database backup.
client_token: Option<String>A client-provided token to ensure the idempotency of the request.
The list of resource tags to apply to the Autonomous Database backup. Each tag is a key-value pair with no predefined name, type, or namespace.
Implementations
Sourceimpl CreateAutonomousDatabaseBackupInput
impl CreateAutonomousDatabaseBackupInput
Sourcepub fn autonomous_database_id(&self) -> Option<&str>
pub fn autonomous_database_id(&self) -> Option<&str>
The unique identifier of the Autonomous Database to back up.
Sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
The user-friendly name for the Autonomous Database backup.
Sourcepub fn retention_period_in_days(&self) -> Option<i32>
pub fn retention_period_in_days(&self) -> Option<i32>
The retention period, in days, for the Autonomous Database backup.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A client-provided token to ensure the idempotency of the request.
The list of resource tags to apply to the Autonomous Database backup. Each tag is a key-value pair with no predefined name, type, or namespace.
Sourceimpl CreateAutonomousDatabaseBackupInput
impl CreateAutonomousDatabaseBackupInput
Sourcepub fn builder() -> CreateAutonomousDatabaseBackupInputBuilder
pub fn builder() -> CreateAutonomousDatabaseBackupInputBuilder
Creates a new builder-style object to manufacture CreateAutonomousDatabaseBackupInput.