#[non_exhaustive]pub struct CreateAutonomousDatabaseWalletInputBuilder { /* private fields */ }Expand description
A builder for CreateAutonomousDatabaseWalletInput.
Implementations
Sourceimpl CreateAutonomousDatabaseWalletInputBuilder
impl CreateAutonomousDatabaseWalletInputBuilder
Sourcepub fn autonomous_database_id(self, input: impl Into<String>) -> Self
pub fn autonomous_database_id(self, input: impl Into<String>) -> Self
The unique identifier of the Autonomous Database to create a wallet for.
This field is required.Sourcepub fn set_autonomous_database_id(self, input: Option<String>) -> Self
pub fn set_autonomous_database_id(self, input: Option<String>) -> Self
The unique identifier of the Autonomous Database to create a wallet for.
Sourcepub fn get_autonomous_database_id(&self) -> &Option<String>
pub fn get_autonomous_database_id(&self) -> &Option<String>
The unique identifier of the Autonomous Database to create a wallet for.
Sourcepub fn wallet_type(self, input: WalletType) -> Self
pub fn wallet_type(self, input: WalletType) -> Self
The type of wallet to create, either a regional wallet or an instance wallet.
Sourcepub fn set_wallet_type(self, input: Option<WalletType>) -> Self
pub fn set_wallet_type(self, input: Option<WalletType>) -> Self
The type of wallet to create, either a regional wallet or an instance wallet.
Sourcepub fn get_wallet_type(&self) -> &Option<WalletType>
pub fn get_wallet_type(&self) -> &Option<WalletType>
The type of wallet to create, either a regional wallet or an instance wallet.
Sourcepub fn password(self, input: impl Into<String>) -> Self
pub fn password(self, input: impl Into<String>) -> Self
The password to encrypt the keys inside the wallet.
Sourcepub fn set_password(self, input: Option<String>) -> Self
pub fn set_password(self, input: Option<String>) -> Self
The password to encrypt the keys inside the wallet.
Sourcepub fn get_password(&self) -> &Option<String>
pub fn get_password(&self) -> &Option<String>
The password to encrypt the keys inside the wallet.
Sourcepub fn password_source(self, input: WalletPasswordSource) -> Self
pub fn password_source(self, input: WalletPasswordSource) -> Self
The source of the password for encrypting the wallet. When set to CUSTOMER_MANAGED_AWS_SECRET, the password is retrieved from an Amazon Web Services Secrets Manager secret.
Sourcepub fn set_password_source(self, input: Option<WalletPasswordSource>) -> Self
pub fn set_password_source(self, input: Option<WalletPasswordSource>) -> Self
The source of the password for encrypting the wallet. When set to CUSTOMER_MANAGED_AWS_SECRET, the password is retrieved from an Amazon Web Services Secrets Manager secret.
Sourcepub fn get_password_source(&self) -> &Option<WalletPasswordSource>
pub fn get_password_source(&self) -> &Option<WalletPasswordSource>
The source of the password for encrypting the wallet. When set to CUSTOMER_MANAGED_AWS_SECRET, the password is retrieved from an Amazon Web Services Secrets Manager secret.
Sourcepub fn password_source_configuration(
self,
input: WalletPasswordSourceConfigurationInput,
) -> Self
pub fn password_source_configuration( self, input: WalletPasswordSourceConfigurationInput, ) -> Self
The configuration of the password source for the Autonomous Database wallet.
Sourcepub fn set_password_source_configuration(
self,
input: Option<WalletPasswordSourceConfigurationInput>,
) -> Self
pub fn set_password_source_configuration( self, input: Option<WalletPasswordSourceConfigurationInput>, ) -> Self
The configuration of the password source for the Autonomous Database wallet.
Sourcepub fn get_password_source_configuration(
&self,
) -> &Option<WalletPasswordSourceConfigurationInput>
pub fn get_password_source_configuration( &self, ) -> &Option<WalletPasswordSourceConfigurationInput>
The configuration of the password source for the Autonomous Database wallet.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A client-provided token to ensure the idempotency of the request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A client-provided token to ensure the idempotency of the request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A client-provided token to ensure the idempotency of the request.
Sourcepub fn build(self) -> Result<CreateAutonomousDatabaseWalletInput, BuildError>
pub fn build(self) -> Result<CreateAutonomousDatabaseWalletInput, BuildError>
Consumes the builder and constructs a CreateAutonomousDatabaseWalletInput.
Sourceimpl CreateAutonomousDatabaseWalletInputBuilder
impl CreateAutonomousDatabaseWalletInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateAutonomousDatabaseWalletOutput, SdkError<CreateAutonomousDatabaseWalletError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateAutonomousDatabaseWalletOutput, SdkError<CreateAutonomousDatabaseWalletError, HttpResponse>>
Sends a request with this input using the given client.