#[non_exhaustive]pub struct CreateAutonomousDatabaseWalletOutput {
pub autonomous_database_wallet_file: Blob,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.autonomous_database_wallet_file: BlobThe generated wallet file for the Autonomous Database, returned as a compressed archive.
Implementations
Sourceimpl CreateAutonomousDatabaseWalletOutput
impl CreateAutonomousDatabaseWalletOutput
Sourcepub fn autonomous_database_wallet_file(&self) -> &Blob
pub fn autonomous_database_wallet_file(&self) -> &Blob
The generated wallet file for the Autonomous Database, returned as a compressed archive.
Sourceimpl CreateAutonomousDatabaseWalletOutput
impl CreateAutonomousDatabaseWalletOutput
Sourcepub fn builder() -> CreateAutonomousDatabaseWalletOutputBuilder
pub fn builder() -> CreateAutonomousDatabaseWalletOutputBuilder
Creates a new builder-style object to manufacture CreateAutonomousDatabaseWalletOutput.