#[non_exhaustive]pub struct DeleteAutonomousDatabaseBackupInput {
pub autonomous_database_backup_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.autonomous_database_backup_id: Option<String>The unique identifier of the Autonomous Database backup to delete.
Implementations
Sourceimpl DeleteAutonomousDatabaseBackupInput
impl DeleteAutonomousDatabaseBackupInput
Sourcepub fn autonomous_database_backup_id(&self) -> Option<&str>
pub fn autonomous_database_backup_id(&self) -> Option<&str>
The unique identifier of the Autonomous Database backup to delete.
Sourceimpl DeleteAutonomousDatabaseBackupInput
impl DeleteAutonomousDatabaseBackupInput
Sourcepub fn builder() -> DeleteAutonomousDatabaseBackupInputBuilder
pub fn builder() -> DeleteAutonomousDatabaseBackupInputBuilder
Creates a new builder-style object to manufacture DeleteAutonomousDatabaseBackupInput.