#[non_exhaustive]pub struct FailoverAutonomousDatabaseInput {
pub autonomous_database_id: Option<String>,
pub peer_db_arn: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.autonomous_database_id: Option<String>The unique identifier of the Autonomous Database to fail over.
peer_db_arn: Option<String>The Amazon Resource Name (ARN) of the peer Autonomous Database to fail over to.
Implementations
Sourceimpl FailoverAutonomousDatabaseInput
impl FailoverAutonomousDatabaseInput
Sourcepub fn autonomous_database_id(&self) -> Option<&str>
pub fn autonomous_database_id(&self) -> Option<&str>
The unique identifier of the Autonomous Database to fail over.
Sourcepub fn peer_db_arn(&self) -> Option<&str>
pub fn peer_db_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the peer Autonomous Database to fail over to.
Sourceimpl FailoverAutonomousDatabaseInput
impl FailoverAutonomousDatabaseInput
Sourcepub fn builder() -> FailoverAutonomousDatabaseInputBuilder
pub fn builder() -> FailoverAutonomousDatabaseInputBuilder
Creates a new builder-style object to manufacture FailoverAutonomousDatabaseInput.