#[non_exhaustive]pub struct GetAutonomousDatabaseBackupInputBuilder { /* private fields */ }Expand description
A builder for GetAutonomousDatabaseBackupInput.
Implementations
Sourceimpl GetAutonomousDatabaseBackupInputBuilder
impl GetAutonomousDatabaseBackupInputBuilder
Sourcepub fn autonomous_database_backup_id(self, input: impl Into<String>) -> Self
pub fn autonomous_database_backup_id(self, input: impl Into<String>) -> Self
The unique identifier of the Autonomous Database backup to retrieve information about.
This field is required.Sourcepub fn set_autonomous_database_backup_id(self, input: Option<String>) -> Self
pub fn set_autonomous_database_backup_id(self, input: Option<String>) -> Self
The unique identifier of the Autonomous Database backup to retrieve information about.
Sourcepub fn get_autonomous_database_backup_id(&self) -> &Option<String>
pub fn get_autonomous_database_backup_id(&self) -> &Option<String>
The unique identifier of the Autonomous Database backup to retrieve information about.
Sourcepub fn build(self) -> Result<GetAutonomousDatabaseBackupInput, BuildError>
pub fn build(self) -> Result<GetAutonomousDatabaseBackupInput, BuildError>
Consumes the builder and constructs a GetAutonomousDatabaseBackupInput.
Sourceimpl GetAutonomousDatabaseBackupInputBuilder
impl GetAutonomousDatabaseBackupInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetAutonomousDatabaseBackupOutput, SdkError<GetAutonomousDatabaseBackupError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetAutonomousDatabaseBackupOutput, SdkError<GetAutonomousDatabaseBackupError, HttpResponse>>
Sends a request with this input using the given client.