#[non_exhaustive]pub struct StopAutonomousDatabaseInput {
pub autonomous_database_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.autonomous_database_id: Option<String>The unique identifier of the Autonomous Database to stop.
Implementations
Sourceimpl StopAutonomousDatabaseInput
impl StopAutonomousDatabaseInput
Sourcepub fn autonomous_database_id(&self) -> Option<&str>
pub fn autonomous_database_id(&self) -> Option<&str>
The unique identifier of the Autonomous Database to stop.
Sourceimpl StopAutonomousDatabaseInput
impl StopAutonomousDatabaseInput
Sourcepub fn builder() -> StopAutonomousDatabaseInputBuilder
pub fn builder() -> StopAutonomousDatabaseInputBuilder
Creates a new builder-style object to manufacture StopAutonomousDatabaseInput.