#[non_exhaustive]pub struct UpdateAutonomousDatabaseBackupInput {
pub autonomous_database_backup_id: Option<String>,
pub retention_period_in_days: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.autonomous_database_backup_id: Option<String>The unique identifier of the Autonomous Database backup to update.
retention_period_in_days: Option<i32>The retention period, in days, for the Autonomous Database backup.
Implementations
Sourceimpl UpdateAutonomousDatabaseBackupInput
impl UpdateAutonomousDatabaseBackupInput
Sourcepub fn autonomous_database_backup_id(&self) -> Option<&str>
pub fn autonomous_database_backup_id(&self) -> Option<&str>
The unique identifier of the Autonomous Database backup to update.
Sourcepub fn retention_period_in_days(&self) -> Option<i32>
pub fn retention_period_in_days(&self) -> Option<i32>
The retention period, in days, for the Autonomous Database backup.
Sourceimpl UpdateAutonomousDatabaseBackupInput
impl UpdateAutonomousDatabaseBackupInput
Sourcepub fn builder() -> UpdateAutonomousDatabaseBackupInputBuilder
pub fn builder() -> UpdateAutonomousDatabaseBackupInputBuilder
Creates a new builder-style object to manufacture UpdateAutonomousDatabaseBackupInput.