AutonomousDatabaseBackupBuilder

Struct AutonomousDatabaseBackupBuilder 

#[non_exhaustive]
pub struct AutonomousDatabaseBackupBuilder { /* private fields */ }
A builder for AutonomousDatabaseBackup.

Implementations

Source

impl AutonomousDatabaseBackupBuilder

pub fn autonomous_database_backup_id(self, input: impl Into<String>) -> Self

The unique identifier of the Autonomous Database backup.

pub fn set_autonomous_database_backup_id(self, input: Option<String>) -> Self

The unique identifier of the Autonomous Database backup.

pub fn get_autonomous_database_backup_id(&self) -> &Option<String>

The unique identifier of the Autonomous Database backup.

pub fn autonomous_database_backup_arn(self, input: impl Into<String>) -> Self

The Amazon Resource Name (ARN) of the Autonomous Database backup.

pub fn set_autonomous_database_backup_arn(self, input: Option<String>) -> Self

The Amazon Resource Name (ARN) of the Autonomous Database backup.

pub fn get_autonomous_database_backup_arn(&self) -> &Option<String>

The Amazon Resource Name (ARN) of the Autonomous Database backup.

pub fn autonomous_database_id(self, input: impl Into<String>) -> Self

The unique identifier of the Autonomous Database that the backup was created from.

pub fn set_autonomous_database_id(self, input: Option<String>) -> Self

The unique identifier of the Autonomous Database that the backup was created from.

pub fn get_autonomous_database_id(&self) -> &Option<String>

The unique identifier of the Autonomous Database that the backup was created from.

pub fn ocid(self, input: impl Into<String>) -> Self

The Oracle Cloud Identifier (OCID) of the Autonomous Database backup.

pub fn set_ocid(self, input: Option<String>) -> Self

The Oracle Cloud Identifier (OCID) of the Autonomous Database backup.

pub fn get_ocid(&self) -> &Option<String>

The Oracle Cloud Identifier (OCID) of the Autonomous Database backup.

pub fn display_name(self, input: impl Into<String>) -> Self

The user-friendly name of the Autonomous Database backup.

pub fn set_display_name(self, input: Option<String>) -> Self

The user-friendly name of the Autonomous Database backup.

pub fn get_display_name(&self) -> &Option<String>

The user-friendly name of the Autonomous Database backup.

pub fn db_version(self, input: impl Into<String>) -> Self

The Oracle Database software version of the Autonomous Database backup.

pub fn set_db_version(self, input: Option<String>) -> Self

The Oracle Database software version of the Autonomous Database backup.

pub fn get_db_version(&self) -> &Option<String>

The Oracle Database software version of the Autonomous Database backup.

pub fn status(self, input: AutonomousDatabaseBackupStatus) -> Self

The current status of the Autonomous Database backup.

pub fn set_status(self, input: Option<AutonomousDatabaseBackupStatus>) -> Self

The current status of the Autonomous Database backup.

pub fn get_status(&self) -> &Option<AutonomousDatabaseBackupStatus>

The current status of the Autonomous Database backup.

pub fn status_reason(self, input: impl Into<String>) -> Self

Additional information about the current status of the Autonomous Database backup, if applicable.

pub fn set_status_reason(self, input: Option<String>) -> Self

Additional information about the current status of the Autonomous Database backup, if applicable.

pub fn get_status_reason(&self) -> &Option<String>

Additional information about the current status of the Autonomous Database backup, if applicable.

pub fn is_automatic(self, input: bool) -> Self

Indicates whether the backup was created automatically.

pub fn set_is_automatic(self, input: Option<bool>) -> Self

Indicates whether the backup was created automatically.

pub fn get_is_automatic(&self) -> &Option<bool>

Indicates whether the backup was created automatically.

pub fn retention_period_in_days(self, input: i32) -> Self

The retention period, in days, for the Autonomous Database backup.

pub fn set_retention_period_in_days(self, input: Option<i32>) -> Self

The retention period, in days, for the Autonomous Database backup.

pub fn get_retention_period_in_days(&self) -> &Option<i32>

The retention period, in days, for the Autonomous Database backup.

pub fn size_in_tbs(self, input: f64) -> Self

The size of the Autonomous Database backup, in terabytes (TB).

pub fn set_size_in_tbs(self, input: Option<f64>) -> Self

The size of the Autonomous Database backup, in terabytes (TB).

pub fn get_size_in_tbs(&self) -> &Option<f64>

The size of the Autonomous Database backup, in terabytes (TB).

pub fn time_available_till(self, input: DateTime) -> Self

The date and time until which the Autonomous Database backup is available for restore.

pub fn set_time_available_till(self, input: Option<DateTime>) -> Self

The date and time until which the Autonomous Database backup is available for restore.

pub fn get_time_available_till(&self) -> &Option<DateTime>

The date and time until which the Autonomous Database backup is available for restore.

pub fn time_started(self, input: DateTime) -> Self

The date and time when the Autonomous Database backup started.

pub fn set_time_started(self, input: Option<DateTime>) -> Self

The date and time when the Autonomous Database backup started.

pub fn get_time_started(&self) -> &Option<DateTime>

The date and time when the Autonomous Database backup started.

pub fn time_ended(self, input: DateTime) -> Self

The date and time when the Autonomous Database backup ended.

pub fn set_time_ended(self, input: Option<DateTime>) -> Self

The date and time when the Autonomous Database backup ended.

pub fn get_time_ended(&self) -> &Option<DateTime>

The date and time when the Autonomous Database backup ended.

pub fn type(self, input: AutonomousDatabaseBackupType) -> Self

The type of the Autonomous Database backup.

pub fn set_type(self, input: Option<AutonomousDatabaseBackupType>) -> Self

The type of the Autonomous Database backup.

pub fn get_type(&self) -> &Option<AutonomousDatabaseBackupType>

The type of the Autonomous Database backup.

pub fn build(self) -> AutonomousDatabaseBackup

Consumes the builder and constructs a AutonomousDatabaseBackup.