AutonomousDatabaseBuilder

Struct AutonomousDatabaseBuilder 

#[non_exhaustive]
pub struct AutonomousDatabaseBuilder { /* private fields */ }
A builder for AutonomousDatabase.

Implementations

Source

impl AutonomousDatabaseBuilder

pub fn autonomous_database_id(self, input: impl Into<String>) -> Self

The unique identifier of the Autonomous Database.

pub fn set_autonomous_database_id(self, input: Option<String>) -> Self

The unique identifier of the Autonomous Database.

pub fn get_autonomous_database_id(&self) -> &Option<String>

The unique identifier of the Autonomous Database.

pub fn autonomous_database_arn(self, input: impl Into<String>) -> Self

The Amazon Resource Name (ARN) of the Autonomous Database.

pub fn set_autonomous_database_arn(self, input: Option<String>) -> Self

The Amazon Resource Name (ARN) of the Autonomous Database.

pub fn get_autonomous_database_arn(&self) -> &Option<String>

The Amazon Resource Name (ARN) of the Autonomous Database.

pub fn oci_resource_anchor_name(self, input: impl Into<String>) -> Self

The name of the Oracle Cloud Infrastructure (OCI) resource anchor associated with the Autonomous Database.

pub fn set_oci_resource_anchor_name(self, input: Option<String>) -> Self

The name of the Oracle Cloud Infrastructure (OCI) resource anchor associated with the Autonomous Database.

pub fn get_oci_resource_anchor_name(&self) -> &Option<String>

The name of the Oracle Cloud Infrastructure (OCI) resource anchor associated with the Autonomous Database.

pub fn percent_progress(self, input: f32) -> Self

The progress of the current operation on the Autonomous Database, as a percentage.

pub fn set_percent_progress(self, input: Option<f32>) -> Self

The progress of the current operation on the Autonomous Database, as a percentage.

pub fn get_percent_progress(&self) -> &Option<f32>

The progress of the current operation on the Autonomous Database, as a percentage.

pub fn ocid(self, input: impl Into<String>) -> Self

The Oracle Cloud Identifier (OCID) of the Autonomous Database.

pub fn set_ocid(self, input: Option<String>) -> Self

The Oracle Cloud Identifier (OCID) of the Autonomous Database.

pub fn get_ocid(&self) -> &Option<String>

The Oracle Cloud Identifier (OCID) of the Autonomous Database.

pub fn oci_url(self, input: impl Into<String>) -> Self

The URL for accessing the OCI console page for the Autonomous Database.

pub fn set_oci_url(self, input: Option<String>) -> Self

The URL for accessing the OCI console page for the Autonomous Database.

pub fn get_oci_url(&self) -> &Option<String>

The URL for accessing the OCI console page for the Autonomous Database.

pub fn display_name(self, input: impl Into<String>) -> Self

The user-friendly name of the Autonomous Database.

pub fn set_display_name(self, input: Option<String>) -> Self

The user-friendly name of the Autonomous Database.

pub fn get_display_name(&self) -> &Option<String>

The user-friendly name of the Autonomous Database.

pub fn db_name(self, input: impl Into<String>) -> Self

The name of the Autonomous Database.

pub fn set_db_name(self, input: Option<String>) -> Self

The name of the Autonomous Database.

pub fn get_db_name(&self) -> &Option<String>

The name of the Autonomous Database.

pub fn source_id(self, input: impl Into<String>) -> Self

The unique identifier of the source from which the Autonomous Database was created.

pub fn set_source_id(self, input: Option<String>) -> Self

The unique identifier of the source from which the Autonomous Database was created.

pub fn get_source_id(&self) -> &Option<String>

The unique identifier of the source from which the Autonomous Database was created.

pub fn status(self, input: AutonomousDatabaseResourceStatus) -> Self

The current status of the Autonomous Database.

pub fn set_status(self, input: Option<AutonomousDatabaseResourceStatus>) -> Self

The current status of the Autonomous Database.

pub fn get_status(&self) -> &Option<AutonomousDatabaseResourceStatus>

The current status of the Autonomous Database.

pub fn status_reason(self, input: impl Into<String>) -> Self

Additional information about the current status of the Autonomous Database, if applicable.

pub fn set_status_reason(self, input: Option<String>) -> Self

Additional information about the current status of the Autonomous Database, if applicable.

pub fn get_status_reason(&self) -> &Option<String>

Additional information about the current status of the Autonomous Database, if applicable.

pub fn database_type(self, input: DatabaseType) -> Self

The type of the Autonomous Database, either a regular database or a clone.

pub fn set_database_type(self, input: Option<DatabaseType>) -> Self

The type of the Autonomous Database, either a regular database or a clone.

pub fn get_database_type(&self) -> &Option<DatabaseType>

The type of the Autonomous Database, either a regular database or a clone.

pub fn db_version(self, input: impl Into<String>) -> Self

The Oracle Database software version of the Autonomous Database.

pub fn set_db_version(self, input: Option<String>) -> Self

The Oracle Database software version of the Autonomous Database.

pub fn get_db_version(&self) -> &Option<String>

The Oracle Database software version of the Autonomous Database.

pub fn db_workload(self, input: DbWorkload) -> Self

The intended use of the Autonomous Database, such as transaction processing, data warehouse, JSON database, or APEX.

pub fn set_db_workload(self, input: Option<DbWorkload>) -> Self

The intended use of the Autonomous Database, such as transaction processing, data warehouse, JSON database, or APEX.

pub fn get_db_workload(&self) -> &Option<DbWorkload>

The intended use of the Autonomous Database, such as transaction processing, data warehouse, JSON database, or APEX.

pub fn character_set(self, input: impl Into<String>) -> Self

The character set of the Autonomous Database.

pub fn set_character_set(self, input: Option<String>) -> Self

The character set of the Autonomous Database.

pub fn get_character_set(&self) -> &Option<String>

The character set of the Autonomous Database.

pub fn ncharacter_set(self, input: impl Into<String>) -> Self

The national character set of the Autonomous Database.

pub fn set_ncharacter_set(self, input: Option<String>) -> Self

The national character set of the Autonomous Database.

pub fn get_ncharacter_set(&self) -> &Option<String>

The national character set of the Autonomous Database.

pub fn database_edition(self, input: DatabaseEdition) -> Self

The Oracle Database edition of the Autonomous Database.

pub fn set_database_edition(self, input: Option<DatabaseEdition>) -> Self

The Oracle Database edition of the Autonomous Database.

pub fn get_database_edition(&self) -> &Option<DatabaseEdition>

The Oracle Database edition of the Autonomous Database.

pub fn license_model(self, input: LicenseModel) -> Self

The Oracle license model that applies to the Autonomous Database.

pub fn set_license_model(self, input: Option<LicenseModel>) -> Self

The Oracle license model that applies to the Autonomous Database.

pub fn get_license_model(&self) -> &Option<LicenseModel>

The Oracle license model that applies to the Autonomous Database.

pub fn open_mode(self, input: OpenMode) -> Self

The mode in which the Autonomous Database is open, either read-only or read/write.

pub fn set_open_mode(self, input: Option<OpenMode>) -> Self

The mode in which the Autonomous Database is open, either read-only or read/write.

pub fn get_open_mode(&self) -> &Option<OpenMode>

The mode in which the Autonomous Database is open, either read-only or read/write.

pub fn permission_level(self, input: PermissionLevel) -> Self

The permission level of the Autonomous Database.

pub fn set_permission_level(self, input: Option<PermissionLevel>) -> Self

The permission level of the Autonomous Database.

pub fn get_permission_level(&self) -> &Option<PermissionLevel>

The permission level of the Autonomous Database.

pub fn is_mtls_connection_required(self, input: bool) -> Self

Indicates whether mutual TLS (mTLS) authentication is required to connect to the Autonomous Database.

pub fn set_is_mtls_connection_required(self, input: Option<bool>) -> Self

Indicates whether mutual TLS (mTLS) authentication is required to connect to the Autonomous Database.

pub fn get_is_mtls_connection_required(&self) -> &Option<bool>

Indicates whether mutual TLS (mTLS) authentication is required to connect to the Autonomous Database.

pub fn autonomous_maintenance_schedule_type( self, input: AutonomousMaintenanceScheduleType, ) -> Self

The maintenance schedule type for the Autonomous Database.

pub fn set_autonomous_maintenance_schedule_type( self, input: Option<AutonomousMaintenanceScheduleType>, ) -> Self

The maintenance schedule type for the Autonomous Database.

pub fn get_autonomous_maintenance_schedule_type( &self, ) -> &Option<AutonomousMaintenanceScheduleType>

The maintenance schedule type for the Autonomous Database.

pub fn net_services_architecture(self, input: NetServicesArchitecture) -> Self

The Oracle Net Services architecture of the Autonomous Database, either dedicated or shared.

pub fn set_net_services_architecture( self, input: Option<NetServicesArchitecture>, ) -> Self

The Oracle Net Services architecture of the Autonomous Database, either dedicated or shared.

pub fn get_net_services_architecture(&self) -> &Option<NetServicesArchitecture>

The Oracle Net Services architecture of the Autonomous Database, either dedicated or shared.

pub fn available_upgrade_versions(self, input: impl Into<String>) -> Self

Appends an item to available_upgrade_versions.

To override the contents of this collection use set_available_upgrade_versions.

The list of Oracle Database software versions to which the Autonomous Database can be upgraded.

pub fn set_available_upgrade_versions(self, input: Option<Vec<String>>) -> Self

The list of Oracle Database software versions to which the Autonomous Database can be upgraded.

pub fn get_available_upgrade_versions(&self) -> &Option<Vec<String>>

The list of Oracle Database software versions to which the Autonomous Database can be upgraded.

pub fn byol_compute_count_limit(self, input: i32) -> Self

The maximum number of compute resources that you can allocate to the Autonomous Database under the bring-your-own-license (BYOL) model.

pub fn set_byol_compute_count_limit(self, input: Option<i32>) -> Self

The maximum number of compute resources that you can allocate to the Autonomous Database under the bring-your-own-license (BYOL) model.

pub fn get_byol_compute_count_limit(&self) -> &Option<i32>

The maximum number of compute resources that you can allocate to the Autonomous Database under the bring-your-own-license (BYOL) model.

pub fn connection_string_details( self, input: AutonomousDatabaseConnectionStrings, ) -> Self

The connection string details for the Autonomous Database.

pub fn set_connection_string_details( self, input: Option<AutonomousDatabaseConnectionStrings>, ) -> Self

The connection string details for the Autonomous Database.

pub fn get_connection_string_details( &self, ) -> &Option<AutonomousDatabaseConnectionStrings>

The connection string details for the Autonomous Database.

pub fn service_console_url(self, input: impl Into<String>) -> Self

The URL for accessing the Oracle service console for the Autonomous Database.

pub fn set_service_console_url(self, input: Option<String>) -> Self

The URL for accessing the Oracle service console for the Autonomous Database.

pub fn get_service_console_url(&self) -> &Option<String>

The URL for accessing the Oracle service console for the Autonomous Database.

pub fn sql_web_developer_url(self, input: impl Into<String>) -> Self

The URL for accessing Oracle SQL Developer Web for the Autonomous Database.

pub fn set_sql_web_developer_url(self, input: Option<String>) -> Self

The URL for accessing Oracle SQL Developer Web for the Autonomous Database.

pub fn get_sql_web_developer_url(&self) -> &Option<String>

The URL for accessing Oracle SQL Developer Web for the Autonomous Database.

pub fn customer_contacts(self, input: CustomerContact) -> Self

Appends an item to customer_contacts.

To override the contents of this collection use set_customer_contacts.

The list of customer contacts that receive operational notifications from Oracle for the Autonomous Database.

pub fn set_customer_contacts(self, input: Option<Vec<CustomerContact>>) -> Self

The list of customer contacts that receive operational notifications from Oracle for the Autonomous Database.

pub fn get_customer_contacts(&self) -> &Option<Vec<CustomerContact>>

The list of customer contacts that receive operational notifications from Oracle for the Autonomous Database.

pub fn apex_details(self, input: AutonomousDatabaseApex) -> Self

The Oracle Application Express (APEX) details for the Autonomous Database.

pub fn set_apex_details(self, input: Option<AutonomousDatabaseApex>) -> Self

The Oracle Application Express (APEX) details for the Autonomous Database.

pub fn get_apex_details(&self) -> &Option<AutonomousDatabaseApex>

The Oracle Application Express (APEX) details for the Autonomous Database.

pub fn standby_db(self, input: DatabaseStandbySummary) -> Self

The details of the standby Autonomous Database in a cross-Region Oracle Data Guard configuration.

pub fn set_standby_db(self, input: Option<DatabaseStandbySummary>) -> Self

The details of the standby Autonomous Database in a cross-Region Oracle Data Guard configuration.

pub fn get_standby_db(&self) -> &Option<DatabaseStandbySummary>

The details of the standby Autonomous Database in a cross-Region Oracle Data Guard configuration.

pub fn local_standby_db(self, input: DatabaseStandbySummary) -> Self

The details of the local standby Autonomous Database in an Oracle Data Guard configuration.

pub fn set_local_standby_db(self, input: Option<DatabaseStandbySummary>) -> Self

The details of the local standby Autonomous Database in an Oracle Data Guard configuration.

pub fn get_local_standby_db(&self) -> &Option<DatabaseStandbySummary>

The details of the local standby Autonomous Database in an Oracle Data Guard configuration.

pub fn data_safe_status(self, input: DataSafeStatus) -> Self

The status of the Oracle Data Safe registration for the Autonomous Database.

pub fn set_data_safe_status(self, input: Option<DataSafeStatus>) -> Self

The status of the Oracle Data Safe registration for the Autonomous Database.

pub fn get_data_safe_status(&self) -> &Option<DataSafeStatus>

The status of the Oracle Data Safe registration for the Autonomous Database.

pub fn database_management_status(self, input: DatabaseManagementStatus) -> Self

The status of Oracle Database Management for the Autonomous Database.

pub fn set_database_management_status( self, input: Option<DatabaseManagementStatus>, ) -> Self

The status of Oracle Database Management for the Autonomous Database.

pub fn get_database_management_status( &self, ) -> &Option<DatabaseManagementStatus>

The status of Oracle Database Management for the Autonomous Database.

pub fn operations_insights_status(self, input: OperationsInsightsStatus) -> Self

The status of Oracle Operations Insights for the Autonomous Database.

pub fn set_operations_insights_status( self, input: Option<OperationsInsightsStatus>, ) -> Self

The status of Oracle Operations Insights for the Autonomous Database.

pub fn get_operations_insights_status( &self, ) -> &Option<OperationsInsightsStatus>

The status of Oracle Operations Insights for the Autonomous Database.

pub fn availability_zone(self, input: impl Into<String>) -> Self

The Availability Zone where the Autonomous Database is located.

pub fn set_availability_zone(self, input: Option<String>) -> Self

The Availability Zone where the Autonomous Database is located.

pub fn get_availability_zone(&self) -> &Option<String>

The Availability Zone where the Autonomous Database is located.

pub fn availability_zone_id(self, input: impl Into<String>) -> Self

The unique identifier of the Availability Zone where the Autonomous Database is located.

pub fn set_availability_zone_id(self, input: Option<String>) -> Self

The unique identifier of the Availability Zone where the Autonomous Database is located.

pub fn get_availability_zone_id(&self) -> &Option<String>

The unique identifier of the Availability Zone where the Autonomous Database is located.

pub fn maintenance_target_component(self, input: impl Into<String>) -> Self

The component on the Autonomous Database that the current maintenance is being applied to.

pub fn set_maintenance_target_component(self, input: Option<String>) -> Self

The component on the Autonomous Database that the current maintenance is being applied to.

pub fn get_maintenance_target_component(&self) -> &Option<String>

The component on the Autonomous Database that the current maintenance is being applied to.

pub fn connection_urls(self, input: AutonomousDatabaseConnectionUrls) -> Self

The connection URLs for accessing tools and services for the Autonomous Database.

pub fn set_connection_urls( self, input: Option<AutonomousDatabaseConnectionUrls>, ) -> Self

The connection URLs for accessing tools and services for the Autonomous Database.

pub fn get_connection_urls(&self) -> &Option<AutonomousDatabaseConnectionUrls>

The connection URLs for accessing tools and services for the Autonomous Database.

pub fn db_tools_details(self, input: DatabaseTool) -> Self

Appends an item to db_tools_details.

To override the contents of this collection use set_db_tools_details.

The list of database management tools enabled for the Autonomous Database.

pub fn set_db_tools_details(self, input: Option<Vec<DatabaseTool>>) -> Self

The list of database management tools enabled for the Autonomous Database.

pub fn get_db_tools_details(&self) -> &Option<Vec<DatabaseTool>>

The list of database management tools enabled for the Autonomous Database.

pub fn scheduled_operations(self, input: ScheduledOperationDetails) -> Self

Appends an item to scheduled_operations.

To override the contents of this collection use set_scheduled_operations.

The list of scheduled start and stop times for the Autonomous Database.

pub fn set_scheduled_operations( self, input: Option<Vec<ScheduledOperationDetails>>, ) -> Self

The list of scheduled start and stop times for the Autonomous Database.

pub fn get_scheduled_operations( &self, ) -> &Option<Vec<ScheduledOperationDetails>>

The list of scheduled start and stop times for the Autonomous Database.

pub fn resource_pool_leader_id(self, input: impl Into<String>) -> Self

The unique identifier of the resource pool leader Autonomous Database.

pub fn set_resource_pool_leader_id(self, input: Option<String>) -> Self

The unique identifier of the resource pool leader Autonomous Database.

pub fn get_resource_pool_leader_id(&self) -> &Option<String>

The unique identifier of the resource pool leader Autonomous Database.

pub fn compute_count(self, input: f32) -> Self

The compute capacity, in number of Elastic CPUs (ECPUs) or Oracle CPUs (OCPUs), assigned to the Autonomous Database.

pub fn set_compute_count(self, input: Option<f32>) -> Self

The compute capacity, in number of Elastic CPUs (ECPUs) or Oracle CPUs (OCPUs), assigned to the Autonomous Database.

pub fn get_compute_count(&self) -> &Option<f32>

The compute capacity, in number of Elastic CPUs (ECPUs) or Oracle CPUs (OCPUs), assigned to the Autonomous Database.

pub fn compute_model(self, input: ComputeModel) -> Self

The compute model of the Autonomous Database, either ECPU or OCPU.

pub fn set_compute_model(self, input: Option<ComputeModel>) -> Self

The compute model of the Autonomous Database, either ECPU or OCPU.

pub fn get_compute_model(&self) -> &Option<ComputeModel>

The compute model of the Autonomous Database, either ECPU or OCPU.

pub fn cpu_core_count(self, input: i32) -> Self

The number of CPU cores allocated to the Autonomous Database.

pub fn set_cpu_core_count(self, input: Option<i32>) -> Self

The number of CPU cores allocated to the Autonomous Database.

pub fn get_cpu_core_count(&self) -> &Option<i32>

The number of CPU cores allocated to the Autonomous Database.

pub fn memory_per_oracle_compute_unit_in_gbs(self, input: i32) -> Self

The amount of memory allocated per Oracle Compute Unit, in GB.

pub fn set_memory_per_oracle_compute_unit_in_gbs( self, input: Option<i32>, ) -> Self

The amount of memory allocated per Oracle Compute Unit, in GB.

pub fn get_memory_per_oracle_compute_unit_in_gbs(&self) -> &Option<i32>

The amount of memory allocated per Oracle Compute Unit, in GB.

pub fn provisionable_cpus(self, input: i32) -> Self

Appends an item to provisionable_cpus.

To override the contents of this collection use set_provisionable_cpus.

The list of CPU core counts that you can provision for the Autonomous Database.

pub fn set_provisionable_cpus(self, input: Option<Vec<i32>>) -> Self

The list of CPU core counts that you can provision for the Autonomous Database.

pub fn get_provisionable_cpus(&self) -> &Option<Vec<i32>>

The list of CPU core counts that you can provision for the Autonomous Database.

pub fn is_auto_scaling_enabled(self, input: bool) -> Self

Indicates whether automatic scaling of the compute resources is enabled for the Autonomous Database.

pub fn set_is_auto_scaling_enabled(self, input: Option<bool>) -> Self

Indicates whether automatic scaling of the compute resources is enabled for the Autonomous Database.

pub fn get_is_auto_scaling_enabled(&self) -> &Option<bool>

Indicates whether automatic scaling of the compute resources is enabled for the Autonomous Database.

pub fn data_storage_size_in_tbs(self, input: f64) -> Self

The size, in terabytes (TB), of the data volume allocated for the Autonomous Database.

pub fn set_data_storage_size_in_tbs(self, input: Option<f64>) -> Self

The size, in terabytes (TB), of the data volume allocated for the Autonomous Database.

pub fn get_data_storage_size_in_tbs(&self) -> &Option<f64>

The size, in terabytes (TB), of the data volume allocated for the Autonomous Database.

pub fn data_storage_size_in_gbs(self, input: i32) -> Self

The size, in gigabytes (GB), of the data volume allocated for the Autonomous Database.

pub fn set_data_storage_size_in_gbs(self, input: Option<i32>) -> Self

The size, in gigabytes (GB), of the data volume allocated for the Autonomous Database.

pub fn get_data_storage_size_in_gbs(&self) -> &Option<i32>

The size, in gigabytes (GB), of the data volume allocated for the Autonomous Database.

pub fn used_data_storage_size_in_tbs(self, input: f64) -> Self

The amount of data storage currently in use by the Autonomous Database, in TB.

pub fn set_used_data_storage_size_in_tbs(self, input: Option<f64>) -> Self

The amount of data storage currently in use by the Autonomous Database, in TB.

pub fn get_used_data_storage_size_in_tbs(&self) -> &Option<f64>

The amount of data storage currently in use by the Autonomous Database, in TB.

pub fn used_data_storage_size_in_gbs(self, input: i32) -> Self

The amount of data storage currently in use by the Autonomous Database, in GB.

pub fn set_used_data_storage_size_in_gbs(self, input: Option<i32>) -> Self

The amount of data storage currently in use by the Autonomous Database, in GB.

pub fn get_used_data_storage_size_in_gbs(&self) -> &Option<i32>

The amount of data storage currently in use by the Autonomous Database, in GB.

pub fn actual_used_data_storage_size_in_tbs(self, input: f64) -> Self

The actual amount of data storage currently in use by the Autonomous Database, in TB.

pub fn set_actual_used_data_storage_size_in_tbs( self, input: Option<f64>, ) -> Self

The actual amount of data storage currently in use by the Autonomous Database, in TB.

pub fn get_actual_used_data_storage_size_in_tbs(&self) -> &Option<f64>

The actual amount of data storage currently in use by the Autonomous Database, in TB.

pub fn allocated_storage_size_in_tbs(self, input: f64) -> Self

The amount of storage currently allocated to the Autonomous Database, in TB.

pub fn set_allocated_storage_size_in_tbs(self, input: Option<f64>) -> Self

The amount of storage currently allocated to the Autonomous Database, in TB.

pub fn get_allocated_storage_size_in_tbs(&self) -> &Option<f64>

The amount of storage currently allocated to the Autonomous Database, in TB.

pub fn in_memory_area_in_gbs(self, input: i32) -> Self

The size of the in-memory area of the Autonomous Database, in GB.

pub fn set_in_memory_area_in_gbs(self, input: Option<i32>) -> Self

The size of the in-memory area of the Autonomous Database, in GB.

pub fn get_in_memory_area_in_gbs(&self) -> &Option<i32>

The size of the in-memory area of the Autonomous Database, in GB.

pub fn is_auto_scaling_for_storage_enabled(self, input: bool) -> Self

Indicates whether automatic scaling of the storage is enabled for the Autonomous Database.

pub fn set_is_auto_scaling_for_storage_enabled( self, input: Option<bool>, ) -> Self

Indicates whether automatic scaling of the storage is enabled for the Autonomous Database.

pub fn get_is_auto_scaling_for_storage_enabled(&self) -> &Option<bool>

Indicates whether automatic scaling of the storage is enabled for the Autonomous Database.

pub fn odb_network_id(self, input: impl Into<String>) -> Self

The unique identifier of the ODB network associated with the Autonomous Database.

pub fn set_odb_network_id(self, input: Option<String>) -> Self

The unique identifier of the ODB network associated with the Autonomous Database.

pub fn get_odb_network_id(&self) -> &Option<String>

The unique identifier of the ODB network associated with the Autonomous Database.

pub fn odb_network_arn(self, input: impl Into<String>) -> Self

The Amazon Resource Name (ARN) of the ODB network associated with the Autonomous Database.

pub fn set_odb_network_arn(self, input: Option<String>) -> Self

The Amazon Resource Name (ARN) of the ODB network associated with the Autonomous Database.

pub fn get_odb_network_arn(&self) -> &Option<String>

The Amazon Resource Name (ARN) of the ODB network associated with the Autonomous Database.

pub fn private_endpoint(self, input: impl Into<String>) -> Self

The private endpoint for the Autonomous Database.

pub fn set_private_endpoint(self, input: Option<String>) -> Self

The private endpoint for the Autonomous Database.

pub fn get_private_endpoint(&self) -> &Option<String>

The private endpoint for the Autonomous Database.

pub fn private_endpoint_ip(self, input: impl Into<String>) -> Self

The private endpoint IP address for the Autonomous Database.

pub fn set_private_endpoint_ip(self, input: Option<String>) -> Self

The private endpoint IP address for the Autonomous Database.

pub fn get_private_endpoint_ip(&self) -> &Option<String>

The private endpoint IP address for the Autonomous Database.

pub fn private_endpoint_label(self, input: impl Into<String>) -> Self

The private endpoint label for the Autonomous Database.

pub fn set_private_endpoint_label(self, input: Option<String>) -> Self

The private endpoint label for the Autonomous Database.

pub fn get_private_endpoint_label(&self) -> &Option<String>

The private endpoint label for the Autonomous Database.

pub fn allowlisted_ips(self, input: impl Into<String>) -> Self

Appends an item to allowlisted_ips.

To override the contents of this collection use set_allowlisted_ips.

The list of IP addresses that are allowed to access the Autonomous Database.

pub fn set_allowlisted_ips(self, input: Option<Vec<String>>) -> Self

The list of IP addresses that are allowed to access the Autonomous Database.

pub fn get_allowlisted_ips(&self) -> &Option<Vec<String>>

The list of IP addresses that are allowed to access the Autonomous Database.

pub fn standby_allowlisted_ips(self, input: impl Into<String>) -> Self

Appends an item to standby_allowlisted_ips.

To override the contents of this collection use set_standby_allowlisted_ips.

The list of IP addresses that are allowed to access the standby Autonomous Database.

pub fn set_standby_allowlisted_ips(self, input: Option<Vec<String>>) -> Self

The list of IP addresses that are allowed to access the standby Autonomous Database.

pub fn get_standby_allowlisted_ips(&self) -> &Option<Vec<String>>

The list of IP addresses that are allowed to access the standby Autonomous Database.

pub fn standby_allowlisted_ips_source( self, input: StandbyAllowlistedIpsSource, ) -> Self

The source of the allowlisted IP addresses for the standby Autonomous Database.

pub fn set_standby_allowlisted_ips_source( self, input: Option<StandbyAllowlistedIpsSource>, ) -> Self

The source of the allowlisted IP addresses for the standby Autonomous Database.

pub fn get_standby_allowlisted_ips_source( &self, ) -> &Option<StandbyAllowlistedIpsSource>

The source of the allowlisted IP addresses for the standby Autonomous Database.

pub fn is_local_data_guard_enabled(self, input: bool) -> Self

Indicates whether local Oracle Data Guard is enabled for the Autonomous Database.

pub fn set_is_local_data_guard_enabled(self, input: Option<bool>) -> Self

Indicates whether local Oracle Data Guard is enabled for the Autonomous Database.

pub fn get_is_local_data_guard_enabled(&self) -> &Option<bool>

Indicates whether local Oracle Data Guard is enabled for the Autonomous Database.

pub fn is_remote_data_guard_enabled(self, input: bool) -> Self

Indicates whether remote Oracle Data Guard is enabled for the Autonomous Database.

pub fn set_is_remote_data_guard_enabled(self, input: Option<bool>) -> Self

Indicates whether remote Oracle Data Guard is enabled for the Autonomous Database.

pub fn get_is_remote_data_guard_enabled(&self) -> &Option<bool>

Indicates whether remote Oracle Data Guard is enabled for the Autonomous Database.

pub fn local_disaster_recovery_type(self, input: DisasterRecoveryType) -> Self

The type of local disaster recovery configured for the Autonomous Database.

pub fn set_local_disaster_recovery_type( self, input: Option<DisasterRecoveryType>, ) -> Self

The type of local disaster recovery configured for the Autonomous Database.

pub fn get_local_disaster_recovery_type(&self) -> &Option<DisasterRecoveryType>

The type of local disaster recovery configured for the Autonomous Database.

pub fn role(self, input: DataGuardRole) -> Self

The Oracle Data Guard role of the Autonomous Database.

pub fn set_role(self, input: Option<DataGuardRole>) -> Self

The Oracle Data Guard role of the Autonomous Database.

pub fn get_role(&self) -> &Option<DataGuardRole>

The Oracle Data Guard role of the Autonomous Database.

pub fn peer_db_ids(self, input: impl Into<String>) -> Self

Appends an item to peer_db_ids.

To override the contents of this collection use set_peer_db_ids.

The list of unique identifiers of the peer Autonomous Databases.

pub fn set_peer_db_ids(self, input: Option<Vec<String>>) -> Self

The list of unique identifiers of the peer Autonomous Databases.

pub fn get_peer_db_ids(&self) -> &Option<Vec<String>>

The list of unique identifiers of the peer Autonomous Databases.

pub fn failed_data_recovery_in_seconds(self, input: i32) -> Self

The amount of time, in seconds, that the data in the Autonomous Database is behind the data in the primary database.

pub fn set_failed_data_recovery_in_seconds(self, input: Option<i32>) -> Self

The amount of time, in seconds, that the data in the Autonomous Database is behind the data in the primary database.

pub fn get_failed_data_recovery_in_seconds(&self) -> &Option<i32>

The amount of time, in seconds, that the data in the Autonomous Database is behind the data in the primary database.

pub fn local_adg_auto_failover_max_data_loss_limit(self, input: i32) -> Self

The maximum data loss limit, in seconds, for automatic failover to the local Oracle Data Guard standby database.

pub fn set_local_adg_auto_failover_max_data_loss_limit( self, input: Option<i32>, ) -> Self

The maximum data loss limit, in seconds, for automatic failover to the local Oracle Data Guard standby database.

pub fn get_local_adg_auto_failover_max_data_loss_limit(&self) -> &Option<i32>

The maximum data loss limit, in seconds, for automatic failover to the local Oracle Data Guard standby database.

pub fn remote_disaster_recovery_configuration( self, input: DisasterRecoveryConfiguration, ) -> Self

The configuration of the remote disaster recovery for the Autonomous Database.

pub fn set_remote_disaster_recovery_configuration( self, input: Option<DisasterRecoveryConfiguration>, ) -> Self

The configuration of the remote disaster recovery for the Autonomous Database.

pub fn get_remote_disaster_recovery_configuration( &self, ) -> &Option<DisasterRecoveryConfiguration>

The configuration of the remote disaster recovery for the Autonomous Database.

pub fn is_refreshable_clone(self, input: bool) -> Self

Indicates whether the Autonomous Database is a refreshable clone.

pub fn set_is_refreshable_clone(self, input: Option<bool>) -> Self

Indicates whether the Autonomous Database is a refreshable clone.

pub fn get_is_refreshable_clone(&self) -> &Option<bool>

Indicates whether the Autonomous Database is a refreshable clone.

pub fn refreshable_mode(self, input: RefreshableMode) -> Self

The refresh mode of the refreshable clone Autonomous Database.

pub fn set_refreshable_mode(self, input: Option<RefreshableMode>) -> Self

The refresh mode of the refreshable clone Autonomous Database.

pub fn get_refreshable_mode(&self) -> &Option<RefreshableMode>

The refresh mode of the refreshable clone Autonomous Database.

pub fn refreshable_status(self, input: RefreshableStatus) -> Self

The refresh status of the refreshable clone Autonomous Database.

pub fn set_refreshable_status(self, input: Option<RefreshableStatus>) -> Self

The refresh status of the refreshable clone Autonomous Database.

pub fn get_refreshable_status(&self) -> &Option<RefreshableStatus>

The refresh status of the refreshable clone Autonomous Database.

pub fn auto_refresh_frequency_in_seconds(self, input: i32) -> Self

The frequency, in seconds, at which the refreshable clone Autonomous Database is automatically refreshed.

pub fn set_auto_refresh_frequency_in_seconds(self, input: Option<i32>) -> Self

The frequency, in seconds, at which the refreshable clone Autonomous Database is automatically refreshed.

pub fn get_auto_refresh_frequency_in_seconds(&self) -> &Option<i32>

The frequency, in seconds, at which the refreshable clone Autonomous Database is automatically refreshed.

pub fn auto_refresh_point_lag_in_seconds(self, input: i32) -> Self

The time lag, in seconds, between the refreshable clone and its source Autonomous Database.

pub fn set_auto_refresh_point_lag_in_seconds(self, input: Option<i32>) -> Self

The time lag, in seconds, between the refreshable clone and its source Autonomous Database.

pub fn get_auto_refresh_point_lag_in_seconds(&self) -> &Option<i32>

The time lag, in seconds, between the refreshable clone and its source Autonomous Database.

pub fn is_reconnect_clone_enabled(self, input: bool) -> Self

Indicates whether reconnecting the refreshable clone to its source Autonomous Database is enabled.

pub fn set_is_reconnect_clone_enabled(self, input: Option<bool>) -> Self

Indicates whether reconnecting the refreshable clone to its source Autonomous Database is enabled.

pub fn get_is_reconnect_clone_enabled(&self) -> &Option<bool>

Indicates whether reconnecting the refreshable clone to its source Autonomous Database is enabled.

pub fn clone_table_space_list(self, input: i32) -> Self

Appends an item to clone_table_space_list.

To override the contents of this collection use set_clone_table_space_list.

The list of tablespace identifiers to clone for the Autonomous Database.

pub fn set_clone_table_space_list(self, input: Option<Vec<i32>>) -> Self

The list of tablespace identifiers to clone for the Autonomous Database.

pub fn get_clone_table_space_list(&self) -> &Option<Vec<i32>>

The list of tablespace identifiers to clone for the Autonomous Database.

pub fn backup_retention_period_in_days(self, input: i32) -> Self

The retention period, in days, for automatic backups of the Autonomous Database.

pub fn set_backup_retention_period_in_days(self, input: Option<i32>) -> Self

The retention period, in days, for automatic backups of the Autonomous Database.

pub fn get_backup_retention_period_in_days(&self) -> &Option<i32>

The retention period, in days, for automatic backups of the Autonomous Database.

pub fn long_term_backup_schedule(self, input: LongTermBackupSchedule) -> Self

The long-term backup schedule for the Autonomous Database.

pub fn set_long_term_backup_schedule( self, input: Option<LongTermBackupSchedule>, ) -> Self

The long-term backup schedule for the Autonomous Database.

pub fn get_long_term_backup_schedule(&self) -> &Option<LongTermBackupSchedule>

The long-term backup schedule for the Autonomous Database.

pub fn is_backup_retention_locked(self, input: bool) -> Self

Indicates whether the backup retention period of the Autonomous Database is locked.

pub fn set_is_backup_retention_locked(self, input: Option<bool>) -> Self

Indicates whether the backup retention period of the Autonomous Database is locked.

pub fn get_is_backup_retention_locked(&self) -> &Option<bool>

Indicates whether the backup retention period of the Autonomous Database is locked.

pub fn total_backup_storage_size_in_gbs(self, input: f64) -> Self

The total amount of backup storage used by the Autonomous Database, in GB.

pub fn set_total_backup_storage_size_in_gbs(self, input: Option<f64>) -> Self

The total amount of backup storage used by the Autonomous Database, in GB.

pub fn get_total_backup_storage_size_in_gbs(&self) -> &Option<f64>

The total amount of backup storage used by the Autonomous Database, in GB.

pub fn resource_pool_summary(self, input: ResourcePoolSummary) -> Self

The configuration of the resource pool for the Autonomous Database.

pub fn set_resource_pool_summary( self, input: Option<ResourcePoolSummary>, ) -> Self

The configuration of the resource pool for the Autonomous Database.

pub fn get_resource_pool_summary(&self) -> &Option<ResourcePoolSummary>

The configuration of the resource pool for the Autonomous Database.

pub fn encryption_summary(self, input: EncryptionSummary) -> Self

The encryption configuration for the Autonomous Database.

pub fn set_encryption_summary(self, input: Option<EncryptionSummary>) -> Self

The encryption configuration for the Autonomous Database.

pub fn get_encryption_summary(&self) -> &Option<EncryptionSummary>

The encryption configuration for the Autonomous Database.

pub fn created_at(self, input: DateTime) -> Self

The date and time when the Autonomous Database was created.

pub fn set_created_at(self, input: Option<DateTime>) -> Self

The date and time when the Autonomous Database was created.

pub fn get_created_at(&self) -> &Option<DateTime>

The date and time when the Autonomous Database was created.

pub fn time_of_last_backup(self, input: DateTime) -> Self

The date and time of the last backup of the Autonomous Database.

pub fn set_time_of_last_backup(self, input: Option<DateTime>) -> Self

The date and time of the last backup of the Autonomous Database.

pub fn get_time_of_last_backup(&self) -> &Option<DateTime>

The date and time of the last backup of the Autonomous Database.

pub fn time_maintenance_begin(self, input: DateTime) -> Self

The date and time when the next maintenance of the Autonomous Database begins.

pub fn set_time_maintenance_begin(self, input: Option<DateTime>) -> Self

The date and time when the next maintenance of the Autonomous Database begins.

pub fn get_time_maintenance_begin(&self) -> &Option<DateTime>

The date and time when the next maintenance of the Autonomous Database begins.

pub fn time_maintenance_end(self, input: DateTime) -> Self

The date and time when the next maintenance of the Autonomous Database ends.

pub fn set_time_maintenance_end(self, input: Option<DateTime>) -> Self

The date and time when the next maintenance of the Autonomous Database ends.

pub fn get_time_maintenance_end(&self) -> &Option<DateTime>

The date and time when the next maintenance of the Autonomous Database ends.

pub fn time_local_data_guard_enabled(self, input: DateTime) -> Self

The date and time when local Oracle Data Guard was enabled for the Autonomous Database.

pub fn set_time_local_data_guard_enabled(self, input: Option<DateTime>) -> Self

The date and time when local Oracle Data Guard was enabled for the Autonomous Database.

pub fn get_time_local_data_guard_enabled(&self) -> &Option<DateTime>

The date and time when local Oracle Data Guard was enabled for the Autonomous Database.

pub fn time_data_guard_role_changed(self, input: DateTime) -> Self

The date and time when the Oracle Data Guard role of the Autonomous Database last changed.

pub fn set_time_data_guard_role_changed(self, input: Option<DateTime>) -> Self

The date and time when the Oracle Data Guard role of the Autonomous Database last changed.

pub fn get_time_data_guard_role_changed(&self) -> &Option<DateTime>

The date and time when the Oracle Data Guard role of the Autonomous Database last changed.

pub fn time_of_last_switchover(self, input: DateTime) -> Self

The date and time of the last switchover operation for the Autonomous Database.

pub fn set_time_of_last_switchover(self, input: Option<DateTime>) -> Self

The date and time of the last switchover operation for the Autonomous Database.

pub fn get_time_of_last_switchover(&self) -> &Option<DateTime>

The date and time of the last switchover operation for the Autonomous Database.

pub fn time_of_last_failover(self, input: DateTime) -> Self

The date and time of the last failover operation for the Autonomous Database.

pub fn set_time_of_last_failover(self, input: Option<DateTime>) -> Self

The date and time of the last failover operation for the Autonomous Database.

pub fn get_time_of_last_failover(&self) -> &Option<DateTime>

The date and time of the last failover operation for the Autonomous Database.

pub fn time_of_last_refresh(self, input: DateTime) -> Self

The date and time of the last refresh of the refreshable clone Autonomous Database.

pub fn set_time_of_last_refresh(self, input: Option<DateTime>) -> Self

The date and time of the last refresh of the refreshable clone Autonomous Database.

pub fn get_time_of_last_refresh(&self) -> &Option<DateTime>

The date and time of the last refresh of the refreshable clone Autonomous Database.

pub fn time_of_last_refresh_point(self, input: DateTime) -> Self

The date and time as of which the data in the refreshable clone Autonomous Database is current.

pub fn set_time_of_last_refresh_point(self, input: Option<DateTime>) -> Self

The date and time as of which the data in the refreshable clone Autonomous Database is current.

pub fn get_time_of_last_refresh_point(&self) -> &Option<DateTime>

The date and time as of which the data in the refreshable clone Autonomous Database is current.

pub fn time_of_next_refresh(self, input: DateTime) -> Self

The date and time of the next scheduled refresh of the refreshable clone Autonomous Database.

pub fn set_time_of_next_refresh(self, input: Option<DateTime>) -> Self

The date and time of the next scheduled refresh of the refreshable clone Autonomous Database.

pub fn get_time_of_next_refresh(&self) -> &Option<DateTime>

The date and time of the next scheduled refresh of the refreshable clone Autonomous Database.

pub fn time_of_auto_refresh_start(self, input: DateTime) -> Self

The date and time at which the automatic refresh of the refreshable clone Autonomous Database starts.

pub fn set_time_of_auto_refresh_start(self, input: Option<DateTime>) -> Self

The date and time at which the automatic refresh of the refreshable clone Autonomous Database starts.

pub fn get_time_of_auto_refresh_start(&self) -> &Option<DateTime>

The date and time at which the automatic refresh of the refreshable clone Autonomous Database starts.

pub fn time_deletion_of_free_autonomous_database(self, input: DateTime) -> Self

The date and time when the inactive Always Free Autonomous Database is scheduled to be automatically deleted.

pub fn set_time_deletion_of_free_autonomous_database( self, input: Option<DateTime>, ) -> Self

The date and time when the inactive Always Free Autonomous Database is scheduled to be automatically deleted.

pub fn get_time_deletion_of_free_autonomous_database(&self) -> &Option<DateTime>

The date and time when the inactive Always Free Autonomous Database is scheduled to be automatically deleted.

pub fn time_reclamation_of_free_autonomous_database( self, input: DateTime, ) -> Self

The date and time when the Always Free Autonomous Database is scheduled to be stopped because of inactivity.

pub fn set_time_reclamation_of_free_autonomous_database( self, input: Option<DateTime>, ) -> Self

The date and time when the Always Free Autonomous Database is scheduled to be stopped because of inactivity.

pub fn get_time_reclamation_of_free_autonomous_database( &self, ) -> &Option<DateTime>

The date and time when the Always Free Autonomous Database is scheduled to be stopped because of inactivity.

pub fn time_disaster_recovery_role_changed(self, input: DateTime) -> Self

The date and time when the disaster recovery role of the Autonomous Database last changed.

pub fn set_time_disaster_recovery_role_changed( self, input: Option<DateTime>, ) -> Self

The date and time when the disaster recovery role of the Autonomous Database last changed.

pub fn get_time_disaster_recovery_role_changed(&self) -> &Option<DateTime>

The date and time when the disaster recovery role of the Autonomous Database last changed.

pub fn time_until_reconnect_clone_enabled(self, input: DateTime) -> Self

The date and time until which reconnecting the refreshable clone to its source Autonomous Database is allowed.

pub fn set_time_until_reconnect_clone_enabled( self, input: Option<DateTime>, ) -> Self

The date and time until which reconnecting the refreshable clone to its source Autonomous Database is allowed.

pub fn get_time_until_reconnect_clone_enabled(&self) -> &Option<DateTime>

The date and time until which reconnecting the refreshable clone to its source Autonomous Database is allowed.

pub fn next_long_term_backup_time_stamp(self, input: DateTime) -> Self

The date and time of the next scheduled long-term backup of the Autonomous Database.

pub fn set_next_long_term_backup_time_stamp( self, input: Option<DateTime>, ) -> Self

The date and time of the next scheduled long-term backup of the Autonomous Database.

pub fn get_next_long_term_backup_time_stamp(&self) -> &Option<DateTime>

The date and time of the next scheduled long-term backup of the Autonomous Database.

pub fn time_undeleted(self, input: DateTime) -> Self

The date and time when the Autonomous Database was restored after deletion.

pub fn set_time_undeleted(self, input: Option<DateTime>) -> Self

The date and time when the Autonomous Database was restored after deletion.

pub fn get_time_undeleted(&self) -> &Option<DateTime>

The date and time when the Autonomous Database was restored after deletion.

pub fn admin_password_source_summary( self, input: AdminPasswordSourceSummary, ) -> Self

The summary of the admin password source configuration for the Autonomous Database.

pub fn set_admin_password_source_summary( self, input: Option<AdminPasswordSourceSummary>, ) -> Self

The summary of the admin password source configuration for the Autonomous Database.

pub fn get_admin_password_source_summary( &self, ) -> &Option<AdminPasswordSourceSummary>

The summary of the admin password source configuration for the Autonomous Database.

pub fn build(self) -> AutonomousDatabase

Consumes the builder and constructs a AutonomousDatabase.