#[non_exhaustive]pub struct AutonomousDatabaseConnectionStringsBuilder { /* private fields */ }Expand description
A builder for AutonomousDatabaseConnectionStrings.
Implementations
Sourceimpl AutonomousDatabaseConnectionStringsBuilder
impl AutonomousDatabaseConnectionStringsBuilder
Sourcepub fn all_connection_strings(
self,
k: impl Into<String>,
v: impl Into<String>,
) -> Self
pub fn all_connection_strings( self, k: impl Into<String>, v: impl Into<String>, ) -> Self
Adds a key-value pair to all_connection_strings.
To override the contents of this collection use set_all_connection_strings.
The list of all connection strings that you can use to connect to the Autonomous Database.
Sourcepub fn set_all_connection_strings(
self,
input: Option<HashMap<String, String>>,
) -> Self
pub fn set_all_connection_strings( self, input: Option<HashMap<String, String>>, ) -> Self
The list of all connection strings that you can use to connect to the Autonomous Database.
Sourcepub fn get_all_connection_strings(&self) -> &Option<HashMap<String, String>>
pub fn get_all_connection_strings(&self) -> &Option<HashMap<String, String>>
The list of all connection strings that you can use to connect to the Autonomous Database.
Sourcepub fn dedicated(self, input: impl Into<String>) -> Self
pub fn dedicated(self, input: impl Into<String>) -> Self
The connection string for connecting to the Autonomous Database with a dedicated service.
Sourcepub fn set_dedicated(self, input: Option<String>) -> Self
pub fn set_dedicated(self, input: Option<String>) -> Self
The connection string for connecting to the Autonomous Database with a dedicated service.
Sourcepub fn get_dedicated(&self) -> &Option<String>
pub fn get_dedicated(&self) -> &Option<String>
The connection string for connecting to the Autonomous Database with a dedicated service.
Sourcepub fn high(self, input: impl Into<String>) -> Self
pub fn high(self, input: impl Into<String>) -> Self
The connection string for the high-priority database service.
Sourcepub fn set_high(self, input: Option<String>) -> Self
pub fn set_high(self, input: Option<String>) -> Self
The connection string for the high-priority database service.
Sourcepub fn get_high(&self) -> &Option<String>
pub fn get_high(&self) -> &Option<String>
The connection string for the high-priority database service.
Sourcepub fn medium(self, input: impl Into<String>) -> Self
pub fn medium(self, input: impl Into<String>) -> Self
The connection string for the medium-priority database service.
Sourcepub fn set_medium(self, input: Option<String>) -> Self
pub fn set_medium(self, input: Option<String>) -> Self
The connection string for the medium-priority database service.
Sourcepub fn get_medium(&self) -> &Option<String>
pub fn get_medium(&self) -> &Option<String>
The connection string for the medium-priority database service.
Sourcepub fn low(self, input: impl Into<String>) -> Self
pub fn low(self, input: impl Into<String>) -> Self
The connection string for the low-priority database service.
Sourcepub fn set_low(self, input: Option<String>) -> Self
pub fn set_low(self, input: Option<String>) -> Self
The connection string for the low-priority database service.
Sourcepub fn get_low(&self) -> &Option<String>
pub fn get_low(&self) -> &Option<String>
The connection string for the low-priority database service.
Sourcepub fn profiles(self, input: DatabaseConnectionStringProfile) -> Self
pub fn profiles(self, input: DatabaseConnectionStringProfile) -> Self
Appends an item to profiles.
To override the contents of this collection use set_profiles.
The list of connection string profiles for the Autonomous Database.
Sourcepub fn set_profiles(
self,
input: Option<Vec<DatabaseConnectionStringProfile>>,
) -> Self
pub fn set_profiles( self, input: Option<Vec<DatabaseConnectionStringProfile>>, ) -> Self
The list of connection string profiles for the Autonomous Database.
Sourcepub fn get_profiles(&self) -> &Option<Vec<DatabaseConnectionStringProfile>>
pub fn get_profiles(&self) -> &Option<Vec<DatabaseConnectionStringProfile>>
The list of connection string profiles for the Autonomous Database.
Sourcepub fn build(self) -> AutonomousDatabaseConnectionStrings
pub fn build(self) -> AutonomousDatabaseConnectionStrings
Consumes the builder and constructs a AutonomousDatabaseConnectionStrings.