#[non_exhaustive]pub struct AutonomousDatabaseConnectionUrlsBuilder { /* private fields */ }Expand description
A builder for AutonomousDatabaseConnectionUrls.
Implementations
Sourceimpl AutonomousDatabaseConnectionUrlsBuilder
impl AutonomousDatabaseConnectionUrlsBuilder
Sourcepub fn apex_url(self, input: impl Into<String>) -> Self
pub fn apex_url(self, input: impl Into<String>) -> Self
The URL for accessing Oracle Application Express (APEX) for the Autonomous Database.
Sourcepub fn set_apex_url(self, input: Option<String>) -> Self
pub fn set_apex_url(self, input: Option<String>) -> Self
The URL for accessing Oracle Application Express (APEX) for the Autonomous Database.
Sourcepub fn get_apex_url(&self) -> &Option<String>
pub fn get_apex_url(&self) -> &Option<String>
The URL for accessing Oracle Application Express (APEX) for the Autonomous Database.
Sourcepub fn database_transforms_url(self, input: impl Into<String>) -> Self
pub fn database_transforms_url(self, input: impl Into<String>) -> Self
The URL for accessing Oracle Database Transforms for the Autonomous Database.
Sourcepub fn set_database_transforms_url(self, input: Option<String>) -> Self
pub fn set_database_transforms_url(self, input: Option<String>) -> Self
The URL for accessing Oracle Database Transforms for the Autonomous Database.
Sourcepub fn get_database_transforms_url(&self) -> &Option<String>
pub fn get_database_transforms_url(&self) -> &Option<String>
The URL for accessing Oracle Database Transforms for the Autonomous Database.
Sourcepub fn graph_studio_url(self, input: impl Into<String>) -> Self
pub fn graph_studio_url(self, input: impl Into<String>) -> Self
The URL for accessing Oracle Graph Studio for the Autonomous Database.
Sourcepub fn set_graph_studio_url(self, input: Option<String>) -> Self
pub fn set_graph_studio_url(self, input: Option<String>) -> Self
The URL for accessing Oracle Graph Studio for the Autonomous Database.
Sourcepub fn get_graph_studio_url(&self) -> &Option<String>
pub fn get_graph_studio_url(&self) -> &Option<String>
The URL for accessing Oracle Graph Studio for the Autonomous Database.
Sourcepub fn machine_learning_notebook_url(self, input: impl Into<String>) -> Self
pub fn machine_learning_notebook_url(self, input: impl Into<String>) -> Self
The URL for accessing the Oracle Machine Learning notebook for the Autonomous Database.
Sourcepub fn set_machine_learning_notebook_url(self, input: Option<String>) -> Self
pub fn set_machine_learning_notebook_url(self, input: Option<String>) -> Self
The URL for accessing the Oracle Machine Learning notebook for the Autonomous Database.
Sourcepub fn get_machine_learning_notebook_url(&self) -> &Option<String>
pub fn get_machine_learning_notebook_url(&self) -> &Option<String>
The URL for accessing the Oracle Machine Learning notebook for the Autonomous Database.
Sourcepub fn machine_learning_user_management_url(
self,
input: impl Into<String>,
) -> Self
pub fn machine_learning_user_management_url( self, input: impl Into<String>, ) -> Self
The URL for accessing Oracle Machine Learning user management for the Autonomous Database.
Sourcepub fn set_machine_learning_user_management_url(
self,
input: Option<String>,
) -> Self
pub fn set_machine_learning_user_management_url( self, input: Option<String>, ) -> Self
The URL for accessing Oracle Machine Learning user management for the Autonomous Database.
Sourcepub fn get_machine_learning_user_management_url(&self) -> &Option<String>
pub fn get_machine_learning_user_management_url(&self) -> &Option<String>
The URL for accessing Oracle Machine Learning user management for the Autonomous Database.
Sourcepub fn mongo_db_url(self, input: impl Into<String>) -> Self
pub fn mongo_db_url(self, input: impl Into<String>) -> Self
The URL for accessing the MongoDB API for the Autonomous Database.
Sourcepub fn set_mongo_db_url(self, input: Option<String>) -> Self
pub fn set_mongo_db_url(self, input: Option<String>) -> Self
The URL for accessing the MongoDB API for the Autonomous Database.
Sourcepub fn get_mongo_db_url(&self) -> &Option<String>
pub fn get_mongo_db_url(&self) -> &Option<String>
The URL for accessing the MongoDB API for the Autonomous Database.
Sourcepub fn ords_url(self, input: impl Into<String>) -> Self
pub fn ords_url(self, input: impl Into<String>) -> Self
The URL for accessing Oracle REST Data Services (ORDS) for the Autonomous Database.
Sourcepub fn set_ords_url(self, input: Option<String>) -> Self
pub fn set_ords_url(self, input: Option<String>) -> Self
The URL for accessing Oracle REST Data Services (ORDS) for the Autonomous Database.
Sourcepub fn get_ords_url(&self) -> &Option<String>
pub fn get_ords_url(&self) -> &Option<String>
The URL for accessing Oracle REST Data Services (ORDS) for the Autonomous Database.
Sourcepub fn spatial_studio_url(self, input: impl Into<String>) -> Self
pub fn spatial_studio_url(self, input: impl Into<String>) -> Self
The URL for accessing Oracle Spatial Studio for the Autonomous Database.
Sourcepub fn set_spatial_studio_url(self, input: Option<String>) -> Self
pub fn set_spatial_studio_url(self, input: Option<String>) -> Self
The URL for accessing Oracle Spatial Studio for the Autonomous Database.
Sourcepub fn get_spatial_studio_url(&self) -> &Option<String>
pub fn get_spatial_studio_url(&self) -> &Option<String>
The URL for accessing Oracle Spatial Studio for the Autonomous Database.
Sourcepub fn sql_dev_web_url(self, input: impl Into<String>) -> Self
pub fn sql_dev_web_url(self, input: impl Into<String>) -> Self
The URL for accessing Oracle SQL Developer Web for the Autonomous Database.
Sourcepub fn set_sql_dev_web_url(self, input: Option<String>) -> Self
pub fn set_sql_dev_web_url(self, input: Option<String>) -> Self
The URL for accessing Oracle SQL Developer Web for the Autonomous Database.
Sourcepub fn get_sql_dev_web_url(&self) -> &Option<String>
pub fn get_sql_dev_web_url(&self) -> &Option<String>
The URL for accessing Oracle SQL Developer Web for the Autonomous Database.
Sourcepub fn build(self) -> AutonomousDatabaseConnectionUrls
pub fn build(self) -> AutonomousDatabaseConnectionUrls
Consumes the builder and constructs a AutonomousDatabaseConnectionUrls.