#[non_exhaustive]pub struct DatabaseConnectionStringProfileBuilder { /* private fields */ }Expand description
A builder for DatabaseConnectionStringProfile.
Implementations
Sourceimpl DatabaseConnectionStringProfileBuilder
impl DatabaseConnectionStringProfileBuilder
Sourcepub fn consumer_group(self, input: impl Into<String>) -> Self
pub fn consumer_group(self, input: impl Into<String>) -> Self
The consumer group associated with the connection string profile.
Sourcepub fn set_consumer_group(self, input: Option<String>) -> Self
pub fn set_consumer_group(self, input: Option<String>) -> Self
The consumer group associated with the connection string profile.
Sourcepub fn get_consumer_group(&self) -> &Option<String>
pub fn get_consumer_group(&self) -> &Option<String>
The consumer group associated with the connection string profile.
Sourcepub fn display_name(self, input: impl Into<String>) -> Self
pub fn display_name(self, input: impl Into<String>) -> Self
The user-friendly name of the connection string profile.
Sourcepub fn set_display_name(self, input: Option<String>) -> Self
pub fn set_display_name(self, input: Option<String>) -> Self
The user-friendly name of the connection string profile.
Sourcepub fn get_display_name(&self) -> &Option<String>
pub fn get_display_name(&self) -> &Option<String>
The user-friendly name of the connection string profile.
Sourcepub fn host_format(self, input: impl Into<String>) -> Self
pub fn host_format(self, input: impl Into<String>) -> Self
The host name format used in the connection string.
Sourcepub fn set_host_format(self, input: Option<String>) -> Self
pub fn set_host_format(self, input: Option<String>) -> Self
The host name format used in the connection string.
Sourcepub fn get_host_format(&self) -> &Option<String>
pub fn get_host_format(&self) -> &Option<String>
The host name format used in the connection string.
Sourcepub fn is_regional(self, input: bool) -> Self
pub fn is_regional(self, input: bool) -> Self
Indicates whether the connection string profile is regional.
Sourcepub fn set_is_regional(self, input: Option<bool>) -> Self
pub fn set_is_regional(self, input: Option<bool>) -> Self
Indicates whether the connection string profile is regional.
Sourcepub fn get_is_regional(&self) -> &Option<bool>
pub fn get_is_regional(&self) -> &Option<bool>
Indicates whether the connection string profile is regional.
Sourcepub fn protocol(self, input: impl Into<String>) -> Self
pub fn protocol(self, input: impl Into<String>) -> Self
The protocol used by the connection string profile.
Sourcepub fn set_protocol(self, input: Option<String>) -> Self
pub fn set_protocol(self, input: Option<String>) -> Self
The protocol used by the connection string profile.
Sourcepub fn get_protocol(&self) -> &Option<String>
pub fn get_protocol(&self) -> &Option<String>
The protocol used by the connection string profile.
Sourcepub fn session_mode(self, input: impl Into<String>) -> Self
pub fn session_mode(self, input: impl Into<String>) -> Self
The session mode of the connection string profile.
Sourcepub fn set_session_mode(self, input: Option<String>) -> Self
pub fn set_session_mode(self, input: Option<String>) -> Self
The session mode of the connection string profile.
Sourcepub fn get_session_mode(&self) -> &Option<String>
pub fn get_session_mode(&self) -> &Option<String>
The session mode of the connection string profile.
Sourcepub fn syntax_format(self, input: impl Into<String>) -> Self
pub fn syntax_format(self, input: impl Into<String>) -> Self
The syntax format of the connection string profile.
Sourcepub fn set_syntax_format(self, input: Option<String>) -> Self
pub fn set_syntax_format(self, input: Option<String>) -> Self
The syntax format of the connection string profile.
Sourcepub fn get_syntax_format(&self) -> &Option<String>
pub fn get_syntax_format(&self) -> &Option<String>
The syntax format of the connection string profile.
Sourcepub fn tls_authentication(self, input: impl Into<String>) -> Self
pub fn tls_authentication(self, input: impl Into<String>) -> Self
The TLS authentication method used by the connection string profile.
Sourcepub fn set_tls_authentication(self, input: Option<String>) -> Self
pub fn set_tls_authentication(self, input: Option<String>) -> Self
The TLS authentication method used by the connection string profile.
Sourcepub fn get_tls_authentication(&self) -> &Option<String>
pub fn get_tls_authentication(&self) -> &Option<String>
The TLS authentication method used by the connection string profile.
Sourcepub fn value(self, input: impl Into<String>) -> Self
pub fn value(self, input: impl Into<String>) -> Self
The connection string value of the profile.
Sourcepub fn set_value(self, input: Option<String>) -> Self
pub fn set_value(self, input: Option<String>) -> Self
The connection string value of the profile.
Sourcepub fn build(self) -> DatabaseConnectionStringProfile
pub fn build(self) -> DatabaseConnectionStringProfile
Consumes the builder and constructs a DatabaseConnectionStringProfile.