#[non_exhaustive]pub struct OkvEncryptionKeyConfigurationBuilder { /* private fields */ }Expand description
A builder for OkvEncryptionKeyConfiguration.
Implementations
Sourceimpl OkvEncryptionKeyConfigurationBuilder
impl OkvEncryptionKeyConfigurationBuilder
Sourcepub fn certificate_directory_name(self, input: impl Into<String>) -> Self
pub fn certificate_directory_name(self, input: impl Into<String>) -> Self
The name of the directory that contains the Oracle Key Vault (OKV) certificate.
This field is required.Sourcepub fn set_certificate_directory_name(self, input: Option<String>) -> Self
pub fn set_certificate_directory_name(self, input: Option<String>) -> Self
The name of the directory that contains the Oracle Key Vault (OKV) certificate.
Sourcepub fn get_certificate_directory_name(&self) -> &Option<String>
pub fn get_certificate_directory_name(&self) -> &Option<String>
The name of the directory that contains the Oracle Key Vault (OKV) certificate.
Sourcepub fn certificate_id(self, input: impl Into<String>) -> Self
pub fn certificate_id(self, input: impl Into<String>) -> Self
The identifier of the Oracle Key Vault (OKV) certificate.
Sourcepub fn set_certificate_id(self, input: Option<String>) -> Self
pub fn set_certificate_id(self, input: Option<String>) -> Self
The identifier of the Oracle Key Vault (OKV) certificate.
Sourcepub fn get_certificate_id(&self) -> &Option<String>
pub fn get_certificate_id(&self) -> &Option<String>
The identifier of the Oracle Key Vault (OKV) certificate.
Sourcepub fn directory_name(self, input: impl Into<String>) -> Self
pub fn directory_name(self, input: impl Into<String>) -> Self
The name of the directory where the Oracle Key Vault (OKV) configuration is stored.
This field is required.Sourcepub fn set_directory_name(self, input: Option<String>) -> Self
pub fn set_directory_name(self, input: Option<String>) -> Self
The name of the directory where the Oracle Key Vault (OKV) configuration is stored.
Sourcepub fn get_directory_name(&self) -> &Option<String>
pub fn get_directory_name(&self) -> &Option<String>
The name of the directory where the Oracle Key Vault (OKV) configuration is stored.
Sourcepub fn okv_kms_key(self, input: impl Into<String>) -> Self
pub fn okv_kms_key(self, input: impl Into<String>) -> Self
The identifier of the Oracle Key Vault (OKV) key to use for encryption.
This field is required.Sourcepub fn set_okv_kms_key(self, input: Option<String>) -> Self
pub fn set_okv_kms_key(self, input: Option<String>) -> Self
The identifier of the Oracle Key Vault (OKV) key to use for encryption.
Sourcepub fn get_okv_kms_key(&self) -> &Option<String>
pub fn get_okv_kms_key(&self) -> &Option<String>
The identifier of the Oracle Key Vault (OKV) key to use for encryption.
Sourcepub fn okv_uri(self, input: impl Into<String>) -> Self
pub fn okv_uri(self, input: impl Into<String>) -> Self
The URI of the Oracle Key Vault (OKV) server.
This field is required.Sourcepub fn set_okv_uri(self, input: Option<String>) -> Self
pub fn set_okv_uri(self, input: Option<String>) -> Self
The URI of the Oracle Key Vault (OKV) server.
Sourcepub fn get_okv_uri(&self) -> &Option<String>
pub fn get_okv_uri(&self) -> &Option<String>
The URI of the Oracle Key Vault (OKV) server.
Sourcepub fn build(self) -> Result<OkvEncryptionKeyConfiguration, BuildError>
pub fn build(self) -> Result<OkvEncryptionKeyConfiguration, BuildError>
Consumes the builder and constructs a OkvEncryptionKeyConfiguration.
This method will fail if any of the following fields are not set: