#[non_exhaustive]pub enum EncryptionKeyConfiguration {
AwsEncryptionKey(AwsEncryptionKeyConfiguration),
OciEncryptionKey(OciEncryptionKeyConfiguration),
OkvEncryptionKey(OkvEncryptionKeyConfiguration),
#[non_exhaustive] Unknown,
}Expand description
The configuration of the encryption key used for an Autonomous Database. This is a union, so only one of the following members can be specified.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AwsEncryptionKey(AwsEncryptionKeyConfiguration)
The configuration of the Amazon Web Services Key Management Service (KMS) encryption key.
OciEncryptionKey(OciEncryptionKeyConfiguration)
The configuration of the Oracle Cloud Infrastructure (OCI) Vault encryption key.
OkvEncryptionKey(OkvEncryptionKeyConfiguration)
The configuration of the Oracle Key Vault (OKV) encryption key.
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl EncryptionKeyConfiguration
impl EncryptionKeyConfiguration
Sourcepub fn as_aws_encryption_key(
&self,
) -> Result<&AwsEncryptionKeyConfiguration, &Self>
pub fn as_aws_encryption_key( &self, ) -> Result<&AwsEncryptionKeyConfiguration, &Self>
Tries to convert the enum instance into AwsEncryptionKey, extracting the inner AwsEncryptionKeyConfiguration.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_aws_encryption_key(&self) -> bool
pub fn is_aws_encryption_key(&self) -> bool
Returns true if this is a AwsEncryptionKey.
Sourcepub fn as_oci_encryption_key(
&self,
) -> Result<&OciEncryptionKeyConfiguration, &Self>
pub fn as_oci_encryption_key( &self, ) -> Result<&OciEncryptionKeyConfiguration, &Self>
Tries to convert the enum instance into OciEncryptionKey, extracting the inner OciEncryptionKeyConfiguration.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_oci_encryption_key(&self) -> bool
pub fn is_oci_encryption_key(&self) -> bool
Returns true if this is a OciEncryptionKey.
Sourcepub fn as_okv_encryption_key(
&self,
) -> Result<&OkvEncryptionKeyConfiguration, &Self>
pub fn as_okv_encryption_key( &self, ) -> Result<&OkvEncryptionKeyConfiguration, &Self>
Tries to convert the enum instance into OkvEncryptionKey, extracting the inner OkvEncryptionKeyConfiguration.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_okv_encryption_key(&self) -> bool
pub fn is_okv_encryption_key(&self) -> bool
Returns true if this is a OkvEncryptionKey.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.