#[non_exhaustive]pub enum SourceConfiguration {
CloneToRefreshable(CloneToRefreshableConfiguration),
CrossRegionDataGuard(CrossRegionDataGuardConfiguration),
CrossRegionDisasterRecovery(CrossRegionDisasterRecoveryConfiguration),
DatabaseClone(DatabaseCloneConfiguration),
PointInTimeRestore(PointInTimeRestoreConfiguration),
RestoreFromBackup(RestoreFromBackupConfiguration),
#[non_exhaustive] Unknown,
}Expand description
The configuration details for the source used to create an Autonomous Database. This is a union, so only one of the following members can be specified.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CloneToRefreshable(CloneToRefreshableConfiguration)
The configuration for creating the Autonomous Database as a refreshable clone.
CrossRegionDataGuard(CrossRegionDataGuardConfiguration)
The configuration for creating the Autonomous Database as a cross-Region Oracle Data Guard peer.
CrossRegionDisasterRecovery(CrossRegionDisasterRecoveryConfiguration)
The configuration for creating the Autonomous Database as a cross-Region disaster recovery peer.
DatabaseClone(DatabaseCloneConfiguration)
The configuration for creating the Autonomous Database as a clone of an existing database.
PointInTimeRestore(PointInTimeRestoreConfiguration)
The configuration for creating the Autonomous Database by restoring to a point in time.
RestoreFromBackup(RestoreFromBackupConfiguration)
The configuration for creating the Autonomous Database by restoring from a backup.
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl SourceConfiguration
impl SourceConfiguration
Sourcepub fn as_clone_to_refreshable(
&self,
) -> Result<&CloneToRefreshableConfiguration, &Self>
pub fn as_clone_to_refreshable( &self, ) -> Result<&CloneToRefreshableConfiguration, &Self>
Tries to convert the enum instance into CloneToRefreshable, extracting the inner CloneToRefreshableConfiguration.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_clone_to_refreshable(&self) -> bool
pub fn is_clone_to_refreshable(&self) -> bool
Returns true if this is a CloneToRefreshable.
Sourcepub fn as_cross_region_data_guard(
&self,
) -> Result<&CrossRegionDataGuardConfiguration, &Self>
pub fn as_cross_region_data_guard( &self, ) -> Result<&CrossRegionDataGuardConfiguration, &Self>
Tries to convert the enum instance into CrossRegionDataGuard, extracting the inner CrossRegionDataGuardConfiguration.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_cross_region_data_guard(&self) -> bool
pub fn is_cross_region_data_guard(&self) -> bool
Returns true if this is a CrossRegionDataGuard.
Sourcepub fn as_cross_region_disaster_recovery(
&self,
) -> Result<&CrossRegionDisasterRecoveryConfiguration, &Self>
pub fn as_cross_region_disaster_recovery( &self, ) -> Result<&CrossRegionDisasterRecoveryConfiguration, &Self>
Tries to convert the enum instance into CrossRegionDisasterRecovery, extracting the inner CrossRegionDisasterRecoveryConfiguration.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_cross_region_disaster_recovery(&self) -> bool
pub fn is_cross_region_disaster_recovery(&self) -> bool
Returns true if this is a CrossRegionDisasterRecovery.
Sourcepub fn as_database_clone(&self) -> Result<&DatabaseCloneConfiguration, &Self>
pub fn as_database_clone(&self) -> Result<&DatabaseCloneConfiguration, &Self>
Tries to convert the enum instance into DatabaseClone, extracting the inner DatabaseCloneConfiguration.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_database_clone(&self) -> bool
pub fn is_database_clone(&self) -> bool
Returns true if this is a DatabaseClone.
Sourcepub fn as_point_in_time_restore(
&self,
) -> Result<&PointInTimeRestoreConfiguration, &Self>
pub fn as_point_in_time_restore( &self, ) -> Result<&PointInTimeRestoreConfiguration, &Self>
Tries to convert the enum instance into PointInTimeRestore, extracting the inner PointInTimeRestoreConfiguration.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_point_in_time_restore(&self) -> bool
pub fn is_point_in_time_restore(&self) -> bool
Returns true if this is a PointInTimeRestore.
Sourcepub fn as_restore_from_backup(
&self,
) -> Result<&RestoreFromBackupConfiguration, &Self>
pub fn as_restore_from_backup( &self, ) -> Result<&RestoreFromBackupConfiguration, &Self>
Tries to convert the enum instance into RestoreFromBackup, extracting the inner RestoreFromBackupConfiguration.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_restore_from_backup(&self) -> bool
pub fn is_restore_from_backup(&self) -> bool
Returns true if this is a RestoreFromBackup.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.