#[non_exhaustive]pub struct AdminPasswordSourceSummary {
pub admin_password_source: Option<AdminPasswordSource>,
pub admin_password_source_configuration: Option<AdminPasswordSourceConfiguration>,
}Expand description
A summary of the admin password source configuration for an Autonomous Database.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.admin_password_source: Option<AdminPasswordSource>The source of the admin password for the Autonomous Database.
admin_password_source_configuration: Option<AdminPasswordSourceConfiguration>The configuration of the admin password source for the Autonomous Database.
Implementations
Sourceimpl AdminPasswordSourceSummary
impl AdminPasswordSourceSummary
Sourcepub fn admin_password_source(&self) -> Option<&AdminPasswordSource>
pub fn admin_password_source(&self) -> Option<&AdminPasswordSource>
The source of the admin password for the Autonomous Database.
Sourcepub fn admin_password_source_configuration(
&self,
) -> Option<&AdminPasswordSourceConfiguration>
pub fn admin_password_source_configuration( &self, ) -> Option<&AdminPasswordSourceConfiguration>
The configuration of the admin password source for the Autonomous Database.
Sourceimpl AdminPasswordSourceSummary
impl AdminPasswordSourceSummary
Sourcepub fn builder() -> AdminPasswordSourceSummaryBuilder
pub fn builder() -> AdminPasswordSourceSummaryBuilder
Creates a new builder-style object to manufacture AdminPasswordSourceSummary.