AutonomousDatabaseBackupSummary

Struct AutonomousDatabaseBackupSummary 

#[non_exhaustive]
pub struct AutonomousDatabaseBackupSummary {
Show 15 fields pub autonomous_database_backup_id: Option<String>, pub autonomous_database_backup_arn: Option<String>, pub autonomous_database_id: Option<String>, pub ocid: Option<String>, pub display_name: Option<String>, pub db_version: Option<String>, pub status: Option<AutonomousDatabaseBackupStatus>, pub status_reason: Option<String>, pub is_automatic: Option<bool>, pub retention_period_in_days: Option<i32>, pub size_in_tbs: Option<f64>, pub time_available_till: Option<DateTime>, pub time_started: Option<DateTime>, pub time_ended: Option<DateTime>, pub type: Option<AutonomousDatabaseBackupType>,
}
A summary of an Autonomous Database backup.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
autonomous_database_backup_id: Option<String>

The unique identifier of the Autonomous Database backup.

autonomous_database_backup_arn: Option<String>

The Amazon Resource Name (ARN) of the Autonomous Database backup.

autonomous_database_id: Option<String>

The unique identifier of the Autonomous Database that the backup was created from.

ocid: Option<String>

The Oracle Cloud Identifier (OCID) of the Autonomous Database backup.

display_name: Option<String>

The user-friendly name of the Autonomous Database backup.

db_version: Option<String>

The Oracle Database software version of the Autonomous Database backup.

status: Option<AutonomousDatabaseBackupStatus>

The current status of the Autonomous Database backup.

status_reason: Option<String>

Additional information about the current status of the Autonomous Database backup, if applicable.

is_automatic: Option<bool>

Indicates whether the backup was created automatically.

retention_period_in_days: Option<i32>

The retention period, in days, for the Autonomous Database backup.

size_in_tbs: Option<f64>

The size of the Autonomous Database backup, in terabytes (TB).

time_available_till: Option<DateTime>

The date and time until which the Autonomous Database backup is available for restore.

time_started: Option<DateTime>

The date and time when the Autonomous Database backup started.

time_ended: Option<DateTime>

The date and time when the Autonomous Database backup ended.

type: Option<AutonomousDatabaseBackupType>

The type of the Autonomous Database backup.

Implementations

Source

impl AutonomousDatabaseBackupSummary

pub fn autonomous_database_backup_id(&self) -> Option<&str>

The unique identifier of the Autonomous Database backup.

pub fn autonomous_database_backup_arn(&self) -> Option<&str>

The Amazon Resource Name (ARN) of the Autonomous Database backup.

pub fn autonomous_database_id(&self) -> Option<&str>

The unique identifier of the Autonomous Database that the backup was created from.

pub fn ocid(&self) -> Option<&str>

The Oracle Cloud Identifier (OCID) of the Autonomous Database backup.

pub fn display_name(&self) -> Option<&str>

The user-friendly name of the Autonomous Database backup.

pub fn db_version(&self) -> Option<&str>

The Oracle Database software version of the Autonomous Database backup.

pub fn status(&self) -> Option<&AutonomousDatabaseBackupStatus>

The current status of the Autonomous Database backup.

pub fn status_reason(&self) -> Option<&str>

Additional information about the current status of the Autonomous Database backup, if applicable.

pub fn is_automatic(&self) -> Option<bool>

Indicates whether the backup was created automatically.

pub fn retention_period_in_days(&self) -> Option<i32>

The retention period, in days, for the Autonomous Database backup.

pub fn size_in_tbs(&self) -> Option<f64>

The size of the Autonomous Database backup, in terabytes (TB).

pub fn time_available_till(&self) -> Option<&DateTime>

The date and time until which the Autonomous Database backup is available for restore.

pub fn time_started(&self) -> Option<&DateTime>

The date and time when the Autonomous Database backup started.

pub fn time_ended(&self) -> Option<&DateTime>

The date and time when the Autonomous Database backup ended.

pub fn type(&self) -> Option<&AutonomousDatabaseBackupType>

The type of the Autonomous Database backup.

Source

impl AutonomousDatabaseBackupSummary

pub fn builder() -> AutonomousDatabaseBackupSummaryBuilder

Creates a new builder-style object to manufacture AutonomousDatabaseBackupSummary.