#[non_exhaustive]pub struct AutonomousDatabaseConnectionStrings {
pub all_connection_strings: Option<HashMap<String, String>>,
pub dedicated: Option<String>,
pub high: Option<String>,
pub medium: Option<String>,
pub low: Option<String>,
pub profiles: Option<Vec<DatabaseConnectionStringProfile>>,
}Expand description
The connection strings used to connect to an Autonomous Database.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.all_connection_strings: Option<HashMap<String, String>>The list of all connection strings that you can use to connect to the Autonomous Database.
dedicated: Option<String>The connection string for connecting to the Autonomous Database with a dedicated service.
high: Option<String>The connection string for the high-priority database service.
medium: Option<String>The connection string for the medium-priority database service.
low: Option<String>The connection string for the low-priority database service.
profiles: Option<Vec<DatabaseConnectionStringProfile>>The list of connection string profiles for the Autonomous Database.
Implementations
Sourceimpl AutonomousDatabaseConnectionStrings
impl AutonomousDatabaseConnectionStrings
Sourcepub fn all_connection_strings(&self) -> Option<&HashMap<String, String>>
pub fn all_connection_strings(&self) -> Option<&HashMap<String, String>>
The list of all connection strings that you can use to connect to the Autonomous Database.
Sourcepub fn dedicated(&self) -> Option<&str>
pub fn dedicated(&self) -> Option<&str>
The connection string for connecting to the Autonomous Database with a dedicated service.
Sourcepub fn high(&self) -> Option<&str>
pub fn high(&self) -> Option<&str>
The connection string for the high-priority database service.
Sourcepub fn medium(&self) -> Option<&str>
pub fn medium(&self) -> Option<&str>
The connection string for the medium-priority database service.
Sourcepub fn profiles(&self) -> &[DatabaseConnectionStringProfile]
pub fn profiles(&self) -> &[DatabaseConnectionStringProfile]
The list of connection string profiles for the Autonomous Database.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .profiles.is_none().
Sourceimpl AutonomousDatabaseConnectionStrings
impl AutonomousDatabaseConnectionStrings
Sourcepub fn builder() -> AutonomousDatabaseConnectionStringsBuilder
pub fn builder() -> AutonomousDatabaseConnectionStringsBuilder
Creates a new builder-style object to manufacture AutonomousDatabaseConnectionStrings.