#[non_exhaustive]pub struct AutonomousDatabaseConnectionUrls {
pub apex_url: Option<String>,
pub database_transforms_url: Option<String>,
pub graph_studio_url: Option<String>,
pub machine_learning_notebook_url: Option<String>,
pub machine_learning_user_management_url: Option<String>,
pub mongo_db_url: Option<String>,
pub ords_url: Option<String>,
pub spatial_studio_url: Option<String>,
pub sql_dev_web_url: Option<String>,
}Expand description
The connection URLs for accessing tools and services for an Autonomous Database.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.apex_url: Option<String>The URL for accessing Oracle Application Express (APEX) for the Autonomous Database.
database_transforms_url: Option<String>The URL for accessing Oracle Database Transforms for the Autonomous Database.
graph_studio_url: Option<String>The URL for accessing Oracle Graph Studio for the Autonomous Database.
machine_learning_notebook_url: Option<String>The URL for accessing the Oracle Machine Learning notebook for the Autonomous Database.
machine_learning_user_management_url: Option<String>The URL for accessing Oracle Machine Learning user management for the Autonomous Database.
mongo_db_url: Option<String>The URL for accessing the MongoDB API for the Autonomous Database.
ords_url: Option<String>The URL for accessing Oracle REST Data Services (ORDS) for the Autonomous Database.
spatial_studio_url: Option<String>The URL for accessing Oracle Spatial Studio for the Autonomous Database.
sql_dev_web_url: Option<String>The URL for accessing Oracle SQL Developer Web for the Autonomous Database.
Implementations
Sourceimpl AutonomousDatabaseConnectionUrls
impl AutonomousDatabaseConnectionUrls
Sourcepub fn apex_url(&self) -> Option<&str>
pub fn apex_url(&self) -> Option<&str>
The URL for accessing Oracle Application Express (APEX) for the Autonomous Database.
Sourcepub fn database_transforms_url(&self) -> Option<&str>
pub fn database_transforms_url(&self) -> Option<&str>
The URL for accessing Oracle Database Transforms for the Autonomous Database.
Sourcepub fn graph_studio_url(&self) -> Option<&str>
pub fn graph_studio_url(&self) -> Option<&str>
The URL for accessing Oracle Graph Studio for the Autonomous Database.
Sourcepub fn machine_learning_notebook_url(&self) -> Option<&str>
pub fn machine_learning_notebook_url(&self) -> Option<&str>
The URL for accessing the Oracle Machine Learning notebook for the Autonomous Database.
Sourcepub fn machine_learning_user_management_url(&self) -> Option<&str>
pub fn machine_learning_user_management_url(&self) -> Option<&str>
The URL for accessing Oracle Machine Learning user management for the Autonomous Database.
Sourcepub fn mongo_db_url(&self) -> Option<&str>
pub fn mongo_db_url(&self) -> Option<&str>
The URL for accessing the MongoDB API for the Autonomous Database.
Sourcepub fn ords_url(&self) -> Option<&str>
pub fn ords_url(&self) -> Option<&str>
The URL for accessing Oracle REST Data Services (ORDS) for the Autonomous Database.
Sourcepub fn spatial_studio_url(&self) -> Option<&str>
pub fn spatial_studio_url(&self) -> Option<&str>
The URL for accessing Oracle Spatial Studio for the Autonomous Database.
Sourcepub fn sql_dev_web_url(&self) -> Option<&str>
pub fn sql_dev_web_url(&self) -> Option<&str>
The URL for accessing Oracle SQL Developer Web for the Autonomous Database.
Sourceimpl AutonomousDatabaseConnectionUrls
impl AutonomousDatabaseConnectionUrls
Sourcepub fn builder() -> AutonomousDatabaseConnectionUrlsBuilder
pub fn builder() -> AutonomousDatabaseConnectionUrlsBuilder
Creates a new builder-style object to manufacture AutonomousDatabaseConnectionUrls.