#[non_exhaustive]pub struct AutonomousDatabasePeerSummary {
pub autonomous_database_id: Option<String>,
pub autonomous_database_arn: Option<String>,
pub ocid: Option<String>,
pub region: Option<String>,
}Expand description
A summary of a peer database of an Autonomous Database.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.autonomous_database_id: Option<String>The unique identifier of the peer Autonomous Database.
autonomous_database_arn: Option<String>The Amazon Resource Name (ARN) of the peer Autonomous Database.
ocid: Option<String>The Oracle Cloud Identifier (OCID) of the peer Autonomous Database.
region: Option<String>The Amazon Web Services Region where the peer Autonomous Database is located.
Implementations
Sourceimpl AutonomousDatabasePeerSummary
impl AutonomousDatabasePeerSummary
Sourcepub fn autonomous_database_id(&self) -> Option<&str>
pub fn autonomous_database_id(&self) -> Option<&str>
The unique identifier of the peer Autonomous Database.
Sourcepub fn autonomous_database_arn(&self) -> Option<&str>
pub fn autonomous_database_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the peer Autonomous Database.
Sourceimpl AutonomousDatabasePeerSummary
impl AutonomousDatabasePeerSummary
Sourcepub fn builder() -> AutonomousDatabasePeerSummaryBuilder
pub fn builder() -> AutonomousDatabasePeerSummaryBuilder
Creates a new builder-style object to manufacture AutonomousDatabasePeerSummary.