#[non_exhaustive]pub struct AutonomousDatabaseVersionSummary {
pub db_workload: Option<DbWorkload>,
pub details: Option<String>,
pub version: Option<String>,
}Expand description
A summary of an available Oracle Database software version for Autonomous Databases.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.db_workload: Option<DbWorkload>The intended use of the Autonomous Database that the version supports, such as transaction processing, data warehouse, JSON database, or APEX.
details: Option<String>Additional details about the Autonomous Database software version.
version: Option<String>The Oracle Database software version.
Implementations
Sourceimpl AutonomousDatabaseVersionSummary
impl AutonomousDatabaseVersionSummary
Sourcepub fn db_workload(&self) -> Option<&DbWorkload>
pub fn db_workload(&self) -> Option<&DbWorkload>
The intended use of the Autonomous Database that the version supports, such as transaction processing, data warehouse, JSON database, or APEX.
Sourceimpl AutonomousDatabaseVersionSummary
impl AutonomousDatabaseVersionSummary
Sourcepub fn builder() -> AutonomousDatabaseVersionSummaryBuilder
pub fn builder() -> AutonomousDatabaseVersionSummaryBuilder
Creates a new builder-style object to manufacture AutonomousDatabaseVersionSummary.