CloneToRefreshableConfiguration

Struct CloneToRefreshableConfiguration 

#[non_exhaustive]
pub struct CloneToRefreshableConfiguration { pub source_autonomous_database_id: String, pub refreshable_mode: Option<RefreshableMode>, pub auto_refresh_frequency_in_seconds: Option<i32>, pub auto_refresh_point_lag_in_seconds: Option<i32>, pub time_of_auto_refresh_start: Option<DateTime>, pub open_mode: Option<OpenMode>, pub clone_type: Option<CloneType>, }
The configuration for creating an Autonomous Database as a refreshable clone.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
source_autonomous_database_id: String

The unique identifier of the source Autonomous Database to create the refreshable clone from.

refreshable_mode: Option<RefreshableMode>

The refresh mode of the refreshable clone, either automatic or manual.

auto_refresh_frequency_in_seconds: Option<i32>

The frequency, in seconds, at which the refreshable clone is automatically refreshed.

auto_refresh_point_lag_in_seconds: Option<i32>

The time lag, in seconds, between the refreshable clone and its source database.

time_of_auto_refresh_start: Option<DateTime>

The date and time at which the automatic refresh of the refreshable clone starts.

open_mode: Option<OpenMode>

The mode in which to open the refreshable clone, either read-only or read/write.

clone_type: Option<CloneType>

The type of clone to create.

Implementations

Source

impl CloneToRefreshableConfiguration

pub fn source_autonomous_database_id(&self) -> &str

The unique identifier of the source Autonomous Database to create the refreshable clone from.

pub fn refreshable_mode(&self) -> Option<&RefreshableMode>

The refresh mode of the refreshable clone, either automatic or manual.

pub fn auto_refresh_frequency_in_seconds(&self) -> Option<i32>

The frequency, in seconds, at which the refreshable clone is automatically refreshed.

pub fn auto_refresh_point_lag_in_seconds(&self) -> Option<i32>

The time lag, in seconds, between the refreshable clone and its source database.

pub fn time_of_auto_refresh_start(&self) -> Option<&DateTime>

The date and time at which the automatic refresh of the refreshable clone starts.

pub fn open_mode(&self) -> Option<&OpenMode>

The mode in which to open the refreshable clone, either read-only or read/write.

pub fn clone_type(&self) -> Option<&CloneType>

The type of clone to create.

Source

impl CloneToRefreshableConfiguration

pub fn builder() -> CloneToRefreshableConfigurationBuilder

Creates a new builder-style object to manufacture CloneToRefreshableConfiguration.