#[non_exhaustive]pub struct CustomerManagedAwsSecretConfigurationInput {
pub secret_id: Option<String>,
pub iam_role_arn: Option<String>,
pub external_id_type: Option<ExternalIdType>,
}Expand description
The input configuration for a customer-managed Amazon Web Services Secrets Manager secret used to supply a password.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.secret_id: Option<String>The identifier or ARN of the Amazon Web Services Secrets Manager secret that contains the password.
iam_role_arn: Option<String>The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) role that OCI assumes to retrieve the secret value.
external_id_type: Option<ExternalIdType>The type of Oracle Cloud Identifier (OCID) used as the external ID when assuming the IAM role.
The valid values depend on the operation. For the CreateAutonomousDatabase operation, only compartment_ocid and tenant_ocid are allowed. For the UpdateAutonomousDatabase and CreateAutonomousDatabaseWallet operations, database_ocid, compartment_ocid, and tenant_ocid are all allowed.
Implementations
Sourceimpl CustomerManagedAwsSecretConfigurationInput
impl CustomerManagedAwsSecretConfigurationInput
Sourcepub fn secret_id(&self) -> Option<&str>
pub fn secret_id(&self) -> Option<&str>
The identifier or ARN of the Amazon Web Services Secrets Manager secret that contains the password.
Sourcepub fn iam_role_arn(&self) -> Option<&str>
pub fn iam_role_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) role that OCI assumes to retrieve the secret value.
Sourcepub fn external_id_type(&self) -> Option<&ExternalIdType>
pub fn external_id_type(&self) -> Option<&ExternalIdType>
The type of Oracle Cloud Identifier (OCID) used as the external ID when assuming the IAM role.
The valid values depend on the operation. For the CreateAutonomousDatabase operation, only compartment_ocid and tenant_ocid are allowed. For the UpdateAutonomousDatabase and CreateAutonomousDatabaseWallet operations, database_ocid, compartment_ocid, and tenant_ocid are all allowed.
Sourceimpl CustomerManagedAwsSecretConfigurationInput
impl CustomerManagedAwsSecretConfigurationInput
Sourcepub fn builder() -> CustomerManagedAwsSecretConfigurationInputBuilder
pub fn builder() -> CustomerManagedAwsSecretConfigurationInputBuilder
Creates a new builder-style object to manufacture CustomerManagedAwsSecretConfigurationInput.