#[non_exhaustive]pub struct DatabaseConnectionStringProfile {
pub consumer_group: Option<String>,
pub display_name: Option<String>,
pub host_format: Option<String>,
pub is_regional: Option<bool>,
pub protocol: Option<String>,
pub session_mode: Option<String>,
pub syntax_format: Option<String>,
pub tls_authentication: Option<String>,
pub value: Option<String>,
}Expand description
A connection string profile for an Autonomous Database.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.consumer_group: Option<String>The consumer group associated with the connection string profile.
display_name: Option<String>The user-friendly name of the connection string profile.
host_format: Option<String>The host name format used in the connection string.
is_regional: Option<bool>Indicates whether the connection string profile is regional.
protocol: Option<String>The protocol used by the connection string profile.
session_mode: Option<String>The session mode of the connection string profile.
syntax_format: Option<String>The syntax format of the connection string profile.
tls_authentication: Option<String>The TLS authentication method used by the connection string profile.
value: Option<String>The connection string value of the profile.
Implementations
Sourceimpl DatabaseConnectionStringProfile
impl DatabaseConnectionStringProfile
Sourcepub fn consumer_group(&self) -> Option<&str>
pub fn consumer_group(&self) -> Option<&str>
The consumer group associated with the connection string profile.
Sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
The user-friendly name of the connection string profile.
Sourcepub fn host_format(&self) -> Option<&str>
pub fn host_format(&self) -> Option<&str>
The host name format used in the connection string.
Sourcepub fn is_regional(&self) -> Option<bool>
pub fn is_regional(&self) -> Option<bool>
Indicates whether the connection string profile is regional.
Sourcepub fn session_mode(&self) -> Option<&str>
pub fn session_mode(&self) -> Option<&str>
The session mode of the connection string profile.
Sourcepub fn syntax_format(&self) -> Option<&str>
pub fn syntax_format(&self) -> Option<&str>
The syntax format of the connection string profile.
Sourcepub fn tls_authentication(&self) -> Option<&str>
pub fn tls_authentication(&self) -> Option<&str>
The TLS authentication method used by the connection string profile.
Sourceimpl DatabaseConnectionStringProfile
impl DatabaseConnectionStringProfile
Sourcepub fn builder() -> DatabaseConnectionStringProfileBuilder
pub fn builder() -> DatabaseConnectionStringProfileBuilder
Creates a new builder-style object to manufacture DatabaseConnectionStringProfile.