#[non_exhaustive]pub struct DatabaseTool {
pub is_enabled: Option<bool>,
pub name: Option<String>,
pub compute_count: Option<f64>,
pub max_idle_time_in_minutes: Option<i32>,
}Expand description
Information about a database management tool for an Autonomous Database.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.is_enabled: Option<bool>Indicates whether the database management tool is enabled.
name: Option<String>The name of the database management tool.
compute_count: Option<f64>The compute capacity allocated to the database management tool.
max_idle_time_in_minutes: Option<i32>The maximum amount of time, in minutes, that the database management tool can be idle before it is shut down.
Implementations
Sourceimpl DatabaseTool
impl DatabaseTool
Sourcepub fn is_enabled(&self) -> Option<bool>
pub fn is_enabled(&self) -> Option<bool>
Indicates whether the database management tool is enabled.
Sourcepub fn compute_count(&self) -> Option<f64>
pub fn compute_count(&self) -> Option<f64>
The compute capacity allocated to the database management tool.
Sourcepub fn max_idle_time_in_minutes(&self) -> Option<i32>
pub fn max_idle_time_in_minutes(&self) -> Option<i32>
The maximum amount of time, in minutes, that the database management tool can be idle before it is shut down.
Sourceimpl DatabaseTool
impl DatabaseTool
Sourcepub fn builder() -> DatabaseToolBuilder
pub fn builder() -> DatabaseToolBuilder
Creates a new builder-style object to manufacture DatabaseTool.