#[non_exhaustive]pub struct OkvEncryptionKeyConfiguration {
pub certificate_directory_name: String,
pub certificate_id: Option<String>,
pub directory_name: String,
pub okv_kms_key: String,
pub okv_uri: String,
}Expand description
The configuration of the Oracle Key Vault (OKV) encryption key used for an Autonomous Database.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.certificate_directory_name: StringThe name of the directory that contains the Oracle Key Vault (OKV) certificate.
certificate_id: Option<String>The identifier of the Oracle Key Vault (OKV) certificate.
directory_name: StringThe name of the directory where the Oracle Key Vault (OKV) configuration is stored.
okv_kms_key: StringThe identifier of the Oracle Key Vault (OKV) key to use for encryption.
okv_uri: StringThe URI of the Oracle Key Vault (OKV) server.
Implementations
Sourceimpl OkvEncryptionKeyConfiguration
impl OkvEncryptionKeyConfiguration
Sourcepub fn certificate_directory_name(&self) -> &str
pub fn certificate_directory_name(&self) -> &str
The name of the directory that contains the Oracle Key Vault (OKV) certificate.
Sourcepub fn certificate_id(&self) -> Option<&str>
pub fn certificate_id(&self) -> Option<&str>
The identifier of the Oracle Key Vault (OKV) certificate.
Sourcepub fn directory_name(&self) -> &str
pub fn directory_name(&self) -> &str
The name of the directory where the Oracle Key Vault (OKV) configuration is stored.
Sourcepub fn okv_kms_key(&self) -> &str
pub fn okv_kms_key(&self) -> &str
The identifier of the Oracle Key Vault (OKV) key to use for encryption.
Sourceimpl OkvEncryptionKeyConfiguration
impl OkvEncryptionKeyConfiguration
Sourcepub fn builder() -> OkvEncryptionKeyConfigurationBuilder
pub fn builder() -> OkvEncryptionKeyConfigurationBuilder
Creates a new builder-style object to manufacture OkvEncryptionKeyConfiguration.