#[non_exhaustive]pub struct PointInTimeRestoreConfiguration {
pub source_autonomous_database_id: String,
pub clone_type: CloneType,
pub timestamp: Option<DateTime>,
pub use_latest_available_backup_timestamp: Option<bool>,
pub clone_table_space_list: Option<Vec<i32>>,
}Expand description
The configuration for creating an Autonomous Database by restoring to a point in time.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_autonomous_database_id: StringThe unique identifier of the source Autonomous Database to restore from.
clone_type: CloneTypeThe type of clone to create from the point-in-time restore.
timestamp: Option<DateTime>The date and time to which to restore the Autonomous Database.
use_latest_available_backup_timestamp: Option<bool>Indicates whether to use the latest available backup timestamp for the restore.
clone_table_space_list: Option<Vec<i32>>The list of tablespace identifiers to clone from the point-in-time restore.
Implementations
Sourceimpl PointInTimeRestoreConfiguration
impl PointInTimeRestoreConfiguration
Sourcepub fn source_autonomous_database_id(&self) -> &str
pub fn source_autonomous_database_id(&self) -> &str
The unique identifier of the source Autonomous Database to restore from.
Sourcepub fn clone_type(&self) -> &CloneType
pub fn clone_type(&self) -> &CloneType
The type of clone to create from the point-in-time restore.
Sourcepub fn timestamp(&self) -> Option<&DateTime>
pub fn timestamp(&self) -> Option<&DateTime>
The date and time to which to restore the Autonomous Database.
Sourcepub fn use_latest_available_backup_timestamp(&self) -> Option<bool>
pub fn use_latest_available_backup_timestamp(&self) -> Option<bool>
Indicates whether to use the latest available backup timestamp for the restore.
Sourcepub fn clone_table_space_list(&self) -> &[i32]
pub fn clone_table_space_list(&self) -> &[i32]
The list of tablespace identifiers to clone from the point-in-time restore.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .clone_table_space_list.is_none().
Sourceimpl PointInTimeRestoreConfiguration
impl PointInTimeRestoreConfiguration
Sourcepub fn builder() -> PointInTimeRestoreConfigurationBuilder
pub fn builder() -> PointInTimeRestoreConfigurationBuilder
Creates a new builder-style object to manufacture PointInTimeRestoreConfiguration.