#[non_exhaustive]pub struct ResourcePoolSummary {
pub is_disabled: Option<bool>,
pub pool_size: Option<i32>,
pub pool_storage_size_in_tbs: Option<i32>,
pub available_storage_capacity_in_tbs: Option<f64>,
pub total_compute_capacity: Option<i32>,
pub available_compute_capacity: Option<i32>,
}Expand description
The configuration of a resource pool for an Autonomous Database.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.is_disabled: Option<bool>Indicates whether the resource pool is disabled.
pool_size: Option<i32>The number of Autonomous Databases that the resource pool can contain.
pool_storage_size_in_tbs: Option<i32>The total storage size of the resource pool, in terabytes (TB).
available_storage_capacity_in_tbs: Option<f64>The available storage capacity in the resource pool, in TB.
total_compute_capacity: Option<i32>The total compute capacity of the resource pool.
available_compute_capacity: Option<i32>The available compute capacity in the resource pool.
Implementations
Sourceimpl ResourcePoolSummary
impl ResourcePoolSummary
Sourcepub fn is_disabled(&self) -> Option<bool>
pub fn is_disabled(&self) -> Option<bool>
Indicates whether the resource pool is disabled.
Sourcepub fn pool_size(&self) -> Option<i32>
pub fn pool_size(&self) -> Option<i32>
The number of Autonomous Databases that the resource pool can contain.
Sourcepub fn pool_storage_size_in_tbs(&self) -> Option<i32>
pub fn pool_storage_size_in_tbs(&self) -> Option<i32>
The total storage size of the resource pool, in terabytes (TB).
Sourcepub fn available_storage_capacity_in_tbs(&self) -> Option<f64>
pub fn available_storage_capacity_in_tbs(&self) -> Option<f64>
The available storage capacity in the resource pool, in TB.
Sourcepub fn total_compute_capacity(&self) -> Option<i32>
pub fn total_compute_capacity(&self) -> Option<i32>
The total compute capacity of the resource pool.
Sourcepub fn available_compute_capacity(&self) -> Option<i32>
pub fn available_compute_capacity(&self) -> Option<i32>
The available compute capacity in the resource pool.
Sourceimpl ResourcePoolSummary
impl ResourcePoolSummary
Sourcepub fn builder() -> ResourcePoolSummaryBuilder
pub fn builder() -> ResourcePoolSummaryBuilder
Creates a new builder-style object to manufacture ResourcePoolSummary.