#[non_exhaustive]pub struct RestoreFromBackupConfiguration {
pub autonomous_database_backup_id: String,
pub clone_type: CloneType,
pub clone_table_space_list: Option<Vec<i32>>,
}Expand description
The configuration for creating an Autonomous Database by restoring from a backup.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.autonomous_database_backup_id: StringThe unique identifier of the Autonomous Database backup to restore from.
clone_type: CloneTypeThe type of clone to create from the backup.
clone_table_space_list: Option<Vec<i32>>The list of tablespace identifiers to clone from the backup.
Implementations
Sourceimpl RestoreFromBackupConfiguration
impl RestoreFromBackupConfiguration
Sourcepub fn autonomous_database_backup_id(&self) -> &str
pub fn autonomous_database_backup_id(&self) -> &str
The unique identifier of the Autonomous Database backup to restore from.
Sourcepub fn clone_type(&self) -> &CloneType
pub fn clone_type(&self) -> &CloneType
The type of clone to create from the backup.
Sourcepub fn clone_table_space_list(&self) -> &[i32]
pub fn clone_table_space_list(&self) -> &[i32]
The list of tablespace identifiers to clone from the backup.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .clone_table_space_list.is_none().
Sourceimpl RestoreFromBackupConfiguration
impl RestoreFromBackupConfiguration
Sourcepub fn builder() -> RestoreFromBackupConfigurationBuilder
pub fn builder() -> RestoreFromBackupConfigurationBuilder
Creates a new builder-style object to manufacture RestoreFromBackupConfiguration.