pub struct CreateAutonomousDatabaseFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateAutonomousDatabase.
Creates a new Autonomous Database.
Implementations
Sourceimpl CreateAutonomousDatabaseFluentBuilder
impl CreateAutonomousDatabaseFluentBuilder
Sourcepub fn as_input(&self) -> &CreateAutonomousDatabaseInputBuilder
pub fn as_input(&self) -> &CreateAutonomousDatabaseInputBuilder
Access the CreateAutonomousDatabase as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateAutonomousDatabaseOutput, SdkError<CreateAutonomousDatabaseError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateAutonomousDatabaseOutput, SdkError<CreateAutonomousDatabaseError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateAutonomousDatabaseOutput, CreateAutonomousDatabaseError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateAutonomousDatabaseOutput, CreateAutonomousDatabaseError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn odb_network_id(self, input: impl Into<String>) -> Self
pub fn odb_network_id(self, input: impl Into<String>) -> Self
The unique identifier of the ODB network to be used for the Autonomous Database.
Sourcepub fn set_odb_network_id(self, input: Option<String>) -> Self
pub fn set_odb_network_id(self, input: Option<String>) -> Self
The unique identifier of the ODB network to be used for the Autonomous Database.
Sourcepub fn get_odb_network_id(&self) -> &Option<String>
pub fn get_odb_network_id(&self) -> &Option<String>
The unique identifier of the ODB network to be used for the Autonomous Database.
Sourcepub fn display_name(self, input: impl Into<String>) -> Self
pub fn display_name(self, input: impl Into<String>) -> Self
The user-friendly name for the Autonomous Database. The name does not have to be unique.
Sourcepub fn set_display_name(self, input: Option<String>) -> Self
pub fn set_display_name(self, input: Option<String>) -> Self
The user-friendly name for the Autonomous Database. The name does not have to be unique.
Sourcepub fn get_display_name(&self) -> &Option<String>
pub fn get_display_name(&self) -> &Option<String>
The user-friendly name for the Autonomous Database. The name does not have to be unique.
Sourcepub fn db_name(self, input: impl Into<String>) -> Self
pub fn db_name(self, input: impl Into<String>) -> Self
The name of the Autonomous Database. The name must begin with an alphabetic character and can contain a maximum of 30 alphanumeric characters. Special characters are not permitted. The name must be unique in the Amazon Web Services account.
Sourcepub fn set_db_name(self, input: Option<String>) -> Self
pub fn set_db_name(self, input: Option<String>) -> Self
The name of the Autonomous Database. The name must begin with an alphabetic character and can contain a maximum of 30 alphanumeric characters. Special characters are not permitted. The name must be unique in the Amazon Web Services account.
Sourcepub fn get_db_name(&self) -> &Option<String>
pub fn get_db_name(&self) -> &Option<String>
The name of the Autonomous Database. The name must begin with an alphabetic character and can contain a maximum of 30 alphanumeric characters. Special characters are not permitted. The name must be unique in the Amazon Web Services account.
Sourcepub fn admin_password(self, input: impl Into<String>) -> Self
pub fn admin_password(self, input: impl Into<String>) -> Self
The password for the ADMIN user of the Autonomous Database.
Sourcepub fn set_admin_password(self, input: Option<String>) -> Self
pub fn set_admin_password(self, input: Option<String>) -> Self
The password for the ADMIN user of the Autonomous Database.
Sourcepub fn get_admin_password(&self) -> &Option<String>
pub fn get_admin_password(&self) -> &Option<String>
The password for the ADMIN user of the Autonomous Database.
Sourcepub fn compute_count(self, input: f64) -> Self
pub fn compute_count(self, input: f64) -> Self
The compute capacity, in number of Elastic CPUs (ECPUs) or Oracle CPUs (OCPUs), to assign to the Autonomous Database.
Sourcepub fn set_compute_count(self, input: Option<f64>) -> Self
pub fn set_compute_count(self, input: Option<f64>) -> Self
The compute capacity, in number of Elastic CPUs (ECPUs) or Oracle CPUs (OCPUs), to assign to the Autonomous Database.
Sourcepub fn get_compute_count(&self) -> &Option<f64>
pub fn get_compute_count(&self) -> &Option<f64>
The compute capacity, in number of Elastic CPUs (ECPUs) or Oracle CPUs (OCPUs), to assign to the Autonomous Database.
Sourcepub fn data_storage_size_in_tbs(self, input: i32) -> Self
pub fn data_storage_size_in_tbs(self, input: i32) -> Self
The size, in terabytes (TB), of the data volume to allocate for the Autonomous Database.
Sourcepub fn set_data_storage_size_in_tbs(self, input: Option<i32>) -> Self
pub fn set_data_storage_size_in_tbs(self, input: Option<i32>) -> Self
The size, in terabytes (TB), of the data volume to allocate for the Autonomous Database.
Sourcepub fn get_data_storage_size_in_tbs(&self) -> &Option<i32>
pub fn get_data_storage_size_in_tbs(&self) -> &Option<i32>
The size, in terabytes (TB), of the data volume to allocate for the Autonomous Database.
Sourcepub fn data_storage_size_in_gbs(self, input: i32) -> Self
pub fn data_storage_size_in_gbs(self, input: i32) -> Self
The size, in gigabytes (GB), of the data volume to allocate for the Autonomous Database.
Sourcepub fn set_data_storage_size_in_gbs(self, input: Option<i32>) -> Self
pub fn set_data_storage_size_in_gbs(self, input: Option<i32>) -> Self
The size, in gigabytes (GB), of the data volume to allocate for the Autonomous Database.
Sourcepub fn get_data_storage_size_in_gbs(&self) -> &Option<i32>
pub fn get_data_storage_size_in_gbs(&self) -> &Option<i32>
The size, in gigabytes (GB), of the data volume to allocate for the Autonomous Database.
Sourcepub fn db_workload(self, input: DbWorkload) -> Self
pub fn db_workload(self, input: DbWorkload) -> Self
The intended use of the Autonomous Database, such as transaction processing, data warehouse, JSON database, or APEX.
Sourcepub fn set_db_workload(self, input: Option<DbWorkload>) -> Self
pub fn set_db_workload(self, input: Option<DbWorkload>) -> Self
The intended use of the Autonomous Database, such as transaction processing, data warehouse, JSON database, or APEX.
Sourcepub fn get_db_workload(&self) -> &Option<DbWorkload>
pub fn get_db_workload(&self) -> &Option<DbWorkload>
The intended use of the Autonomous Database, such as transaction processing, data warehouse, JSON database, or APEX.
Sourcepub fn is_auto_scaling_enabled(self, input: bool) -> Self
pub fn is_auto_scaling_enabled(self, input: bool) -> Self
Specifies whether to enable automatic scaling of the compute resources for the Autonomous Database.
Sourcepub fn set_is_auto_scaling_enabled(self, input: Option<bool>) -> Self
pub fn set_is_auto_scaling_enabled(self, input: Option<bool>) -> Self
Specifies whether to enable automatic scaling of the compute resources for the Autonomous Database.
Sourcepub fn get_is_auto_scaling_enabled(&self) -> &Option<bool>
pub fn get_is_auto_scaling_enabled(&self) -> &Option<bool>
Specifies whether to enable automatic scaling of the compute resources for the Autonomous Database.
Sourcepub fn is_auto_scaling_for_storage_enabled(self, input: bool) -> Self
pub fn is_auto_scaling_for_storage_enabled(self, input: bool) -> Self
Specifies whether to enable automatic scaling of the storage for the Autonomous Database.
Sourcepub fn set_is_auto_scaling_for_storage_enabled(
self,
input: Option<bool>,
) -> Self
pub fn set_is_auto_scaling_for_storage_enabled( self, input: Option<bool>, ) -> Self
Specifies whether to enable automatic scaling of the storage for the Autonomous Database.
Sourcepub fn get_is_auto_scaling_for_storage_enabled(&self) -> &Option<bool>
pub fn get_is_auto_scaling_for_storage_enabled(&self) -> &Option<bool>
Specifies whether to enable automatic scaling of the storage for the Autonomous Database.
Sourcepub fn license_model(self, input: LicenseModel) -> Self
pub fn license_model(self, input: LicenseModel) -> Self
The Oracle license model to apply to the Autonomous Database.
Sourcepub fn set_license_model(self, input: Option<LicenseModel>) -> Self
pub fn set_license_model(self, input: Option<LicenseModel>) -> Self
The Oracle license model to apply to the Autonomous Database.
Sourcepub fn get_license_model(&self) -> &Option<LicenseModel>
pub fn get_license_model(&self) -> &Option<LicenseModel>
The Oracle license model to apply to the Autonomous Database.
Sourcepub fn character_set(self, input: impl Into<String>) -> Self
pub fn character_set(self, input: impl Into<String>) -> Self
The character set to use for the Autonomous Database.
Sourcepub fn set_character_set(self, input: Option<String>) -> Self
pub fn set_character_set(self, input: Option<String>) -> Self
The character set to use for the Autonomous Database.
Sourcepub fn get_character_set(&self) -> &Option<String>
pub fn get_character_set(&self) -> &Option<String>
The character set to use for the Autonomous Database.
Sourcepub fn ncharacter_set(self, input: impl Into<String>) -> Self
pub fn ncharacter_set(self, input: impl Into<String>) -> Self
The national character set to use for the Autonomous Database.
Sourcepub fn set_ncharacter_set(self, input: Option<String>) -> Self
pub fn set_ncharacter_set(self, input: Option<String>) -> Self
The national character set to use for the Autonomous Database.
Sourcepub fn get_ncharacter_set(&self) -> &Option<String>
pub fn get_ncharacter_set(&self) -> &Option<String>
The national character set to use for the Autonomous Database.
Sourcepub fn db_version(self, input: impl Into<String>) -> Self
pub fn db_version(self, input: impl Into<String>) -> Self
The Oracle Database software version to use for the Autonomous Database.
Sourcepub fn set_db_version(self, input: Option<String>) -> Self
pub fn set_db_version(self, input: Option<String>) -> Self
The Oracle Database software version to use for the Autonomous Database.
Sourcepub fn get_db_version(&self) -> &Option<String>
pub fn get_db_version(&self) -> &Option<String>
The Oracle Database software version to use for the Autonomous Database.
Sourcepub fn database_edition(self, input: DatabaseEdition) -> Self
pub fn database_edition(self, input: DatabaseEdition) -> Self
The Oracle Database edition to apply to the Autonomous Database.
Sourcepub fn set_database_edition(self, input: Option<DatabaseEdition>) -> Self
pub fn set_database_edition(self, input: Option<DatabaseEdition>) -> Self
The Oracle Database edition to apply to the Autonomous Database.
Sourcepub fn get_database_edition(&self) -> &Option<DatabaseEdition>
pub fn get_database_edition(&self) -> &Option<DatabaseEdition>
The Oracle Database edition to apply to the Autonomous Database.
Sourcepub fn standby_allowlisted_ips_source(
self,
input: StandbyAllowlistedIpsSource,
) -> Self
pub fn standby_allowlisted_ips_source( self, input: StandbyAllowlistedIpsSource, ) -> Self
The source of the allowlisted IP addresses for the standby Autonomous Database.
Sourcepub fn set_standby_allowlisted_ips_source(
self,
input: Option<StandbyAllowlistedIpsSource>,
) -> Self
pub fn set_standby_allowlisted_ips_source( self, input: Option<StandbyAllowlistedIpsSource>, ) -> Self
The source of the allowlisted IP addresses for the standby Autonomous Database.
Sourcepub fn get_standby_allowlisted_ips_source(
&self,
) -> &Option<StandbyAllowlistedIpsSource>
pub fn get_standby_allowlisted_ips_source( &self, ) -> &Option<StandbyAllowlistedIpsSource>
The source of the allowlisted IP addresses for the standby Autonomous Database.
Sourcepub fn autonomous_maintenance_schedule_type(
self,
input: AutonomousMaintenanceScheduleType,
) -> Self
pub fn autonomous_maintenance_schedule_type( self, input: AutonomousMaintenanceScheduleType, ) -> Self
The maintenance schedule type for the Autonomous Database.
Sourcepub fn set_autonomous_maintenance_schedule_type(
self,
input: Option<AutonomousMaintenanceScheduleType>,
) -> Self
pub fn set_autonomous_maintenance_schedule_type( self, input: Option<AutonomousMaintenanceScheduleType>, ) -> Self
The maintenance schedule type for the Autonomous Database.
Sourcepub fn get_autonomous_maintenance_schedule_type(
&self,
) -> &Option<AutonomousMaintenanceScheduleType>
pub fn get_autonomous_maintenance_schedule_type( &self, ) -> &Option<AutonomousMaintenanceScheduleType>
The maintenance schedule type for the Autonomous Database.
Sourcepub fn backup_retention_period_in_days(self, input: i32) -> Self
pub fn backup_retention_period_in_days(self, input: i32) -> Self
The retention period, in days, for automatic backups of the Autonomous Database.
Sourcepub fn set_backup_retention_period_in_days(self, input: Option<i32>) -> Self
pub fn set_backup_retention_period_in_days(self, input: Option<i32>) -> Self
The retention period, in days, for automatic backups of the Autonomous Database.
Sourcepub fn get_backup_retention_period_in_days(&self) -> &Option<i32>
pub fn get_backup_retention_period_in_days(&self) -> &Option<i32>
The retention period, in days, for automatic backups of the Autonomous Database.
Sourcepub fn byol_compute_count_limit(self, input: f64) -> Self
pub fn byol_compute_count_limit(self, input: f64) -> Self
The maximum number of compute resources that you can allocate to the Autonomous Database under the bring-your-own-license (BYOL) model.
Sourcepub fn set_byol_compute_count_limit(self, input: Option<f64>) -> Self
pub fn set_byol_compute_count_limit(self, input: Option<f64>) -> Self
The maximum number of compute resources that you can allocate to the Autonomous Database under the bring-your-own-license (BYOL) model.
Sourcepub fn get_byol_compute_count_limit(&self) -> &Option<f64>
pub fn get_byol_compute_count_limit(&self) -> &Option<f64>
The maximum number of compute resources that you can allocate to the Autonomous Database under the bring-your-own-license (BYOL) model.
Sourcepub fn cpu_core_count(self, input: i32) -> Self
pub fn cpu_core_count(self, input: i32) -> Self
The number of CPU cores to allocate to the Autonomous Database.
Sourcepub fn set_cpu_core_count(self, input: Option<i32>) -> Self
pub fn set_cpu_core_count(self, input: Option<i32>) -> Self
The number of CPU cores to allocate to the Autonomous Database.
Sourcepub fn get_cpu_core_count(&self) -> &Option<i32>
pub fn get_cpu_core_count(&self) -> &Option<i32>
The number of CPU cores to allocate to the Autonomous Database.
Sourcepub fn customer_contacts_to_send_to_oci(self, input: CustomerContact) -> Self
pub fn customer_contacts_to_send_to_oci(self, input: CustomerContact) -> Self
Appends an item to customerContactsToSendToOCI.
To override the contents of this collection use set_customer_contacts_to_send_to_oci.
The list of customer contacts to receive operational notifications from Oracle Cloud Infrastructure (OCI) for the Autonomous Database.
Sourcepub fn set_customer_contacts_to_send_to_oci(
self,
input: Option<Vec<CustomerContact>>,
) -> Self
pub fn set_customer_contacts_to_send_to_oci( self, input: Option<Vec<CustomerContact>>, ) -> Self
The list of customer contacts to receive operational notifications from Oracle Cloud Infrastructure (OCI) for the Autonomous Database.
Sourcepub fn get_customer_contacts_to_send_to_oci(
&self,
) -> &Option<Vec<CustomerContact>>
pub fn get_customer_contacts_to_send_to_oci( &self, ) -> &Option<Vec<CustomerContact>>
The list of customer contacts to receive operational notifications from Oracle Cloud Infrastructure (OCI) for the Autonomous Database.
Sourcepub fn private_endpoint_ip(self, input: impl Into<String>) -> Self
pub fn private_endpoint_ip(self, input: impl Into<String>) -> Self
The private endpoint IP address for the Autonomous Database.
Sourcepub fn set_private_endpoint_ip(self, input: Option<String>) -> Self
pub fn set_private_endpoint_ip(self, input: Option<String>) -> Self
The private endpoint IP address for the Autonomous Database.
Sourcepub fn get_private_endpoint_ip(&self) -> &Option<String>
pub fn get_private_endpoint_ip(&self) -> &Option<String>
The private endpoint IP address for the Autonomous Database.
Sourcepub fn private_endpoint_label(self, input: impl Into<String>) -> Self
pub fn private_endpoint_label(self, input: impl Into<String>) -> Self
The private endpoint label for the Autonomous Database.
Sourcepub fn set_private_endpoint_label(self, input: Option<String>) -> Self
pub fn set_private_endpoint_label(self, input: Option<String>) -> Self
The private endpoint label for the Autonomous Database.
Sourcepub fn get_private_endpoint_label(&self) -> &Option<String>
pub fn get_private_endpoint_label(&self) -> &Option<String>
The private endpoint label for the Autonomous Database.
Sourcepub fn resource_pool_leader_id(self, input: impl Into<String>) -> Self
pub fn resource_pool_leader_id(self, input: impl Into<String>) -> Self
The unique identifier of the resource pool leader Autonomous Database.
Sourcepub fn set_resource_pool_leader_id(self, input: Option<String>) -> Self
pub fn set_resource_pool_leader_id(self, input: Option<String>) -> Self
The unique identifier of the resource pool leader Autonomous Database.
Sourcepub fn get_resource_pool_leader_id(&self) -> &Option<String>
pub fn get_resource_pool_leader_id(&self) -> &Option<String>
The unique identifier of the resource pool leader Autonomous Database.
Sourcepub fn resource_pool_summary(self, input: ResourcePoolSummary) -> Self
pub fn resource_pool_summary(self, input: ResourcePoolSummary) -> Self
The configuration of the resource pool for the Autonomous Database.
Sourcepub fn set_resource_pool_summary(
self,
input: Option<ResourcePoolSummary>,
) -> Self
pub fn set_resource_pool_summary( self, input: Option<ResourcePoolSummary>, ) -> Self
The configuration of the resource pool for the Autonomous Database.
Sourcepub fn get_resource_pool_summary(&self) -> &Option<ResourcePoolSummary>
pub fn get_resource_pool_summary(&self) -> &Option<ResourcePoolSummary>
The configuration of the resource pool for the Autonomous Database.
Sourcepub fn scheduled_operations(self, input: ScheduledOperationDetails) -> Self
pub fn scheduled_operations(self, input: ScheduledOperationDetails) -> Self
Appends an item to scheduledOperations.
To override the contents of this collection use set_scheduled_operations.
The list of scheduled start and stop times for the Autonomous Database.
Sourcepub fn set_scheduled_operations(
self,
input: Option<Vec<ScheduledOperationDetails>>,
) -> Self
pub fn set_scheduled_operations( self, input: Option<Vec<ScheduledOperationDetails>>, ) -> Self
The list of scheduled start and stop times for the Autonomous Database.
Sourcepub fn get_scheduled_operations(
&self,
) -> &Option<Vec<ScheduledOperationDetails>>
pub fn get_scheduled_operations( &self, ) -> &Option<Vec<ScheduledOperationDetails>>
The list of scheduled start and stop times for the Autonomous Database.
Sourcepub fn standby_allowlisted_ips(self, input: impl Into<String>) -> Self
pub fn standby_allowlisted_ips(self, input: impl Into<String>) -> Self
Appends an item to standbyAllowlistedIps.
To override the contents of this collection use set_standby_allowlisted_ips.
The list of IP addresses that are allowed to access the standby Autonomous Database.
Sourcepub fn set_standby_allowlisted_ips(self, input: Option<Vec<String>>) -> Self
pub fn set_standby_allowlisted_ips(self, input: Option<Vec<String>>) -> Self
The list of IP addresses that are allowed to access the standby Autonomous Database.
Sourcepub fn get_standby_allowlisted_ips(&self) -> &Option<Vec<String>>
pub fn get_standby_allowlisted_ips(&self) -> &Option<Vec<String>>
The list of IP addresses that are allowed to access the standby Autonomous Database.
Sourcepub fn allowlisted_ips(self, input: impl Into<String>) -> Self
pub fn allowlisted_ips(self, input: impl Into<String>) -> Self
Appends an item to allowlistedIps.
To override the contents of this collection use set_allowlisted_ips.
The list of IP addresses that are allowed to access the Autonomous Database.
Sourcepub fn set_allowlisted_ips(self, input: Option<Vec<String>>) -> Self
pub fn set_allowlisted_ips(self, input: Option<Vec<String>>) -> Self
The list of IP addresses that are allowed to access the Autonomous Database.
Sourcepub fn get_allowlisted_ips(&self) -> &Option<Vec<String>>
pub fn get_allowlisted_ips(&self) -> &Option<Vec<String>>
The list of IP addresses that are allowed to access the Autonomous Database.
Sourcepub fn transportable_tablespace(self, input: TransportableTablespace) -> Self
pub fn transportable_tablespace(self, input: TransportableTablespace) -> Self
The transportable tablespace configuration to use when creating the Autonomous Database.
Sourcepub fn set_transportable_tablespace(
self,
input: Option<TransportableTablespace>,
) -> Self
pub fn set_transportable_tablespace( self, input: Option<TransportableTablespace>, ) -> Self
The transportable tablespace configuration to use when creating the Autonomous Database.
Sourcepub fn get_transportable_tablespace(&self) -> &Option<TransportableTablespace>
pub fn get_transportable_tablespace(&self) -> &Option<TransportableTablespace>
The transportable tablespace configuration to use when creating the Autonomous Database.
Sourcepub fn is_backup_retention_locked(self, input: bool) -> Self
pub fn is_backup_retention_locked(self, input: bool) -> Self
Specifies whether to lock the backup retention period of the Autonomous Database to prevent it from being shortened.
Sourcepub fn set_is_backup_retention_locked(self, input: Option<bool>) -> Self
pub fn set_is_backup_retention_locked(self, input: Option<bool>) -> Self
Specifies whether to lock the backup retention period of the Autonomous Database to prevent it from being shortened.
Sourcepub fn get_is_backup_retention_locked(&self) -> &Option<bool>
pub fn get_is_backup_retention_locked(&self) -> &Option<bool>
Specifies whether to lock the backup retention period of the Autonomous Database to prevent it from being shortened.
Sourcepub fn is_local_data_guard_enabled(self, input: bool) -> Self
pub fn is_local_data_guard_enabled(self, input: bool) -> Self
Specifies whether to enable local Oracle Data Guard for the Autonomous Database.
Sourcepub fn set_is_local_data_guard_enabled(self, input: Option<bool>) -> Self
pub fn set_is_local_data_guard_enabled(self, input: Option<bool>) -> Self
Specifies whether to enable local Oracle Data Guard for the Autonomous Database.
Sourcepub fn get_is_local_data_guard_enabled(&self) -> &Option<bool>
pub fn get_is_local_data_guard_enabled(&self) -> &Option<bool>
Specifies whether to enable local Oracle Data Guard for the Autonomous Database.
Sourcepub fn is_mtls_connection_required(self, input: bool) -> Self
pub fn is_mtls_connection_required(self, input: bool) -> Self
Specifies whether mutual TLS (mTLS) authentication is required to connect to the Autonomous Database.
Sourcepub fn set_is_mtls_connection_required(self, input: Option<bool>) -> Self
pub fn set_is_mtls_connection_required(self, input: Option<bool>) -> Self
Specifies whether mutual TLS (mTLS) authentication is required to connect to the Autonomous Database.
Sourcepub fn get_is_mtls_connection_required(&self) -> &Option<bool>
pub fn get_is_mtls_connection_required(&self) -> &Option<bool>
Specifies whether mutual TLS (mTLS) authentication is required to connect to the Autonomous Database.
Sourcepub fn db_tools_details(self, input: DatabaseTool) -> Self
pub fn db_tools_details(self, input: DatabaseTool) -> Self
Appends an item to dbToolsDetails.
To override the contents of this collection use set_db_tools_details.
The list of database management tools to enable for the Autonomous Database.
Sourcepub fn set_db_tools_details(self, input: Option<Vec<DatabaseTool>>) -> Self
pub fn set_db_tools_details(self, input: Option<Vec<DatabaseTool>>) -> Self
The list of database management tools to enable for the Autonomous Database.
Sourcepub fn get_db_tools_details(&self) -> &Option<Vec<DatabaseTool>>
pub fn get_db_tools_details(&self) -> &Option<Vec<DatabaseTool>>
The list of database management tools to enable for the Autonomous Database.
Sourcepub fn source(self, input: SourceType) -> Self
pub fn source(self, input: SourceType) -> Self
The source from which to create the Autonomous Database, such as a clone, backup, or cross-Region copy.
Sourcepub fn set_source(self, input: Option<SourceType>) -> Self
pub fn set_source(self, input: Option<SourceType>) -> Self
The source from which to create the Autonomous Database, such as a clone, backup, or cross-Region copy.
Sourcepub fn get_source(&self) -> &Option<SourceType>
pub fn get_source(&self) -> &Option<SourceType>
The source from which to create the Autonomous Database, such as a clone, backup, or cross-Region copy.
Sourcepub fn source_configuration(self, input: SourceConfiguration) -> Self
pub fn source_configuration(self, input: SourceConfiguration) -> Self
The configuration details for the source used to create the Autonomous Database.
Sourcepub fn set_source_configuration(
self,
input: Option<SourceConfiguration>,
) -> Self
pub fn set_source_configuration( self, input: Option<SourceConfiguration>, ) -> Self
The configuration details for the source used to create the Autonomous Database.
Sourcepub fn get_source_configuration(&self) -> &Option<SourceConfiguration>
pub fn get_source_configuration(&self) -> &Option<SourceConfiguration>
The configuration details for the source used to create the Autonomous Database.
Sourcepub fn encryption_key_provider(self, input: EncryptionKeyProviderInput) -> Self
pub fn encryption_key_provider(self, input: EncryptionKeyProviderInput) -> Self
The provider of the encryption key to use for the Autonomous Database.
Sourcepub fn set_encryption_key_provider(
self,
input: Option<EncryptionKeyProviderInput>,
) -> Self
pub fn set_encryption_key_provider( self, input: Option<EncryptionKeyProviderInput>, ) -> Self
The provider of the encryption key to use for the Autonomous Database.
Sourcepub fn get_encryption_key_provider(&self) -> &Option<EncryptionKeyProviderInput>
pub fn get_encryption_key_provider(&self) -> &Option<EncryptionKeyProviderInput>
The provider of the encryption key to use for the Autonomous Database.
Sourcepub fn encryption_key_configuration(
self,
input: EncryptionKeyConfigurationInput,
) -> Self
pub fn encryption_key_configuration( self, input: EncryptionKeyConfigurationInput, ) -> Self
The configuration of the encryption key to use for the Autonomous Database.
Sourcepub fn set_encryption_key_configuration(
self,
input: Option<EncryptionKeyConfigurationInput>,
) -> Self
pub fn set_encryption_key_configuration( self, input: Option<EncryptionKeyConfigurationInput>, ) -> Self
The configuration of the encryption key to use for the Autonomous Database.
Sourcepub fn get_encryption_key_configuration(
&self,
) -> &Option<EncryptionKeyConfigurationInput>
pub fn get_encryption_key_configuration( &self, ) -> &Option<EncryptionKeyConfigurationInput>
The configuration of the encryption key to use for the Autonomous Database.
Sourcepub fn admin_password_source(self, input: AdminPasswordSource) -> Self
pub fn admin_password_source(self, input: AdminPasswordSource) -> Self
The source of the admin password for the Autonomous Database. When set to CUSTOMER_MANAGED_AWS_SECRET, the admin password is retrieved from an Amazon Web Services Secrets Manager secret.
Sourcepub fn set_admin_password_source(
self,
input: Option<AdminPasswordSource>,
) -> Self
pub fn set_admin_password_source( self, input: Option<AdminPasswordSource>, ) -> Self
The source of the admin password for the Autonomous Database. When set to CUSTOMER_MANAGED_AWS_SECRET, the admin password is retrieved from an Amazon Web Services Secrets Manager secret.
Sourcepub fn get_admin_password_source(&self) -> &Option<AdminPasswordSource>
pub fn get_admin_password_source(&self) -> &Option<AdminPasswordSource>
The source of the admin password for the Autonomous Database. When set to CUSTOMER_MANAGED_AWS_SECRET, the admin password is retrieved from an Amazon Web Services Secrets Manager secret.
Sourcepub fn admin_password_source_configuration(
self,
input: AdminPasswordSourceConfigurationInput,
) -> Self
pub fn admin_password_source_configuration( self, input: AdminPasswordSourceConfigurationInput, ) -> Self
The configuration of the admin password source for the Autonomous Database.
Sourcepub fn set_admin_password_source_configuration(
self,
input: Option<AdminPasswordSourceConfigurationInput>,
) -> Self
pub fn set_admin_password_source_configuration( self, input: Option<AdminPasswordSourceConfigurationInput>, ) -> Self
The configuration of the admin password source for the Autonomous Database.
Sourcepub fn get_admin_password_source_configuration(
&self,
) -> &Option<AdminPasswordSourceConfigurationInput>
pub fn get_admin_password_source_configuration( &self, ) -> &Option<AdminPasswordSourceConfigurationInput>
The configuration of the admin password source for the Autonomous Database.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A client-provided token to ensure the idempotency of the request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A client-provided token to ensure the idempotency of the request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A client-provided token to ensure the idempotency of the request.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
The list of resource tags to apply to the Autonomous Database. Each tag is a key-value pair with no predefined name, type, or namespace.
The list of resource tags to apply to the Autonomous Database. Each tag is a key-value pair with no predefined name, type, or namespace.
The list of resource tags to apply to the Autonomous Database. Each tag is a key-value pair with no predefined name, type, or namespace.