#[non_exhaustive]pub struct UpdateAutonomousDatabaseInput {Show 45 fields
pub autonomous_database_id: Option<String>,
pub admin_password: Option<String>,
pub compute_count: Option<f64>,
pub cpu_core_count: Option<i32>,
pub data_storage_size_in_tbs: Option<i32>,
pub data_storage_size_in_gbs: Option<i32>,
pub display_name: Option<String>,
pub db_name: Option<String>,
pub db_version: Option<String>,
pub db_workload: Option<DbWorkload>,
pub db_tools_details: Option<Vec<DatabaseTool>>,
pub database_edition: Option<DatabaseEdition>,
pub license_model: Option<LicenseModel>,
pub is_auto_scaling_enabled: Option<bool>,
pub is_auto_scaling_for_storage_enabled: Option<bool>,
pub is_backup_retention_locked: Option<bool>,
pub is_local_data_guard_enabled: Option<bool>,
pub is_mtls_connection_required: Option<bool>,
pub is_refreshable_clone: Option<bool>,
pub is_disconnect_peer: Option<bool>,
pub backup_retention_period_in_days: Option<i32>,
pub byol_compute_count_limit: Option<f64>,
pub local_adg_auto_failover_max_data_loss_limit: Option<i32>,
pub autonomous_maintenance_schedule_type: Option<AutonomousMaintenanceScheduleType>,
pub customer_contacts_to_send_to_oci: Option<Vec<CustomerContact>>,
pub scheduled_operations: Option<Vec<ScheduledOperationDetails>>,
pub long_term_backup_schedule: Option<LongTermBackupSchedule>,
pub open_mode: Option<OpenMode>,
pub permission_level: Option<PermissionLevel>,
pub refreshable_mode: Option<RefreshableMode>,
pub private_endpoint_ip: Option<String>,
pub private_endpoint_label: Option<String>,
pub peer_db_id: Option<String>,
pub resource_pool_leader_id: Option<String>,
pub resource_pool_summary: Option<ResourcePoolSummary>,
pub standby_allowlisted_ips_source: Option<StandbyAllowlistedIpsSource>,
pub standby_allowlisted_ips: Option<Vec<String>>,
pub allowlisted_ips: Option<Vec<String>>,
pub auto_refresh_frequency_in_seconds: Option<i32>,
pub auto_refresh_point_lag_in_seconds: Option<i32>,
pub time_of_auto_refresh_start: Option<DateTime>,
pub encryption_key_provider: Option<EncryptionKeyProviderInput>,
pub encryption_key_configuration: Option<EncryptionKeyConfigurationInput>,
pub admin_password_source: Option<AdminPasswordSource>,
pub admin_password_source_configuration: Option<AdminPasswordSourceConfigurationInput>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.autonomous_database_id: Option<String>The unique identifier of the Autonomous Database to update.
admin_password: Option<String>The new password for the ADMIN user of the Autonomous Database.
compute_count: Option<f64>The compute capacity, in number of ECPUs or OCPUs, to assign to the Autonomous Database.
cpu_core_count: Option<i32>The number of CPU cores to allocate to the Autonomous Database.
data_storage_size_in_tbs: Option<i32>The size, in terabytes (TB), of the data volume to allocate for the Autonomous Database.
data_storage_size_in_gbs: Option<i32>The size, in gigabytes (GB), of the data volume to allocate for the Autonomous Database.
display_name: Option<String>The new user-friendly name for the Autonomous Database.
db_name: Option<String>The new name of the Autonomous Database.
db_version: Option<String>The Oracle Database software version to use for the Autonomous Database.
db_workload: Option<DbWorkload>The intended use of the Autonomous Database, such as transaction processing, data warehouse, JSON database, or APEX.
db_tools_details: Option<Vec<DatabaseTool>>The list of database management tools to enable for the Autonomous Database.
database_edition: Option<DatabaseEdition>The Oracle Database edition to apply to the Autonomous Database.
license_model: Option<LicenseModel>The Oracle license model to apply to the Autonomous Database.
is_auto_scaling_enabled: Option<bool>Specifies whether to enable automatic scaling of the compute resources for the Autonomous Database.
is_auto_scaling_for_storage_enabled: Option<bool>Specifies whether to enable automatic scaling of the storage for the Autonomous Database.
is_backup_retention_locked: Option<bool>Specifies whether to lock the backup retention period of the Autonomous Database to prevent it from being shortened.
is_local_data_guard_enabled: Option<bool>Specifies whether to enable local Oracle Data Guard for the Autonomous Database.
is_mtls_connection_required: Option<bool>Specifies whether mutual TLS (mTLS) authentication is required to connect to the Autonomous Database.
is_refreshable_clone: Option<bool>Specifies whether the Autonomous Database is a refreshable clone.
is_disconnect_peer: Option<bool>Specifies whether to disconnect the Autonomous Database from its peer database.
backup_retention_period_in_days: Option<i32>The retention period, in days, for automatic backups of the Autonomous Database.
byol_compute_count_limit: Option<f64>The maximum number of compute resources that you can allocate to the Autonomous Database under the bring-your-own-license (BYOL) model.
local_adg_auto_failover_max_data_loss_limit: Option<i32>The maximum data loss limit, in seconds, for automatic failover to the local Oracle Data Guard standby database.
autonomous_maintenance_schedule_type: Option<AutonomousMaintenanceScheduleType>The maintenance schedule type for the Autonomous Database.
customer_contacts_to_send_to_oci: Option<Vec<CustomerContact>>The list of customer contacts to receive operational notifications from OCI for the Autonomous Database.
scheduled_operations: Option<Vec<ScheduledOperationDetails>>The list of scheduled start and stop times for the Autonomous Database.
long_term_backup_schedule: Option<LongTermBackupSchedule>The long-term backup schedule for the Autonomous Database.
open_mode: Option<OpenMode>The mode in which to open the Autonomous Database, either read-only or read/write.
permission_level: Option<PermissionLevel>The permission level of the Autonomous Database.
refreshable_mode: Option<RefreshableMode>The refresh mode of the refreshable clone Autonomous Database.
private_endpoint_ip: Option<String>The private endpoint IP address for the Autonomous Database.
private_endpoint_label: Option<String>The private endpoint label for the Autonomous Database.
peer_db_id: Option<String>The unique identifier of the peer Autonomous Database.
resource_pool_leader_id: Option<String>The unique identifier of the resource pool leader Autonomous Database.
resource_pool_summary: Option<ResourcePoolSummary>The configuration of the resource pool for the Autonomous Database.
standby_allowlisted_ips_source: Option<StandbyAllowlistedIpsSource>The source of the allowlisted IP addresses for the standby Autonomous Database.
standby_allowlisted_ips: Option<Vec<String>>The list of IP addresses that are allowed to access the standby Autonomous Database.
allowlisted_ips: Option<Vec<String>>The list of IP addresses that are allowed to access the Autonomous Database.
auto_refresh_frequency_in_seconds: Option<i32>The frequency, in seconds, at which the refreshable clone Autonomous Database is automatically refreshed.
auto_refresh_point_lag_in_seconds: Option<i32>The time lag, in seconds, between the refreshable clone and its source Autonomous Database.
time_of_auto_refresh_start: Option<DateTime>The date and time at which the automatic refresh of the refreshable clone Autonomous Database starts.
encryption_key_provider: Option<EncryptionKeyProviderInput>The provider of the encryption key to use for the Autonomous Database.
encryption_key_configuration: Option<EncryptionKeyConfigurationInput>The configuration of the encryption key to use for the Autonomous Database.
admin_password_source: Option<AdminPasswordSource>The source of the admin password for the Autonomous Database. When set to CUSTOMER_MANAGED_AWS_SECRET, the admin password is retrieved from an Amazon Web Services Secrets Manager secret.
admin_password_source_configuration: Option<AdminPasswordSourceConfigurationInput>The configuration of the admin password source for the Autonomous Database.
Implementations
Sourceimpl UpdateAutonomousDatabaseInput
impl UpdateAutonomousDatabaseInput
Sourcepub fn autonomous_database_id(&self) -> Option<&str>
pub fn autonomous_database_id(&self) -> Option<&str>
The unique identifier of the Autonomous Database to update.
Sourcepub fn admin_password(&self) -> Option<&str>
pub fn admin_password(&self) -> Option<&str>
The new password for the ADMIN user of the Autonomous Database.
Sourcepub fn compute_count(&self) -> Option<f64>
pub fn compute_count(&self) -> Option<f64>
The compute capacity, in number of ECPUs or OCPUs, to assign to the Autonomous Database.
Sourcepub fn cpu_core_count(&self) -> Option<i32>
pub fn cpu_core_count(&self) -> Option<i32>
The number of CPU cores to allocate to the Autonomous Database.
Sourcepub fn data_storage_size_in_tbs(&self) -> Option<i32>
pub fn data_storage_size_in_tbs(&self) -> Option<i32>
The size, in terabytes (TB), of the data volume to allocate for the Autonomous Database.
Sourcepub fn data_storage_size_in_gbs(&self) -> Option<i32>
pub fn data_storage_size_in_gbs(&self) -> Option<i32>
The size, in gigabytes (GB), of the data volume to allocate for the Autonomous Database.
Sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
The new user-friendly name for the Autonomous Database.
Sourcepub fn db_version(&self) -> Option<&str>
pub fn db_version(&self) -> Option<&str>
The Oracle Database software version to use for the Autonomous Database.
Sourcepub fn db_workload(&self) -> Option<&DbWorkload>
pub fn db_workload(&self) -> Option<&DbWorkload>
The intended use of the Autonomous Database, such as transaction processing, data warehouse, JSON database, or APEX.
Sourcepub fn db_tools_details(&self) -> &[DatabaseTool]
pub fn db_tools_details(&self) -> &[DatabaseTool]
The list of database management tools to enable for the Autonomous Database.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .db_tools_details.is_none().
Sourcepub fn database_edition(&self) -> Option<&DatabaseEdition>
pub fn database_edition(&self) -> Option<&DatabaseEdition>
The Oracle Database edition to apply to the Autonomous Database.
Sourcepub fn license_model(&self) -> Option<&LicenseModel>
pub fn license_model(&self) -> Option<&LicenseModel>
The Oracle license model to apply to the Autonomous Database.
Sourcepub fn is_auto_scaling_enabled(&self) -> Option<bool>
pub fn is_auto_scaling_enabled(&self) -> Option<bool>
Specifies whether to enable automatic scaling of the compute resources for the Autonomous Database.
Sourcepub fn is_auto_scaling_for_storage_enabled(&self) -> Option<bool>
pub fn is_auto_scaling_for_storage_enabled(&self) -> Option<bool>
Specifies whether to enable automatic scaling of the storage for the Autonomous Database.
Sourcepub fn is_backup_retention_locked(&self) -> Option<bool>
pub fn is_backup_retention_locked(&self) -> Option<bool>
Specifies whether to lock the backup retention period of the Autonomous Database to prevent it from being shortened.
Sourcepub fn is_local_data_guard_enabled(&self) -> Option<bool>
pub fn is_local_data_guard_enabled(&self) -> Option<bool>
Specifies whether to enable local Oracle Data Guard for the Autonomous Database.
Sourcepub fn is_mtls_connection_required(&self) -> Option<bool>
pub fn is_mtls_connection_required(&self) -> Option<bool>
Specifies whether mutual TLS (mTLS) authentication is required to connect to the Autonomous Database.
Sourcepub fn is_refreshable_clone(&self) -> Option<bool>
pub fn is_refreshable_clone(&self) -> Option<bool>
Specifies whether the Autonomous Database is a refreshable clone.
Sourcepub fn is_disconnect_peer(&self) -> Option<bool>
pub fn is_disconnect_peer(&self) -> Option<bool>
Specifies whether to disconnect the Autonomous Database from its peer database.
Sourcepub fn backup_retention_period_in_days(&self) -> Option<i32>
pub fn backup_retention_period_in_days(&self) -> Option<i32>
The retention period, in days, for automatic backups of the Autonomous Database.
Sourcepub fn byol_compute_count_limit(&self) -> Option<f64>
pub fn byol_compute_count_limit(&self) -> Option<f64>
The maximum number of compute resources that you can allocate to the Autonomous Database under the bring-your-own-license (BYOL) model.
Sourcepub fn local_adg_auto_failover_max_data_loss_limit(&self) -> Option<i32>
pub fn local_adg_auto_failover_max_data_loss_limit(&self) -> Option<i32>
The maximum data loss limit, in seconds, for automatic failover to the local Oracle Data Guard standby database.
Sourcepub fn autonomous_maintenance_schedule_type(
&self,
) -> Option<&AutonomousMaintenanceScheduleType>
pub fn autonomous_maintenance_schedule_type( &self, ) -> Option<&AutonomousMaintenanceScheduleType>
The maintenance schedule type for the Autonomous Database.
Sourcepub fn customer_contacts_to_send_to_oci(&self) -> &[CustomerContact]
pub fn customer_contacts_to_send_to_oci(&self) -> &[CustomerContact]
The list of customer contacts to receive operational notifications from OCI for the Autonomous Database.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .customer_contacts_to_send_to_oci.is_none().
Sourcepub fn scheduled_operations(&self) -> &[ScheduledOperationDetails]
pub fn scheduled_operations(&self) -> &[ScheduledOperationDetails]
The list of scheduled start and stop times for the Autonomous Database.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .scheduled_operations.is_none().
Sourcepub fn long_term_backup_schedule(&self) -> Option<&LongTermBackupSchedule>
pub fn long_term_backup_schedule(&self) -> Option<&LongTermBackupSchedule>
The long-term backup schedule for the Autonomous Database.
Sourcepub fn open_mode(&self) -> Option<&OpenMode>
pub fn open_mode(&self) -> Option<&OpenMode>
The mode in which to open the Autonomous Database, either read-only or read/write.
Sourcepub fn permission_level(&self) -> Option<&PermissionLevel>
pub fn permission_level(&self) -> Option<&PermissionLevel>
The permission level of the Autonomous Database.
Sourcepub fn refreshable_mode(&self) -> Option<&RefreshableMode>
pub fn refreshable_mode(&self) -> Option<&RefreshableMode>
The refresh mode of the refreshable clone Autonomous Database.
Sourcepub fn private_endpoint_ip(&self) -> Option<&str>
pub fn private_endpoint_ip(&self) -> Option<&str>
The private endpoint IP address for the Autonomous Database.
Sourcepub fn private_endpoint_label(&self) -> Option<&str>
pub fn private_endpoint_label(&self) -> Option<&str>
The private endpoint label for the Autonomous Database.
Sourcepub fn peer_db_id(&self) -> Option<&str>
pub fn peer_db_id(&self) -> Option<&str>
The unique identifier of the peer Autonomous Database.
Sourcepub fn resource_pool_leader_id(&self) -> Option<&str>
pub fn resource_pool_leader_id(&self) -> Option<&str>
The unique identifier of the resource pool leader Autonomous Database.
Sourcepub fn resource_pool_summary(&self) -> Option<&ResourcePoolSummary>
pub fn resource_pool_summary(&self) -> Option<&ResourcePoolSummary>
The configuration of the resource pool for the Autonomous Database.
Sourcepub fn standby_allowlisted_ips_source(
&self,
) -> Option<&StandbyAllowlistedIpsSource>
pub fn standby_allowlisted_ips_source( &self, ) -> Option<&StandbyAllowlistedIpsSource>
The source of the allowlisted IP addresses for the standby Autonomous Database.
Sourcepub fn standby_allowlisted_ips(&self) -> &[String]
pub fn standby_allowlisted_ips(&self) -> &[String]
The list of IP addresses that are allowed to access the standby Autonomous Database.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .standby_allowlisted_ips.is_none().
Sourcepub fn allowlisted_ips(&self) -> &[String]
pub fn allowlisted_ips(&self) -> &[String]
The list of IP addresses that are allowed to access the Autonomous Database.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .allowlisted_ips.is_none().
Sourcepub fn auto_refresh_frequency_in_seconds(&self) -> Option<i32>
pub fn auto_refresh_frequency_in_seconds(&self) -> Option<i32>
The frequency, in seconds, at which the refreshable clone Autonomous Database is automatically refreshed.
Sourcepub fn auto_refresh_point_lag_in_seconds(&self) -> Option<i32>
pub fn auto_refresh_point_lag_in_seconds(&self) -> Option<i32>
The time lag, in seconds, between the refreshable clone and its source Autonomous Database.
Sourcepub fn time_of_auto_refresh_start(&self) -> Option<&DateTime>
pub fn time_of_auto_refresh_start(&self) -> Option<&DateTime>
The date and time at which the automatic refresh of the refreshable clone Autonomous Database starts.
Sourcepub fn encryption_key_provider(&self) -> Option<&EncryptionKeyProviderInput>
pub fn encryption_key_provider(&self) -> Option<&EncryptionKeyProviderInput>
The provider of the encryption key to use for the Autonomous Database.
Sourcepub fn encryption_key_configuration(
&self,
) -> Option<&EncryptionKeyConfigurationInput>
pub fn encryption_key_configuration( &self, ) -> Option<&EncryptionKeyConfigurationInput>
The configuration of the encryption key to use for the Autonomous Database.
Sourcepub fn admin_password_source(&self) -> Option<&AdminPasswordSource>
pub fn admin_password_source(&self) -> Option<&AdminPasswordSource>
The source of the admin password for the Autonomous Database. When set to CUSTOMER_MANAGED_AWS_SECRET, the admin password is retrieved from an Amazon Web Services Secrets Manager secret.
Sourcepub fn admin_password_source_configuration(
&self,
) -> Option<&AdminPasswordSourceConfigurationInput>
pub fn admin_password_source_configuration( &self, ) -> Option<&AdminPasswordSourceConfigurationInput>
The configuration of the admin password source for the Autonomous Database.
Sourceimpl UpdateAutonomousDatabaseInput
impl UpdateAutonomousDatabaseInput
Sourcepub fn builder() -> UpdateAutonomousDatabaseInputBuilder
pub fn builder() -> UpdateAutonomousDatabaseInputBuilder
Creates a new builder-style object to manufacture UpdateAutonomousDatabaseInput.