#[non_exhaustive]pub struct AutonomousDatabaseSummary {Show 104 fields
pub autonomous_database_id: Option<String>,
pub autonomous_database_arn: Option<String>,
pub oci_resource_anchor_name: Option<String>,
pub percent_progress: Option<f32>,
pub ocid: Option<String>,
pub oci_url: Option<String>,
pub display_name: Option<String>,
pub db_name: Option<String>,
pub source_id: Option<String>,
pub status: Option<AutonomousDatabaseResourceStatus>,
pub status_reason: Option<String>,
pub database_type: Option<DatabaseType>,
pub db_version: Option<String>,
pub db_workload: Option<DbWorkload>,
pub character_set: Option<String>,
pub ncharacter_set: Option<String>,
pub database_edition: Option<DatabaseEdition>,
pub license_model: Option<LicenseModel>,
pub open_mode: Option<OpenMode>,
pub permission_level: Option<PermissionLevel>,
pub is_mtls_connection_required: Option<bool>,
pub autonomous_maintenance_schedule_type: Option<AutonomousMaintenanceScheduleType>,
pub net_services_architecture: Option<NetServicesArchitecture>,
pub available_upgrade_versions: Option<Vec<String>>,
pub byol_compute_count_limit: Option<i32>,
pub connection_string_details: Option<AutonomousDatabaseConnectionStrings>,
pub service_console_url: Option<String>,
pub sql_web_developer_url: Option<String>,
pub customer_contacts: Option<Vec<CustomerContact>>,
pub apex_details: Option<AutonomousDatabaseApex>,
pub standby_db: Option<DatabaseStandbySummary>,
pub local_standby_db: Option<DatabaseStandbySummary>,
pub data_safe_status: Option<DataSafeStatus>,
pub database_management_status: Option<DatabaseManagementStatus>,
pub operations_insights_status: Option<OperationsInsightsStatus>,
pub availability_zone: Option<String>,
pub availability_zone_id: Option<String>,
pub maintenance_target_component: Option<String>,
pub connection_urls: Option<AutonomousDatabaseConnectionUrls>,
pub db_tools_details: Option<Vec<DatabaseTool>>,
pub scheduled_operations: Option<Vec<ScheduledOperationDetails>>,
pub resource_pool_leader_id: Option<String>,
pub compute_count: Option<f32>,
pub compute_model: Option<ComputeModel>,
pub cpu_core_count: Option<i32>,
pub memory_per_oracle_compute_unit_in_gbs: Option<i32>,
pub provisionable_cpus: Option<Vec<i32>>,
pub is_auto_scaling_enabled: Option<bool>,
pub data_storage_size_in_tbs: Option<f64>,
pub data_storage_size_in_gbs: Option<i32>,
pub used_data_storage_size_in_tbs: Option<f64>,
pub used_data_storage_size_in_gbs: Option<i32>,
pub actual_used_data_storage_size_in_tbs: Option<f64>,
pub allocated_storage_size_in_tbs: Option<f64>,
pub in_memory_area_in_gbs: Option<i32>,
pub is_auto_scaling_for_storage_enabled: Option<bool>,
pub odb_network_id: Option<String>,
pub odb_network_arn: Option<String>,
pub private_endpoint: Option<String>,
pub private_endpoint_ip: Option<String>,
pub private_endpoint_label: Option<String>,
pub allowlisted_ips: Option<Vec<String>>,
pub standby_allowlisted_ips: Option<Vec<String>>,
pub standby_allowlisted_ips_source: Option<StandbyAllowlistedIpsSource>,
pub is_local_data_guard_enabled: Option<bool>,
pub is_remote_data_guard_enabled: Option<bool>,
pub local_disaster_recovery_type: Option<DisasterRecoveryType>,
pub role: Option<DataGuardRole>,
pub peer_db_ids: Option<Vec<String>>,
pub failed_data_recovery_in_seconds: Option<i32>,
pub local_adg_auto_failover_max_data_loss_limit: Option<i32>,
pub remote_disaster_recovery_configuration: Option<DisasterRecoveryConfiguration>,
pub is_refreshable_clone: Option<bool>,
pub refreshable_mode: Option<RefreshableMode>,
pub refreshable_status: Option<RefreshableStatus>,
pub auto_refresh_frequency_in_seconds: Option<i32>,
pub auto_refresh_point_lag_in_seconds: Option<i32>,
pub is_reconnect_clone_enabled: Option<bool>,
pub clone_table_space_list: Option<Vec<i32>>,
pub backup_retention_period_in_days: Option<i32>,
pub long_term_backup_schedule: Option<LongTermBackupSchedule>,
pub is_backup_retention_locked: Option<bool>,
pub total_backup_storage_size_in_gbs: Option<f64>,
pub resource_pool_summary: Option<ResourcePoolSummary>,
pub encryption_summary: Option<EncryptionSummary>,
pub created_at: Option<DateTime>,
pub time_of_last_backup: Option<DateTime>,
pub time_maintenance_begin: Option<DateTime>,
pub time_maintenance_end: Option<DateTime>,
pub time_local_data_guard_enabled: Option<DateTime>,
pub time_data_guard_role_changed: Option<DateTime>,
pub time_of_last_switchover: Option<DateTime>,
pub time_of_last_failover: Option<DateTime>,
pub time_of_last_refresh: Option<DateTime>,
pub time_of_last_refresh_point: Option<DateTime>,
pub time_of_next_refresh: Option<DateTime>,
pub time_of_auto_refresh_start: Option<DateTime>,
pub time_deletion_of_free_autonomous_database: Option<DateTime>,
pub time_reclamation_of_free_autonomous_database: Option<DateTime>,
pub time_disaster_recovery_role_changed: Option<DateTime>,
pub time_until_reconnect_clone_enabled: Option<DateTime>,
pub next_long_term_backup_time_stamp: Option<DateTime>,
pub time_undeleted: Option<DateTime>,
pub admin_password_source_summary: Option<AdminPasswordSourceSummary>,
}Expand description
A summary of an Autonomous Database.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.autonomous_database_id: Option<String>The unique identifier of the Autonomous Database.
autonomous_database_arn: Option<String>The Amazon Resource Name (ARN) of the Autonomous Database.
oci_resource_anchor_name: Option<String>The name of the Oracle Cloud Infrastructure (OCI) resource anchor associated with the Autonomous Database.
percent_progress: Option<f32>The progress of the current operation on the Autonomous Database, as a percentage.
ocid: Option<String>The Oracle Cloud Identifier (OCID) of the Autonomous Database.
oci_url: Option<String>The URL for accessing the OCI console page for the Autonomous Database.
display_name: Option<String>The user-friendly name of the Autonomous Database.
db_name: Option<String>The name of the Autonomous Database.
source_id: Option<String>The unique identifier of the source from which the Autonomous Database was created.
status: Option<AutonomousDatabaseResourceStatus>The current status of the Autonomous Database.
status_reason: Option<String>Additional information about the current status of the Autonomous Database, if applicable.
database_type: Option<DatabaseType>The type of the Autonomous Database, either a regular database or a clone.
db_version: Option<String>The Oracle Database software version of the Autonomous Database.
db_workload: Option<DbWorkload>The intended use of the Autonomous Database, such as transaction processing, data warehouse, JSON database, or APEX.
character_set: Option<String>The character set of the Autonomous Database.
ncharacter_set: Option<String>The national character set of the Autonomous Database.
database_edition: Option<DatabaseEdition>The Oracle Database edition of the Autonomous Database.
license_model: Option<LicenseModel>The Oracle license model that applies to the Autonomous Database.
open_mode: Option<OpenMode>The mode in which the Autonomous Database is open, either read-only or read/write.
permission_level: Option<PermissionLevel>The permission level of the Autonomous Database.
is_mtls_connection_required: Option<bool>Indicates whether mutual TLS (mTLS) authentication is required to connect to the Autonomous Database.
autonomous_maintenance_schedule_type: Option<AutonomousMaintenanceScheduleType>The maintenance schedule type for the Autonomous Database.
net_services_architecture: Option<NetServicesArchitecture>The Oracle Net Services architecture of the Autonomous Database, either dedicated or shared.
available_upgrade_versions: Option<Vec<String>>The list of Oracle Database software versions to which the Autonomous Database can be upgraded.
byol_compute_count_limit: Option<i32>The maximum number of compute resources that you can allocate to the Autonomous Database under the bring-your-own-license (BYOL) model.
connection_string_details: Option<AutonomousDatabaseConnectionStrings>The connection string details for the Autonomous Database.
service_console_url: Option<String>The URL for accessing the Oracle service console for the Autonomous Database.
sql_web_developer_url: Option<String>The URL for accessing Oracle SQL Developer Web for the Autonomous Database.
customer_contacts: Option<Vec<CustomerContact>>The list of customer contacts that receive operational notifications from Oracle for the Autonomous Database.
apex_details: Option<AutonomousDatabaseApex>The Oracle Application Express (APEX) details for the Autonomous Database.
standby_db: Option<DatabaseStandbySummary>The details of the standby Autonomous Database in a cross-Region Oracle Data Guard configuration.
local_standby_db: Option<DatabaseStandbySummary>The details of the local standby Autonomous Database in an Oracle Data Guard configuration.
data_safe_status: Option<DataSafeStatus>The status of the Oracle Data Safe registration for the Autonomous Database.
database_management_status: Option<DatabaseManagementStatus>The status of Oracle Database Management for the Autonomous Database.
operations_insights_status: Option<OperationsInsightsStatus>The status of Oracle Operations Insights for the Autonomous Database.
availability_zone: Option<String>The Availability Zone where the Autonomous Database is located.
availability_zone_id: Option<String>The unique identifier of the Availability Zone where the Autonomous Database is located.
maintenance_target_component: Option<String>The component on the Autonomous Database that the current maintenance is being applied to.
connection_urls: Option<AutonomousDatabaseConnectionUrls>The connection URLs for accessing tools and services for the Autonomous Database.
db_tools_details: Option<Vec<DatabaseTool>>The list of database management tools enabled for the Autonomous Database.
scheduled_operations: Option<Vec<ScheduledOperationDetails>>The list of scheduled start and stop times for the Autonomous Database.
resource_pool_leader_id: Option<String>The unique identifier of the resource pool leader Autonomous Database.
compute_count: Option<f32>The compute capacity, in number of Elastic CPUs (ECPUs) or Oracle CPUs (OCPUs), assigned to the Autonomous Database.
compute_model: Option<ComputeModel>The compute model of the Autonomous Database, either ECPU or OCPU.
cpu_core_count: Option<i32>The number of CPU cores allocated to the Autonomous Database.
memory_per_oracle_compute_unit_in_gbs: Option<i32>The amount of memory allocated per Oracle Compute Unit, in GB.
provisionable_cpus: Option<Vec<i32>>The list of CPU core counts that you can provision for the Autonomous Database.
is_auto_scaling_enabled: Option<bool>Indicates whether automatic scaling of the compute resources is enabled for the Autonomous Database.
data_storage_size_in_tbs: Option<f64>The size, in terabytes (TB), of the data volume allocated for the Autonomous Database.
data_storage_size_in_gbs: Option<i32>The size, in gigabytes (GB), of the data volume allocated for the Autonomous Database.
used_data_storage_size_in_tbs: Option<f64>The amount of data storage currently in use by the Autonomous Database, in TB.
used_data_storage_size_in_gbs: Option<i32>The amount of data storage currently in use by the Autonomous Database, in GB.
actual_used_data_storage_size_in_tbs: Option<f64>The actual amount of data storage currently in use by the Autonomous Database, in TB.
allocated_storage_size_in_tbs: Option<f64>The amount of storage currently allocated to the Autonomous Database, in TB.
in_memory_area_in_gbs: Option<i32>The size of the in-memory area of the Autonomous Database, in GB.
is_auto_scaling_for_storage_enabled: Option<bool>Indicates whether automatic scaling of the storage is enabled for the Autonomous Database.
odb_network_id: Option<String>The unique identifier of the ODB network associated with the Autonomous Database.
odb_network_arn: Option<String>The Amazon Resource Name (ARN) of the ODB network associated with the Autonomous Database.
private_endpoint: Option<String>The private endpoint for the Autonomous Database.
private_endpoint_ip: Option<String>The private endpoint IP address for the Autonomous Database.
private_endpoint_label: Option<String>The private endpoint label for the Autonomous Database.
allowlisted_ips: Option<Vec<String>>The list of IP addresses that are allowed to access the Autonomous Database.
standby_allowlisted_ips: Option<Vec<String>>The list of IP addresses that are allowed to access the standby Autonomous Database.
standby_allowlisted_ips_source: Option<StandbyAllowlistedIpsSource>The source of the allowlisted IP addresses for the standby Autonomous Database.
is_local_data_guard_enabled: Option<bool>Indicates whether local Oracle Data Guard is enabled for the Autonomous Database.
is_remote_data_guard_enabled: Option<bool>Indicates whether remote Oracle Data Guard is enabled for the Autonomous Database.
local_disaster_recovery_type: Option<DisasterRecoveryType>The type of local disaster recovery configured for the Autonomous Database.
role: Option<DataGuardRole>The Oracle Data Guard role of the Autonomous Database.
peer_db_ids: Option<Vec<String>>The list of unique identifiers of the peer Autonomous Databases.
failed_data_recovery_in_seconds: Option<i32>The amount of time, in seconds, that the data in the Autonomous Database is behind the data in the primary database.
local_adg_auto_failover_max_data_loss_limit: Option<i32>The maximum data loss limit, in seconds, for automatic failover to the local Oracle Data Guard standby database.
remote_disaster_recovery_configuration: Option<DisasterRecoveryConfiguration>The configuration of the remote disaster recovery for the Autonomous Database.
is_refreshable_clone: Option<bool>Indicates whether the Autonomous Database is a refreshable clone.
refreshable_mode: Option<RefreshableMode>The refresh mode of the refreshable clone Autonomous Database.
refreshable_status: Option<RefreshableStatus>The refresh status of the refreshable clone Autonomous Database.
auto_refresh_frequency_in_seconds: Option<i32>The frequency, in seconds, at which the refreshable clone Autonomous Database is automatically refreshed.
auto_refresh_point_lag_in_seconds: Option<i32>The time lag, in seconds, between the refreshable clone and its source Autonomous Database.
is_reconnect_clone_enabled: Option<bool>Indicates whether reconnecting the refreshable clone to its source Autonomous Database is enabled.
clone_table_space_list: Option<Vec<i32>>The list of tablespace identifiers to clone for the Autonomous Database.
backup_retention_period_in_days: Option<i32>The retention period, in days, for automatic backups of the Autonomous Database.
long_term_backup_schedule: Option<LongTermBackupSchedule>The long-term backup schedule for the Autonomous Database.
is_backup_retention_locked: Option<bool>Indicates whether the backup retention period of the Autonomous Database is locked.
total_backup_storage_size_in_gbs: Option<f64>The total amount of backup storage used by the Autonomous Database, in GB.
resource_pool_summary: Option<ResourcePoolSummary>The configuration of the resource pool for the Autonomous Database.
encryption_summary: Option<EncryptionSummary>The encryption configuration for the Autonomous Database.
created_at: Option<DateTime>The date and time when the Autonomous Database was created.
time_of_last_backup: Option<DateTime>The date and time of the last backup of the Autonomous Database.
time_maintenance_begin: Option<DateTime>The date and time when the next maintenance of the Autonomous Database begins.
time_maintenance_end: Option<DateTime>The date and time when the next maintenance of the Autonomous Database ends.
time_local_data_guard_enabled: Option<DateTime>The date and time when local Oracle Data Guard was enabled for the Autonomous Database.
time_data_guard_role_changed: Option<DateTime>The date and time when the Oracle Data Guard role of the Autonomous Database last changed.
time_of_last_switchover: Option<DateTime>The date and time of the last switchover operation for the Autonomous Database.
time_of_last_failover: Option<DateTime>The date and time of the last failover operation for the Autonomous Database.
time_of_last_refresh: Option<DateTime>The date and time of the last refresh of the refreshable clone Autonomous Database.
time_of_last_refresh_point: Option<DateTime>The date and time as of which the data in the refreshable clone Autonomous Database is current.
time_of_next_refresh: Option<DateTime>The date and time of the next scheduled refresh of the refreshable clone Autonomous Database.
time_of_auto_refresh_start: Option<DateTime>The date and time at which the automatic refresh of the refreshable clone Autonomous Database starts.
time_deletion_of_free_autonomous_database: Option<DateTime>The date and time when the inactive Always Free Autonomous Database is scheduled to be automatically deleted.
time_reclamation_of_free_autonomous_database: Option<DateTime>The date and time when the Always Free Autonomous Database is scheduled to be stopped because of inactivity.
time_disaster_recovery_role_changed: Option<DateTime>The date and time when the disaster recovery role of the Autonomous Database last changed.
time_until_reconnect_clone_enabled: Option<DateTime>The date and time until which reconnecting the refreshable clone to its source Autonomous Database is allowed.
next_long_term_backup_time_stamp: Option<DateTime>The date and time of the next scheduled long-term backup of the Autonomous Database.
time_undeleted: Option<DateTime>The date and time when the Autonomous Database was restored after deletion.
admin_password_source_summary: Option<AdminPasswordSourceSummary>The summary of the admin password source configuration for the Autonomous Database.
Implementations
Sourceimpl AutonomousDatabaseSummary
impl AutonomousDatabaseSummary
Sourcepub fn autonomous_database_id(&self) -> Option<&str>
pub fn autonomous_database_id(&self) -> Option<&str>
The unique identifier of the Autonomous Database.
Sourcepub fn autonomous_database_arn(&self) -> Option<&str>
pub fn autonomous_database_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the Autonomous Database.
Sourcepub fn oci_resource_anchor_name(&self) -> Option<&str>
pub fn oci_resource_anchor_name(&self) -> Option<&str>
The name of the Oracle Cloud Infrastructure (OCI) resource anchor associated with the Autonomous Database.
Sourcepub fn percent_progress(&self) -> Option<f32>
pub fn percent_progress(&self) -> Option<f32>
The progress of the current operation on the Autonomous Database, as a percentage.
Sourcepub fn ocid(&self) -> Option<&str>
pub fn ocid(&self) -> Option<&str>
The Oracle Cloud Identifier (OCID) of the Autonomous Database.
Sourcepub fn oci_url(&self) -> Option<&str>
pub fn oci_url(&self) -> Option<&str>
The URL for accessing the OCI console page for the Autonomous Database.
Sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
The user-friendly name of the Autonomous Database.
Sourcepub fn source_id(&self) -> Option<&str>
pub fn source_id(&self) -> Option<&str>
The unique identifier of the source from which the Autonomous Database was created.
Sourcepub fn status(&self) -> Option<&AutonomousDatabaseResourceStatus>
pub fn status(&self) -> Option<&AutonomousDatabaseResourceStatus>
The current status of the Autonomous Database.
Sourcepub fn status_reason(&self) -> Option<&str>
pub fn status_reason(&self) -> Option<&str>
Additional information about the current status of the Autonomous Database, if applicable.
Sourcepub fn database_type(&self) -> Option<&DatabaseType>
pub fn database_type(&self) -> Option<&DatabaseType>
The type of the Autonomous Database, either a regular database or a clone.
Sourcepub fn db_version(&self) -> Option<&str>
pub fn db_version(&self) -> Option<&str>
The Oracle Database software version of the Autonomous Database.
Sourcepub fn db_workload(&self) -> Option<&DbWorkload>
pub fn db_workload(&self) -> Option<&DbWorkload>
The intended use of the Autonomous Database, such as transaction processing, data warehouse, JSON database, or APEX.
Sourcepub fn character_set(&self) -> Option<&str>
pub fn character_set(&self) -> Option<&str>
The character set of the Autonomous Database.
Sourcepub fn ncharacter_set(&self) -> Option<&str>
pub fn ncharacter_set(&self) -> Option<&str>
The national character set of the Autonomous Database.
Sourcepub fn database_edition(&self) -> Option<&DatabaseEdition>
pub fn database_edition(&self) -> Option<&DatabaseEdition>
The Oracle Database edition of the Autonomous Database.
Sourcepub fn license_model(&self) -> Option<&LicenseModel>
pub fn license_model(&self) -> Option<&LicenseModel>
The Oracle license model that applies to the Autonomous Database.
Sourcepub fn open_mode(&self) -> Option<&OpenMode>
pub fn open_mode(&self) -> Option<&OpenMode>
The mode in which the Autonomous Database is open, either read-only or read/write.
Sourcepub fn permission_level(&self) -> Option<&PermissionLevel>
pub fn permission_level(&self) -> Option<&PermissionLevel>
The permission level of the Autonomous Database.
Sourcepub fn is_mtls_connection_required(&self) -> Option<bool>
pub fn is_mtls_connection_required(&self) -> Option<bool>
Indicates whether mutual TLS (mTLS) authentication is required to connect to the Autonomous Database.
Sourcepub fn autonomous_maintenance_schedule_type(
&self,
) -> Option<&AutonomousMaintenanceScheduleType>
pub fn autonomous_maintenance_schedule_type( &self, ) -> Option<&AutonomousMaintenanceScheduleType>
The maintenance schedule type for the Autonomous Database.
Sourcepub fn net_services_architecture(&self) -> Option<&NetServicesArchitecture>
pub fn net_services_architecture(&self) -> Option<&NetServicesArchitecture>
The Oracle Net Services architecture of the Autonomous Database, either dedicated or shared.
Sourcepub fn available_upgrade_versions(&self) -> &[String]
pub fn available_upgrade_versions(&self) -> &[String]
The list of Oracle Database software versions to which the Autonomous Database can be upgraded.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .available_upgrade_versions.is_none().
Sourcepub fn byol_compute_count_limit(&self) -> Option<i32>
pub fn byol_compute_count_limit(&self) -> Option<i32>
The maximum number of compute resources that you can allocate to the Autonomous Database under the bring-your-own-license (BYOL) model.
Sourcepub fn connection_string_details(
&self,
) -> Option<&AutonomousDatabaseConnectionStrings>
pub fn connection_string_details( &self, ) -> Option<&AutonomousDatabaseConnectionStrings>
The connection string details for the Autonomous Database.
Sourcepub fn service_console_url(&self) -> Option<&str>
pub fn service_console_url(&self) -> Option<&str>
The URL for accessing the Oracle service console for the Autonomous Database.
Sourcepub fn sql_web_developer_url(&self) -> Option<&str>
pub fn sql_web_developer_url(&self) -> Option<&str>
The URL for accessing Oracle SQL Developer Web for the Autonomous Database.
Sourcepub fn customer_contacts(&self) -> &[CustomerContact]
pub fn customer_contacts(&self) -> &[CustomerContact]
The list of customer contacts that receive operational notifications from Oracle for the Autonomous Database.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .customer_contacts.is_none().
Sourcepub fn apex_details(&self) -> Option<&AutonomousDatabaseApex>
pub fn apex_details(&self) -> Option<&AutonomousDatabaseApex>
The Oracle Application Express (APEX) details for the Autonomous Database.
Sourcepub fn standby_db(&self) -> Option<&DatabaseStandbySummary>
pub fn standby_db(&self) -> Option<&DatabaseStandbySummary>
The details of the standby Autonomous Database in a cross-Region Oracle Data Guard configuration.
Sourcepub fn local_standby_db(&self) -> Option<&DatabaseStandbySummary>
pub fn local_standby_db(&self) -> Option<&DatabaseStandbySummary>
The details of the local standby Autonomous Database in an Oracle Data Guard configuration.
Sourcepub fn data_safe_status(&self) -> Option<&DataSafeStatus>
pub fn data_safe_status(&self) -> Option<&DataSafeStatus>
The status of the Oracle Data Safe registration for the Autonomous Database.
Sourcepub fn database_management_status(&self) -> Option<&DatabaseManagementStatus>
pub fn database_management_status(&self) -> Option<&DatabaseManagementStatus>
The status of Oracle Database Management for the Autonomous Database.
Sourcepub fn operations_insights_status(&self) -> Option<&OperationsInsightsStatus>
pub fn operations_insights_status(&self) -> Option<&OperationsInsightsStatus>
The status of Oracle Operations Insights for the Autonomous Database.
Sourcepub fn availability_zone(&self) -> Option<&str>
pub fn availability_zone(&self) -> Option<&str>
The Availability Zone where the Autonomous Database is located.
Sourcepub fn availability_zone_id(&self) -> Option<&str>
pub fn availability_zone_id(&self) -> Option<&str>
The unique identifier of the Availability Zone where the Autonomous Database is located.
Sourcepub fn maintenance_target_component(&self) -> Option<&str>
pub fn maintenance_target_component(&self) -> Option<&str>
The component on the Autonomous Database that the current maintenance is being applied to.
Sourcepub fn connection_urls(&self) -> Option<&AutonomousDatabaseConnectionUrls>
pub fn connection_urls(&self) -> Option<&AutonomousDatabaseConnectionUrls>
The connection URLs for accessing tools and services for the Autonomous Database.
Sourcepub fn db_tools_details(&self) -> &[DatabaseTool]
pub fn db_tools_details(&self) -> &[DatabaseTool]
The list of database management tools enabled for the Autonomous Database.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .db_tools_details.is_none().
Sourcepub fn scheduled_operations(&self) -> &[ScheduledOperationDetails]
pub fn scheduled_operations(&self) -> &[ScheduledOperationDetails]
The list of scheduled start and stop times for the Autonomous Database.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .scheduled_operations.is_none().
Sourcepub fn resource_pool_leader_id(&self) -> Option<&str>
pub fn resource_pool_leader_id(&self) -> Option<&str>
The unique identifier of the resource pool leader Autonomous Database.
Sourcepub fn compute_count(&self) -> Option<f32>
pub fn compute_count(&self) -> Option<f32>
The compute capacity, in number of Elastic CPUs (ECPUs) or Oracle CPUs (OCPUs), assigned to the Autonomous Database.
Sourcepub fn compute_model(&self) -> Option<&ComputeModel>
pub fn compute_model(&self) -> Option<&ComputeModel>
The compute model of the Autonomous Database, either ECPU or OCPU.
Sourcepub fn cpu_core_count(&self) -> Option<i32>
pub fn cpu_core_count(&self) -> Option<i32>
The number of CPU cores allocated to the Autonomous Database.
Sourcepub fn memory_per_oracle_compute_unit_in_gbs(&self) -> Option<i32>
pub fn memory_per_oracle_compute_unit_in_gbs(&self) -> Option<i32>
The amount of memory allocated per Oracle Compute Unit, in GB.
Sourcepub fn provisionable_cpus(&self) -> &[i32]
pub fn provisionable_cpus(&self) -> &[i32]
The list of CPU core counts that you can provision for the Autonomous Database.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .provisionable_cpus.is_none().
Sourcepub fn is_auto_scaling_enabled(&self) -> Option<bool>
pub fn is_auto_scaling_enabled(&self) -> Option<bool>
Indicates whether automatic scaling of the compute resources is enabled for the Autonomous Database.
Sourcepub fn data_storage_size_in_tbs(&self) -> Option<f64>
pub fn data_storage_size_in_tbs(&self) -> Option<f64>
The size, in terabytes (TB), of the data volume allocated for the Autonomous Database.
Sourcepub fn data_storage_size_in_gbs(&self) -> Option<i32>
pub fn data_storage_size_in_gbs(&self) -> Option<i32>
The size, in gigabytes (GB), of the data volume allocated for the Autonomous Database.
Sourcepub fn used_data_storage_size_in_tbs(&self) -> Option<f64>
pub fn used_data_storage_size_in_tbs(&self) -> Option<f64>
The amount of data storage currently in use by the Autonomous Database, in TB.
Sourcepub fn used_data_storage_size_in_gbs(&self) -> Option<i32>
pub fn used_data_storage_size_in_gbs(&self) -> Option<i32>
The amount of data storage currently in use by the Autonomous Database, in GB.
Sourcepub fn actual_used_data_storage_size_in_tbs(&self) -> Option<f64>
pub fn actual_used_data_storage_size_in_tbs(&self) -> Option<f64>
The actual amount of data storage currently in use by the Autonomous Database, in TB.
Sourcepub fn allocated_storage_size_in_tbs(&self) -> Option<f64>
pub fn allocated_storage_size_in_tbs(&self) -> Option<f64>
The amount of storage currently allocated to the Autonomous Database, in TB.
Sourcepub fn in_memory_area_in_gbs(&self) -> Option<i32>
pub fn in_memory_area_in_gbs(&self) -> Option<i32>
The size of the in-memory area of the Autonomous Database, in GB.
Sourcepub fn is_auto_scaling_for_storage_enabled(&self) -> Option<bool>
pub fn is_auto_scaling_for_storage_enabled(&self) -> Option<bool>
Indicates whether automatic scaling of the storage is enabled for the Autonomous Database.
Sourcepub fn odb_network_id(&self) -> Option<&str>
pub fn odb_network_id(&self) -> Option<&str>
The unique identifier of the ODB network associated with the Autonomous Database.
Sourcepub fn odb_network_arn(&self) -> Option<&str>
pub fn odb_network_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the ODB network associated with the Autonomous Database.
Sourcepub fn private_endpoint(&self) -> Option<&str>
pub fn private_endpoint(&self) -> Option<&str>
The private endpoint for the Autonomous Database.
Sourcepub fn private_endpoint_ip(&self) -> Option<&str>
pub fn private_endpoint_ip(&self) -> Option<&str>
The private endpoint IP address for the Autonomous Database.
Sourcepub fn private_endpoint_label(&self) -> Option<&str>
pub fn private_endpoint_label(&self) -> Option<&str>
The private endpoint label for the Autonomous Database.
Sourcepub fn allowlisted_ips(&self) -> &[String]
pub fn allowlisted_ips(&self) -> &[String]
The list of IP addresses that are allowed to access the Autonomous Database.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .allowlisted_ips.is_none().
Sourcepub fn standby_allowlisted_ips(&self) -> &[String]
pub fn standby_allowlisted_ips(&self) -> &[String]
The list of IP addresses that are allowed to access the standby Autonomous Database.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .standby_allowlisted_ips.is_none().
Sourcepub fn standby_allowlisted_ips_source(
&self,
) -> Option<&StandbyAllowlistedIpsSource>
pub fn standby_allowlisted_ips_source( &self, ) -> Option<&StandbyAllowlistedIpsSource>
The source of the allowlisted IP addresses for the standby Autonomous Database.
Sourcepub fn is_local_data_guard_enabled(&self) -> Option<bool>
pub fn is_local_data_guard_enabled(&self) -> Option<bool>
Indicates whether local Oracle Data Guard is enabled for the Autonomous Database.
Sourcepub fn is_remote_data_guard_enabled(&self) -> Option<bool>
pub fn is_remote_data_guard_enabled(&self) -> Option<bool>
Indicates whether remote Oracle Data Guard is enabled for the Autonomous Database.
Sourcepub fn local_disaster_recovery_type(&self) -> Option<&DisasterRecoveryType>
pub fn local_disaster_recovery_type(&self) -> Option<&DisasterRecoveryType>
The type of local disaster recovery configured for the Autonomous Database.
Sourcepub fn role(&self) -> Option<&DataGuardRole>
pub fn role(&self) -> Option<&DataGuardRole>
The Oracle Data Guard role of the Autonomous Database.
Sourcepub fn peer_db_ids(&self) -> &[String]
pub fn peer_db_ids(&self) -> &[String]
The list of unique identifiers of the peer Autonomous Databases.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .peer_db_ids.is_none().
Sourcepub fn failed_data_recovery_in_seconds(&self) -> Option<i32>
pub fn failed_data_recovery_in_seconds(&self) -> Option<i32>
The amount of time, in seconds, that the data in the Autonomous Database is behind the data in the primary database.
Sourcepub fn local_adg_auto_failover_max_data_loss_limit(&self) -> Option<i32>
pub fn local_adg_auto_failover_max_data_loss_limit(&self) -> Option<i32>
The maximum data loss limit, in seconds, for automatic failover to the local Oracle Data Guard standby database.
Sourcepub fn remote_disaster_recovery_configuration(
&self,
) -> Option<&DisasterRecoveryConfiguration>
pub fn remote_disaster_recovery_configuration( &self, ) -> Option<&DisasterRecoveryConfiguration>
The configuration of the remote disaster recovery for the Autonomous Database.
Sourcepub fn is_refreshable_clone(&self) -> Option<bool>
pub fn is_refreshable_clone(&self) -> Option<bool>
Indicates whether the Autonomous Database is a refreshable clone.
Sourcepub fn refreshable_mode(&self) -> Option<&RefreshableMode>
pub fn refreshable_mode(&self) -> Option<&RefreshableMode>
The refresh mode of the refreshable clone Autonomous Database.
Sourcepub fn refreshable_status(&self) -> Option<&RefreshableStatus>
pub fn refreshable_status(&self) -> Option<&RefreshableStatus>
The refresh status of the refreshable clone Autonomous Database.
Sourcepub fn auto_refresh_frequency_in_seconds(&self) -> Option<i32>
pub fn auto_refresh_frequency_in_seconds(&self) -> Option<i32>
The frequency, in seconds, at which the refreshable clone Autonomous Database is automatically refreshed.
Sourcepub fn auto_refresh_point_lag_in_seconds(&self) -> Option<i32>
pub fn auto_refresh_point_lag_in_seconds(&self) -> Option<i32>
The time lag, in seconds, between the refreshable clone and its source Autonomous Database.
Sourcepub fn is_reconnect_clone_enabled(&self) -> Option<bool>
pub fn is_reconnect_clone_enabled(&self) -> Option<bool>
Indicates whether reconnecting the refreshable clone to its source Autonomous Database is enabled.
Sourcepub fn clone_table_space_list(&self) -> &[i32]
pub fn clone_table_space_list(&self) -> &[i32]
The list of tablespace identifiers to clone for the Autonomous Database.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .clone_table_space_list.is_none().
Sourcepub fn backup_retention_period_in_days(&self) -> Option<i32>
pub fn backup_retention_period_in_days(&self) -> Option<i32>
The retention period, in days, for automatic backups of the Autonomous Database.
Sourcepub fn long_term_backup_schedule(&self) -> Option<&LongTermBackupSchedule>
pub fn long_term_backup_schedule(&self) -> Option<&LongTermBackupSchedule>
The long-term backup schedule for the Autonomous Database.
Sourcepub fn is_backup_retention_locked(&self) -> Option<bool>
pub fn is_backup_retention_locked(&self) -> Option<bool>
Indicates whether the backup retention period of the Autonomous Database is locked.
Sourcepub fn total_backup_storage_size_in_gbs(&self) -> Option<f64>
pub fn total_backup_storage_size_in_gbs(&self) -> Option<f64>
The total amount of backup storage used by the Autonomous Database, in GB.
Sourcepub fn resource_pool_summary(&self) -> Option<&ResourcePoolSummary>
pub fn resource_pool_summary(&self) -> Option<&ResourcePoolSummary>
The configuration of the resource pool for the Autonomous Database.
Sourcepub fn encryption_summary(&self) -> Option<&EncryptionSummary>
pub fn encryption_summary(&self) -> Option<&EncryptionSummary>
The encryption configuration for the Autonomous Database.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time when the Autonomous Database was created.
Sourcepub fn time_of_last_backup(&self) -> Option<&DateTime>
pub fn time_of_last_backup(&self) -> Option<&DateTime>
The date and time of the last backup of the Autonomous Database.
Sourcepub fn time_maintenance_begin(&self) -> Option<&DateTime>
pub fn time_maintenance_begin(&self) -> Option<&DateTime>
The date and time when the next maintenance of the Autonomous Database begins.
Sourcepub fn time_maintenance_end(&self) -> Option<&DateTime>
pub fn time_maintenance_end(&self) -> Option<&DateTime>
The date and time when the next maintenance of the Autonomous Database ends.
Sourcepub fn time_local_data_guard_enabled(&self) -> Option<&DateTime>
pub fn time_local_data_guard_enabled(&self) -> Option<&DateTime>
The date and time when local Oracle Data Guard was enabled for the Autonomous Database.
Sourcepub fn time_data_guard_role_changed(&self) -> Option<&DateTime>
pub fn time_data_guard_role_changed(&self) -> Option<&DateTime>
The date and time when the Oracle Data Guard role of the Autonomous Database last changed.
Sourcepub fn time_of_last_switchover(&self) -> Option<&DateTime>
pub fn time_of_last_switchover(&self) -> Option<&DateTime>
The date and time of the last switchover operation for the Autonomous Database.
Sourcepub fn time_of_last_failover(&self) -> Option<&DateTime>
pub fn time_of_last_failover(&self) -> Option<&DateTime>
The date and time of the last failover operation for the Autonomous Database.
Sourcepub fn time_of_last_refresh(&self) -> Option<&DateTime>
pub fn time_of_last_refresh(&self) -> Option<&DateTime>
The date and time of the last refresh of the refreshable clone Autonomous Database.
Sourcepub fn time_of_last_refresh_point(&self) -> Option<&DateTime>
pub fn time_of_last_refresh_point(&self) -> Option<&DateTime>
The date and time as of which the data in the refreshable clone Autonomous Database is current.
Sourcepub fn time_of_next_refresh(&self) -> Option<&DateTime>
pub fn time_of_next_refresh(&self) -> Option<&DateTime>
The date and time of the next scheduled refresh of the refreshable clone Autonomous Database.
Sourcepub fn time_of_auto_refresh_start(&self) -> Option<&DateTime>
pub fn time_of_auto_refresh_start(&self) -> Option<&DateTime>
The date and time at which the automatic refresh of the refreshable clone Autonomous Database starts.
Sourcepub fn time_deletion_of_free_autonomous_database(&self) -> Option<&DateTime>
pub fn time_deletion_of_free_autonomous_database(&self) -> Option<&DateTime>
The date and time when the inactive Always Free Autonomous Database is scheduled to be automatically deleted.
Sourcepub fn time_reclamation_of_free_autonomous_database(&self) -> Option<&DateTime>
pub fn time_reclamation_of_free_autonomous_database(&self) -> Option<&DateTime>
The date and time when the Always Free Autonomous Database is scheduled to be stopped because of inactivity.
Sourcepub fn time_disaster_recovery_role_changed(&self) -> Option<&DateTime>
pub fn time_disaster_recovery_role_changed(&self) -> Option<&DateTime>
The date and time when the disaster recovery role of the Autonomous Database last changed.
Sourcepub fn time_until_reconnect_clone_enabled(&self) -> Option<&DateTime>
pub fn time_until_reconnect_clone_enabled(&self) -> Option<&DateTime>
The date and time until which reconnecting the refreshable clone to its source Autonomous Database is allowed.
Sourcepub fn next_long_term_backup_time_stamp(&self) -> Option<&DateTime>
pub fn next_long_term_backup_time_stamp(&self) -> Option<&DateTime>
The date and time of the next scheduled long-term backup of the Autonomous Database.
Sourcepub fn time_undeleted(&self) -> Option<&DateTime>
pub fn time_undeleted(&self) -> Option<&DateTime>
The date and time when the Autonomous Database was restored after deletion.
Sourcepub fn admin_password_source_summary(
&self,
) -> Option<&AdminPasswordSourceSummary>
pub fn admin_password_source_summary( &self, ) -> Option<&AdminPasswordSourceSummary>
The summary of the admin password source configuration for the Autonomous Database.
Sourceimpl AutonomousDatabaseSummary
impl AutonomousDatabaseSummary
Sourcepub fn builder() -> AutonomousDatabaseSummaryBuilder
pub fn builder() -> AutonomousDatabaseSummaryBuilder
Creates a new builder-style object to manufacture AutonomousDatabaseSummary.